
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** LOAD DATA
***********************/

use "source/RawDataCPS", clear

*gen rand=runiform()
*keep if rand<.1

/***********************
** OCCUPATION AGGREGATION
***********************/

gen occ_agg = .
replace occ_agg=1 if occ>=1 & occ<=43
replace occ_agg=2 if occ>=50 & occ<=73
replace occ_agg=3 if occ>=80 & occ<=95
replace occ_agg=4 if occ>=100 & occ<=124
replace occ_agg=5 if occ>=130 & occ<=156
replace occ_agg=6 if occ>=160 & occ<=196
replace occ_agg=7 if occ>=200 & occ<=206
replace occ_agg=8 if occ>=210 & occ<=215
replace occ_agg=9 if occ>=220 & occ<=255
replace occ_agg=10 if occ>=260 & occ<=296
replace occ_agg=11 if occ>=300 & occ<=354
replace occ_agg=12 if occ>=360 & occ<=365
replace occ_agg=13 if occ>=370 & occ<=395
replace occ_agg=14 if occ>=400 & occ<=416
replace occ_agg=15 if occ>=420 & occ<=425
replace occ_agg=16 if occ>=430 & occ<=465
replace occ_agg=17 if occ>=470 & occ<=496
replace occ_agg=18 if occ>=500 & occ<=593
replace occ_agg=19 if occ>=600 & occ<=613
replace occ_agg=20 if occ>=620 & occ<=676
replace occ_agg=21 if occ>=680 & occ<=694
replace occ_agg=22 if occ>=700 & occ<=762
replace occ_agg=23 if occ>=770 & occ<=896
replace occ_agg=24 if occ>=900 & occ<=975


label define occ_agg_lbl 1 `"Management occupations"'
label define occ_agg_lbl 2 `"Business Operations Specialists"', add
label define occ_agg_lbl 3 `"Financial Specialists"', add
label define occ_agg_lbl 4 `"Computer and Mathematical Occupations"', add
label define occ_agg_lbl 5 `"Architecture and Engineering Occupations"', add
label define occ_agg_lbl 6 `"Life, Physical, and Social Science Occupations"', add
label define occ_agg_lbl 7 `"Community and Social Services Occupations"', add
label define occ_agg_lbl 8 `"Legal Occupations"', add
label define occ_agg_lbl 9 `"Education, Training, and Library Occupations"', add
label define occ_agg_lbl 10 `"Arts, Design, Entertainment, Sports, and Media Occupations"', add
label define occ_agg_lbl 11 `"Healthcare Practitioners and Technical Occupations"', add
label define occ_agg_lbl 12 `"Healthcare Support Occupations"', add
label define occ_agg_lbl 13 `"Protective Service Occupations"', add
label define occ_agg_lbl 14 `"Food Preparation and Serving Occupations"', add
label define occ_agg_lbl 15 `"Building and Grounds Cleaning and Maintenance Occupations"', add
label define occ_agg_lbl 16 `"Personal Care and Service Occupations"', add
label define occ_agg_lbl 17 `"Sales Occupations"', add
label define occ_agg_lbl 18 `"Office and Administrative Support Occupations"', add
label define occ_agg_lbl 19 `"Farming, Fishing, and Forestry Occupations"', add
label define occ_agg_lbl 20 `"Construction Trades"', add
label define occ_agg_lbl 21 `"Extraction Workers"', add
label define occ_agg_lbl 22 `"Installation, Maintenance, and Repair Workers"', add
label define occ_agg_lbl 23 `"Production Occupations"', add
label define occ_agg_lbl 24 `"Transportation and Material Moving Occupations"', add


gen ind_agg = .
replace ind_agg=1 if ind1950>=105 & ind1950<=126
replace ind_agg=2 if ind1950>=206 & ind1950<=236
replace ind_agg=3 if ind1950==246
replace ind_agg=4 if ind1950>=306 & ind1950<=399
replace ind_agg=5 if ind1950>=406 & ind1950<=499
replace ind_agg=6 if ind1950>=506 & ind1950<=598
replace ind_agg=7 if ind1950>=606 & ind1950<=699
replace ind_agg=8 if ind1950>=716 & ind1950<=746
replace ind_agg=9 if ind1950>=806 & ind1950<=817
replace ind_agg=10 if ind1950>=826 & ind1950<=849
replace ind_agg=11 if ind1950>=856 & ind1950<=859
replace ind_agg=12 if ind1950>=868 & ind1950<=899
replace ind_agg=13 if ind1950>=906 & ind1950<=936


label define ind_agg_lbl 1 `"Agriculture"'
label define ind_agg_lbl 2 `"Mining"', add
label define ind_agg_lbl 3 `"Construction"', add
label define ind_agg_lbl 4 `"Manufacturing Durables"', add
label define ind_agg_lbl 5 `"Manufacturing Non Durables"', add
label define ind_agg_lbl 6 `"Transportation"', add
label define ind_agg_lbl 7 `"Wholesale and Retail Trade"', add
label define ind_agg_lbl 8 `"Finance"', add
label define ind_agg_lbl 9 `"Business and Repair Services"', add
label define ind_agg_lbl 10 `"Personal Services"', add
label define ind_agg_lbl 11 `"Entertainment Services"', add
label define ind_agg_lbl 12 `"Professional Services"', add
label define ind_agg_lbl 13 `"Public Administration"', add


/***********************
** KEEP OBSERVATIONS IN THE 90s
***********************/

*keep if year>=1990 

/***********************
** FLAG FOR WAGE COMPUTATION
***********************/

gen wage_flag=1 //labor is a flag variable. labor=0 means that should not be considered for wage computations

/***********************
** DROP INVALID STATE AND NOT IN LABOR FORCE
***********************/

replace uhrswork=98 if  uhrswork==99 
replace hrswork=98 if  hrswork==99 


gen byte white=race==100 
gen byte black=race==200 
gen byte other=race!=100&race!=200 
assert white+black+other==1 


*select people who worked a positive amount of weeks;
replace wage_flag=0 if wkswork1==0 & year>1975 
replace wage_flag=0 if wkswork2==0 & year<=1975 
 
** eliminate people who do not have or report invalid wage income;
replace wage_flag=0 if (incwage==0 | incwage==999999) 

** eliminate self-employed
replace wage_flag=0 if classwkr<20 | classwkr>=30

**male dummy;
gen byte male=(sex==1)

replace age=90 if age>=90

*select people in working age;
drop if age<16
drop if age>66

replace wkswork1=0 if wkswork1==.

gen fullyear=0
replace fullyear=1 if (wkswork1>=40 & wkswork1<=52 & year>1975) | (wkswork2>=4 & wkswork2<=6 & year<=1975) & (fullpart==1)
replace wage_flag=0 if fullyear!=1 

/***********************
** COMPPUTING YEARS OF EDUCATION
***********************/

replace educ=. if educ==0 | educ==1 | educ==2 | educ==999 /*its distributed over all years*/
gen eduyears=.

replace eduyear=1 if educ==011
replace eduyear=2 if educ==012
replace eduyear=3 if educ==013
replace eduyear=4 if educ==014
replace eduyear=5 if educ==021
replace eduyear=6 if educ==022
replace eduyear=7 if educ==031
replace eduyear=8 if educ==032
replace eduyear=9 if educ==40
replace eduyear=10 if educ==50
replace eduyear=11 if educ==60
replace eduyears=12 if educ==72 | educ==73 /*"12th grade, diploma unclear" AND "High school diploma or equivalent"*/
replace eduyears=12+1 if educ==80
replace eduyears=12+2 if educ==90
replace eduyears=12+3 if educ==100
replace eduyears=12+4 if educ==110
replace eduyears=12+4 if educ==111 /*"bachelor degree"; might also take 5 years*/
replace eduyears=12+6 if (educ>111) & (educ<=125)
replace eduyears=. if year>1991
replace eduyears=4 if year>1991 & educ==10 /*grades 1, 2, 3, or 4*/
replace eduyears=6 if year>1991 & educ==20 /*grades 5 or 6*/
replace eduyears=8 if year>1991 & educ==30 /*grades 7 or 8*/
replace eduyears=9 if year>1991 & educ==40 /*grade 9*/
replace eduyears=10 if year>1991 & educ==50 /*grade 10*/
replace eduyears=11 if year>1991 & educ==60 /*grade 11*/
replace eduyears=12 if year>1991 & (educ==71 | educ==73) /*"12th grade, no diploma" AND "Hiehschool diploma or equivalent"|*/
replace eduyears=15 if year>1991 & educ==81 /*Some colleee but no deeree*/
replace eduyears=16 if year>1991 & educ==111 /*Bachelor's deeree */
replace eduyears=18 if year>1991 & (educ>111) & (educ<=125)/*Master's deeree AND Doctorate deeree*/

/***********************
** EDUCATION CATEGORIES
***********************/

gen byte school=1 if (educ<70) 
replace school=2 if (educ>=70)&(educ<=73) 
replace school=3 if (educ>=80) & (educ<110) 
replace school=4 if (educ>=110) & (educ<=111)  
replace school=5 if (educ>111) 

assert school!=. 

label define school 1 "HSD" 2 "HSG" 3 "SMC" 4 "CLG" 5 "GTC" 
label values school school 

drop if eduyears==.

/***********************
** POTENTIAL EXPERIENCE
***********************/

*gen exp=max(min(age-eduyears-6, age-17),0) 
gen exp=age-eduyears-5 

/***********************
** TOP CODING
***********************/

replace incwage=incwage*1.5 if incwage==50000 & year>=1968 & year<=1981 
replace incwage=incwage*1.5 if incwage==75000 & year>=1982 & year<=1984 
replace incwage=incwage*1.5 if incwage==99999 & year>=1985 & year<=1987
	
/***********************
** WAGE DEFINITION
***********************/

gen yearly=incwage*cpi
gen weekly=yearly/wkswork1 if year>1975
replace weekly=yearly/43.5 if year<=1975 & wkswork2==4
replace weekly=yearly/48.5 if year<=1975 & wkswork2==5
replace weekly=yearly/51 if year<=1975 & wkswork2==6
gen hourly=weekly/uhrswork

gen realhourwage=hourwage*cpi


/***********************
** LABOR FORCE PARTICIPATION
***********************/
	
gen employment=0 
replace employment=1 if empstat==10 | empstat==11 | empstat==12 
replace employment=2 if employment==1 & wage_flag==0
replace employment=3 if empstat==20 | empstat==21 | empstat==22
replace employment=4 if empstat>=30
replace employment=5 if empstat==13

label define employment 1 "L" 2 "L, part-time/self employed" 3 "U" 4 "NL" 5 "AF" 
label values employment employment 

tab wage_flag if year>1990 & year<2000

tab employment if year>1991 & year<1999

gen wage=ln(weekly)
count if year>1991 & year<1999 & employment==1
local count=r(N)

histogram wage if year>1991 & year<1999 & employment==1, title("Wage distribution, raw data")note("Obs: `count'")

histogram exp if year>1991 & year<1999 & employment==1, title("Experience distribution, raw data")note("Obs: `count'") discrete 

histogram age if year>1991 & year<1999 & employment==1, title("Age distribution, raw data")note("Obs: `count'") discrete 

drop wage


save "data/CPS_data.dta", replace
