
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"

** STATEFIP

import excel "source/HPI_AT_BDL_state.xlsx", sheet("state") cellrange(A7:I2149) firstrow clear //Data on housing prices come from the Freddie Mac (FM) repeat sales index

destring(HPIwith1990base), replace
destring(HPIwith2000base), replace
destring(FIPS), replace
destring(Year), replace
drop HPI //base 1975 dropped

ren FIPS statefip
ren Year year
gen ln_HPI=ln(HPIwith1990base)

keep if year==1980 | year==1990 | year==2000

keep ln_HPI statefip year HPIwith1990base
reshape wide ln_HPI HPIwith1990base, i(statefip) j(year)

gen ln_HPI_2000_1990=ln_HPI2000-ln_HPI1990
gen ln_HPI_1990_1980=ln_HPI1990-ln_HPI1980

//gen ln_HPI_2000_1990=(HPIwith1990base2000-HPIwith1990base1990)/HPIwith1990base1990
//gen ln_HPI_1990_1980=(HPIwith1990base1990-HPIwith1990base1980)/HPIwith1990base1980

label data "House Prices 1990 - 1999"
save "data/House_prices_statefip_long_run.dta", replace

** METAREA

tempfile tf_cbsa_crosswalk

import delimited "source/cbsatocountycrosswalk.csv", clear  //NBER Crosswalk
drop if cbsa==.
keep msaname msa cbsa* //cbsaold*
drop if msa < 80 //dropping states
*replace msa = int(msa/10)
sort msa
drop cbsaold cbsanameold
duplicates drop

drop if msa==1145 | msa ==2920 | msa == 5015 | msa==5660 | msa ==875 | msa ==3640 | msa == 7440 | msa ==470 | msa==1310 //dropping duplicates not captured in cbsa but captured in msa and puerto rico. 
drop if msa==5640 | msa ==3200 | msa == 8840 | msa==3800 | msa ==9270 | msa ==440 | msa == 6160 | msa ==7610 //dropping duplicates not captured in cbsa but captured in msa and puerto rico. 
drop if msaname=="BOSTON-WORCESTER-LAWRENCE-LOWELL-BROCKTON, MA-NH"
drop if cbsaname=="Providence-New Bedford-Fall River, RI-M" & msaname =="BOSTON-WORCESTER-LAWRENCE-LOWELL-BROCKTON, MA"
replace cbsa=int(cbsa/10)
//keep msa cbsa
duplicates drop
save `tf_cbsa_crosswalk'.dta, replace

import excel "source/HPI_AT_BDL_cbsa.xlsx", sheet("cbsa") cellrange(A7:H34939)  firstrow clear


destring(HPIwith1990base), replace
destring(HPIwith2000base), replace
destring(CBSA), replace
destring(Year), replace
drop HPI //base 1975 dropped
drop if CBSA < 100 // rural areas
ren CBSA cbsa

replace cbsa=35640 if cbsa==35620 //New york city
replace cbsa=33120 if cbsa==33100 | cbsa==33060 //Miami
replace cbsa=41880 if cbsa==41860 //San Francisco
replace cbsa=16970 if cbsa==16980 //Chicago
replace cbsa=14480 if cbsa==14460 //Boston
replace cbsa=42060 if cbsa==42200 //Santa Barbara
replace cbsa=47640 if cbsa==19820 //Detroit
replace cbsa=19120 if cbsa==19100 //Dallas

replace cbsa=int(cbsa/10)

merge m:1 cbsa  using `tf_cbsa_crosswalk'.dta, //nogen
browse if _merge==2

gen metarea=int(msa/10)
collapse (mean) HPIwith1990 HPIwith2000 , by(metarea Year)

ren Year year
gen ln_HPI=ln(HPIwith1990base)

keep if year==1980 | year==1990 | year==2000

keep ln_HPI metarea year HPIwith1990base
reshape wide ln_HPI HPIwith1990base, i(metarea) j(year)

gen ln_HPI_2000_1990=ln_HPI2000-ln_HPI1990
gen ln_HPI_1990_1980=ln_HPI1990-ln_HPI1980

//gen ln_HPI_2000_1990=(HPIwith1990base2000-HPIwith1990base1990)/HPIwith1990base1990
//gen ln_HPI_1990_1980=(HPIwith1990base1990-HPIwith1990base1980)/HPIwith1990base1980

label data "House Prices 1990 - 1999"
save "data/House_prices_metarea_long_run.dta", replace
