
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"
clear all

/***********************
** PROGRAMS
***********************/


cap program drop wages 
program define wages

syntax using/,  geo(string) 

tempfile t1 t2 t3 t4 t5 t6 t7 t8 t9 t10 t11 t12

/***********************
** LOAD DATA
***********************/

** low-skilled

use "`using'", clear

keep if age >=20
keep if school<3
keep if statefip<100
drop if bpl==20000
*drop if hispan==108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)*wtsupp
drop if wage==.
gen obs_wages_low_skilled=1

collapse (sum) wage wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

replace year=year-1  // Yearly wage refers to previous year

keep if year>1990 & year <2001

keep year `geo' wage obs

ren wage wage_low_skilled

gen time=year-1990
xi: reg wage_low_skilled i.time i.`geo'*time [aw=obs]
predict wage_hat, xb
replace wage_hat=wage_low_skilled-wage_hat

ren wage_hat wage_low_skilled_no_state_trend

keep year `geo' wage** obs

save `t1', replace

** high-skilled

use "`using'", clear

keep if age >= 22
keep if school>=3
keep if statefip<100
drop if bpl==20000
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)*wtsupp
drop if wage==.
gen obs_wages_high_skilled=1

collapse (sum) wage wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

replace year=year-1  // Yearly wage refers to previous year

keep if year>1990 & year <2001

keep year `geo' wage obs

ren wage wage_high_skilled

gen time=year-1990
xi: reg wage_high_skilled i.time i.`geo'*time [aw=obs]
predict wage_hat, xb
replace wage_hat=wage_high_skilled-wage_hat

ren wage_hat wage_high_skilled_no_state_trend

keep year `geo' wage** obs
save `t2', replace


** high school drop-outs

use "`using'", clear

keep if age >=18
keep if statefip<100
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

keep if school<2

replace wage=ln(weekly)*wtsupp
drop if wage==.
gen obs_wages_HSDO=1

collapse (sum) wage wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp
replace wage_hat=wage_hat/wtsupp

replace year=year-1  // Yearly wage refers to previous year

keep if year>1990 & year <2001

keep year `geo' wage wage_hat obs

ren wage wage_HSDO
ren wage_hat wage_HSDO_ind_controls

gen time=year-1990
xi: reg wage_HSDO i.time i.`geo'*time [aw=obs]
predict wage_hat, xb
replace wage_hat=wage_HSDO-wage_hat

ren wage_hat wage_HSDO_no_state_trend

keep year `geo' wage** obs

save `t3', replace

** high school graduates

use "`using'", clear

keep if age >= 18
keep if statefip<100
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

keep if school==2

replace wage=ln(weekly)*wtsupp
drop if wage==.
gen obs_wages_HSG=1

collapse (sum) wage wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp
replace wage_hat=wage_hat/wtsupp

replace year=year-1  // Yearly wage refers to previous year

keep if year>1990 & year <2001

keep year `geo' wage wage_hat obs

ren wage wage_HSG
ren wage_hat wage_HSG_ind_controls

gen time=year-1990
xi: reg wage_HSG i.time i.`geo'*time [aw=obs]
predict wage_hat, xb
replace wage_hat=wage_HSG-wage_hat

ren wage_hat wage_HSG_no_state_trend

keep year `geo' wage** obs

save `t4', replace

** low-skilled natives

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if bpl<20000
*drop if citizen==3
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp
drop if wage==.
drop wage
gen wage=wage_hat

gen obs_wages_low_skilled_natives=1

collapse (sum) wage wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

replace year=year-1  // Yearly wage refers to previous year

keep if year>1990 & year <2001

keep year `geo' wage obs

ren wage wage_low_skilled_nat

gen time=year-1990
xi: reg wage_low_skilled_nat i.time i.`geo'*time [aw=obs]
predict wage_hat, xb
replace wage_hat=wage_low_skilled_nat-wage_hat

ren wage_hat wage_low_skilled_nat_no_trend

keep year `geo' wage** obs

save `t5', replace

** low-skilled natives 1992-1994

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if hispan!=108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

replace year=year-1  // Yearly wage refers to previous year
replace year=1994 if (year==1993)|(year==1992)
keep if year>1993 & year <1996

gen obs_wages_low_skilled_imm=1

collapse (sum) wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

keep year `geo' wage obs

ren wage wage_low_skilled_9294

keep year `geo' wage** obs

save `t6', replace

** high-skilled natives 1992-1994

use "`using'", clear

keep if age >= 22
keep if school>=3
keep if statefip<100
keep if hispan!=108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

replace year=year-1  // Yearly wage refers to previous year
replace year=1994 if (year==1993)|(year==1992)
keep if year>1993 & year <1996

gen obs_wages_low_skilled_imm=1

collapse (sum) wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

keep year `geo' wage obs

ren wage wage_high_skilled_9294

keep year `geo' wage** obs

save `t7', replace

** low-skilled natives 1992-1995

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if hispan!=108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race  [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

replace year=year-1  // Yearly wage refers to previous year
replace year=1994 if (year==1993)|(year==1992)
replace year=1995 if (year==1996)
keep if year>1993 & year <1996

gen obs_wages_low_skilled_imm=1

collapse (sum) wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

keep year `geo' wage obs

ren wage wage_low_skilled_9296

keep year `geo' wage_low_skilled_

save `t8', replace

** low-skilled natives 1992-1995

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if hispan!=108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race  [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

replace year=year-1  // Yearly wage refers to previous year
replace year=1994 if (year==1993)|(year==1992)
replace year=1995 if (year==1996)|(year==1997)
keep if year>1993 & year <1996

gen obs_wages_low_skilled_imm=1

collapse (sum) wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

keep year `geo' wage obs

ren wage wage_low_skilled_9297

keep year `geo' wage_low_skilled_

save `t9', replace

** low-skilled natives 1992-1995

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if hispan!=108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

keep if year>1990 & year<2000
gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

replace year=year-1  // wage refers to previous year
replace year=1994 if (year==1993)|(year==1992)
replace year=1995 if (year==1996)|(year==1997) |(year==1998)
keep if year>1993 & year <1996

gen obs_wages_low_skilled_imm=1

collapse (sum) wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

keep year `geo' wage obs

ren wage wage_low_skilled_9298

keep year `geo' wage_low_skilled_

save `t10', replace

** low-skilled natives 1992-1995

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if hispan!=108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race if year>1990 & year<2000 [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

replace year=year-1  // wage refers to previous year
keep if year>1990 & year<2000
replace year=1994 if (year==1993)|(year==1992)
replace year=1995 if (year==1996)|(year==1997) |(year==1998) |(year==1999)
keep if year>1993 & year <1996

gen obs_wages_low_skilled_imm=1

collapse (sum) wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

keep year `geo' wage obs

ren wage wage_low_skilled_9299

keep year `geo' wage_low_skilled_

save `t11', replace

** low-skilled natives pre-years

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if hispan!=108
keep if employment==1
keep if wage_flag==1
drop if gq==2
*keep if sex==1
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen wage=ln(weekly)
drop if wage==.

gen time=year-1990
gen age2=age*age
xi: areg wage i.time i.`geo'*time age age2 i.sex i.race if year>1990 & year<2000 [pw=wtsupp], a(occ1990)
predict wage_hat, xb
replace wage_hat=(wage-wage_hat)*wtsupp

replace year=year-1  // wage refers to previous year
keep if year>1990 & year<2000
replace year=1994 if (year==1993)|(year==1992)
replace year=1995 if (year<1992)
keep if year>1993 & year <1996

gen obs_wages_low_skilled_imm=1

collapse (sum) wage_hat wtsupp obs, by(`geo' year)

replace wage=wage/wtsupp

keep year `geo' wage obs

ren wage wage_low_skilled_9193

keep year `geo' wage_low_skilled_

save `t12', replace


***** merging wage files ***

use `t1'
merge 1:1 year `geo' using `t2', nogen
merge 1:1 year `geo' using `t3', nogen
merge 1:1 year `geo' using `t4', nogen
merge 1:1 year `geo' using `t5', nogen
merge 1:1 year `geo' using `t6', nogen
merge 1:1 year `geo' using `t7', nogen
merge 1:1 year `geo' using `t8', nogen
merge 1:1 year `geo' using `t9', nogen
merge 1:1 year `geo' using `t10', nogen
merge 1:1 year `geo' using `t11', nogen
merge 1:1 year `geo' using `t12', nogen

keep if (year==1994)|(year==1995)


label var wage_low_skilled "Low-skilled wage"
label var wage_high_skilled "High-skilled wage"
label var wage_low_skilled_no_state_trend "Low-skilled wage, net of state-specific trends"
label var wage_high_skilled_no_state_trend "High-skilled wage, net of state-specific trends"
label var obs_wages_low_skilled "Number of observations used to compute low skilled wages"
label var obs_wages_high_skilled "Number of observations used to compute high skilled wages"
label var wage_HSDO "HSDO wage"
label var wage_HSG "HSG wage"
label var wage_HSDO_no_state_trend "HSDO wage, net of state-specific trends"
label var wage_HSG_no_state_trend "HSG wage, net of state-specific trends"
label var wage_low_skilled_nat "Native low-skilled wage"
label var wage_low_skilled_nat_no_trend "Native low-skilled wage, net of state-specific trends"
label var wage_low_skilled_9294 "Low-skilled wage, non-hispanic 1992-1994 as one year"
label var wage_low_skilled_9296 "Low-skilled wage, post year includes 96"
label var wage_low_skilled_9297 "Low-skilled wage, post year includes 97"
label var wage_low_skilled_9298 "Low-skilled wage, post year includes 98"
label var wage_low_skilled_9299 "Low-skilled wage, post year includes 99"
label var wage_low_skilled_9193 "Low-skilled wage, pre year"

label var wage_high_skilled_9294 "High-skilled wage, non-hispanic 1992-1994 as one year"

label var wage_HSG_ind_controls "HSG wage, individual controls"
label var wage_HSDO_ind_controls "HSDO wage, individual controls"

label var obs_wages_low_skilled_natives "Number of observations used to compute low skilled wages, natives"
label var obs_wages_low_skilled_imm "Number of observations used to compute low skilled wages, immigrants"
label var obs_wages_HSDO "Number of observations used to compute HSDO wages"
label var obs_wages_HSG "Number of observations used to compute HSG wages"

label data "Wages by skill, 1994-1995"
save "data/wages_1994-1995.dta", replace

end

cap program drop labor_supply 
program define labor_supply

syntax using/,  geo(string) 

tempfile t1 t2

** low-skilled

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
keep if employment==1
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp labor_low_skilled

keep year `geo' labor

save `t1', replace

** high-skilled

use "`using'", clear

keep if age >= 20
keep if school>=3
keep if statefip<100
keep if employment==1
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp labor_high_skilled

keep year `geo' labor

merge 1:1 year `geo' using `t1'
drop _merge

keep if (year==1994)|(year==1995)

label var labor_low_skilled "Low-skilled labor"
label var labor_high_skilled "High-skilled labor"

label data "Labor by skill, 1994-1995"
save "data/labor_1994-1995.dta", replace


end


cap program drop labor_supply_mexicans 
program define labor_supply_mexicans

syntax using/,  geo(string) 

tempfile t1 t2

** low-skilled

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
*keep if employment==1
drop if gq==2
keep if bpl==20000
gen obs_low_skilled_mexican=1 
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp obs_low_skilled_mexican, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp labor_low_skilled_mexican

keep year `geo' labor obs

save `t1', replace

** high-skilled

use "`using'", clear

keep if age >= 18
keep if school>=3
keep if statefip<100
*keep if employment==1
keep if bpl==20000
drop if gq==2
gen obs_high_skilled_mexican=1 
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp obs_high_skilled_mexican, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp labor_high_skilled_mexican

keep year `geo' labor obs

merge 1:1 year `geo' using `t1'
drop _merge



replace labor_low_skilled_mexican=0 if labor_low_skilled_mexican==.
replace labor_high_skilled_mexican=0 if labor_high_skilled_mexican==.

replace obs_low_skilled_mexican=0 if obs_low_skilled_mexican==.
replace obs_high_skilled_mexican=0 if obs_high_skilled_mexican==.

label var labor_low_skilled_mexican "Low-skilled population, Mexican"
label var labor_high_skilled_mexican "High-skilled population, Mexican"

label var obs_low_skilled_mexican "Obs Low-skilled population, Mexican"
label var obs_high_skilled_mexican "Obs High-skilled population, Mexican"

keep if (year>1993)&(year<2000)
label data "Mexican population by skill, 1994-1999"
save "data/pop_mexican_1994-1999.dta", replace

keep if (year==1994)|(year==1995)

label data "Mexican Labor by skill, 1994-1995"
save "data/labor_mexican_1994-1995.dta", replace


end


cap program drop population
program define population

syntax using/,  geo(string) 

tempfile t1 t2

** low-skilled

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp pop_low_skilled_native

keep year `geo' pop

save `t1', replace

** high-skilled

use "`using'", clear

keep if age >= 20
keep if school>=3
keep if statefip<100
*drop if bpl>=20000
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp pop_high_skilled_native

keep year `geo' pop

merge 1:1 year `geo' using `t1'
drop _merge

keep if (year==1994)|(year==1995)

label var pop_low_skilled "Low-skilled population"
label var pop_high_skilled "High-skilled population"

label data "Population by skill, 1994-1995"
save "data/population_1994-1995.dta", replace

end

cap program drop labor_supply_native
program define labor_supply_native

syntax using/,  geo(string) 

tempfile t1 t2

** low-skilled

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
drop if bpl>=20000
keep if employment==1
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp labor_low_skilled_native

keep year `geo' labor

save `t1', replace

** high-skilled

use "`using'", clear

keep if age >= 20
keep if school>=3
keep if statefip<100
drop if bpl>=20000
keep if employment==1
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

collapse (sum) wtsupp, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp labor_high_skilled_native

keep year `geo' labor

merge 1:1 year `geo' using `t1'
drop _merge

keep if (year==1994)|(year==1995)

label var labor_low_skilled "Low-skilled labor, native"
label var labor_high_skilled "High-skilled labor, native"

label data "Native Labor by skill, 1994-1995"
save "data/labor_native_1994-1995.dta", replace

end

cap program drop  
program define clean_house_prices

syntax ,  [geo(string)]

import excel "source/HPI_AT_BDL_state.xlsx", sheet("state") cellrange(A7:I2149) firstrow clear //Data on housing prices come from the Freddie Mac (FM) repeat sales index

destring(HPIwith1990base), replace
destring(HPIwith2000base), replace
destring(FIPS), replace
destring(Year), replace
drop HPI //base 1975 dropped

ren FIPS statefip
ren Year year

keep if year>=1990 & year<=2000

gen ln_HPI=ln(HPIwith1990base)
//gen ln_HPI=ln(HPIwith2000base)
xi: reg ln_HPI i.statefip*year i.year if year<1995
predict ln_HPI_res, res

two (connected HPIwith1990base year if statefip==6)(connected HPIwith1990base year if statefip==48)
two (connected ln_HPI_res year if statefip==6)(connected ln_HPI_res year if statefip==48)(connected ln_HPI_res year if statefip==36)
two (connected ln_HPI_res year if statefip==6)(connected ln_HPI_res year if statefip==48)(connected ln_HPI_res year if statefip==4)
two (connected HPIwith1990base year if statefip==6)(connected HPIwith1990base year if statefip==4)

ren HPIwith1990base HPI

keep statefip ln_HPI ln_HPI_res year

collapse (mean) ln_HPI ln_HPI_res,by(statefip year)

save "data/HPI_statefip_1990_20000", replace

keep if year>=1994 & year<=1995
*replace year=1995 if year>=1996 //simple way to check longer-time horizons
save "data/HPI_statefip", replace

forvalues i=1996(1)1999 {
use "data/HPI_statefip_1990_20000", replace

replace year=1995 if year>=1995 & year<=`i'
keep if year>=1994 & year<=1995
collapse (mean) ln_HPI ln_HPI_res,by(statefip year)
ren ln_HPI ln_HPI_1994`i'
ren ln_HPI_res ln_HPI_res_1994`i'
save "data/HPI_statefip_`i'", replace
}

use "data/HPI_statefip_1990_20000", replace

replace year=1995 if year==1992
keep if year>=1994 & year<=1995
collapse (mean) ln_HPI ln_HPI_res,by(statefip year)
ren ln_HPI ln_HPI_19941992
ren ln_HPI_res ln_HPI_res_19941992

save "data/HPI_statefip_1992", replace


**** metareas

tempfile tf_cbsa_crosswalk

import delimited "source/cbsatocountycrosswalk.csv", clear  //NBER Crosswalk
drop if cbsa==.
keep msaname msa cbsa* //cbsaold*
drop if msa < 80 //dropping states
*replace msa = int(msa/10)
sort msa
drop cbsaold cbsanameold
duplicates drop

drop if msa==1145 | msa ==2920 | msa == 5015 | msa==5660 | msa ==875 | msa ==3640 | msa == 7440 | msa ==470 | msa==1310 //dropping duplicates not captured in cbsa but captured in msa and puerto rico. 
drop if msa==5640 | msa ==3200 | msa == 8840 | msa==3800 | msa ==9270 | msa ==440 | msa == 6160 | msa ==7610 //dropping duplicates not captured in cbsa but captured in msa and puerto rico. 
drop if msaname=="BOSTON-WORCESTER-LAWRENCE-LOWELL-BROCKTON, MA-NH"
drop if cbsaname=="Providence-New Bedford-Fall River, RI-M" & msaname =="BOSTON-WORCESTER-LAWRENCE-LOWELL-BROCKTON, MA"
replace cbsa=int(cbsa/10)
//keep msa cbsa
duplicates drop
save `tf_cbsa_crosswalk'.dta, replace

import excel "source/HPI_AT_BDL_cbsa.xlsx", sheet("cbsa") cellrange(A7:H34939)  firstrow clear


destring(HPIwith1990base), replace
destring(HPIwith2000base), replace
destring(CBSA), replace
destring(Year), replace
drop HPI //base 1975 dropped
drop if CBSA < 100 // rural areas
ren CBSA cbsa

replace cbsa=35640 if cbsa==35620 //New york city
replace cbsa=33120 if cbsa==33100 | cbsa==33060 //Miami
replace cbsa=41880 if cbsa==41860 //San Francisco
replace cbsa=16970 if cbsa==16980 //Chicago
replace cbsa=14480 if cbsa==14460 //Boston
replace cbsa=42060 if cbsa==42200 //Santa Barbara
replace cbsa=47640 if cbsa==19820 //Detroit
replace cbsa=19120 if cbsa==19100 //Dallas

replace cbsa=int(cbsa/10)

merge m:1 cbsa  using `tf_cbsa_crosswalk'.dta, //nogen
browse if _merge==2

gen metarea=int(msa/10)
collapse (mean) HPIwith1990 HPIwith2000, by(metarea Year)

ren Year year

keep if year>=1990 & year<=2000
 
gen ln_HPI=ln(HPIwith1990base)
//gen ln_HPI=ln(HPIwith2000base)
xi: reg ln_HPI i.metarea*year  i.year if year<1995
predict ln_HPI_res, res

keep metarea ln_HPI ln_HPI_res year

collapse (mean) ln_HPI ln_HPI_res, by(metarea year)  //simple way to check longer-time horizons

save "data/HPI_metarea_1990_2000", replace

keep if year>=1994 & year<=1995
*replace year=1995 if year>=1996 //simple way to check longer-time horizons

save "data/HPI_metarea", replace

forvalues i=1996(1)1999 {
use "data/HPI_metarea_1990_2000", replace

replace year=1995 if year>=1995 & year<=`i'
keep if year>=1994 & year<=1995
collapse (mean) ln_HPI ln_HPI_res,by(metarea year)
ren ln_HPI ln_HPI_1994`i'
ren ln_HPI_res ln_HPI_res_1994`i'
save "data/HPI_metarea_`i'", replace
}

use "data/HPI_metarea_1990_2000", replace

replace year=1995 if year==1992
keep if year>=1994 & year<=1995
collapse (mean) ln_HPI ln_HPI_res,by(metarea year)
ren ln_HPI ln_HPI_19941992
ren ln_HPI_res ln_HPI_res_19941992

save "data/HPI_metarea_1992", replace



end

cap program drop clean_house_rental_prices 
program define clean_house_rental_prices

syntax ,  [geo(string)]

** STATEFIP

import excel "source/FMR_2Bed_1983_2018-1.xlsx", sheet("1999-1990") firstrow clear //Data for rents in MSAs is the Department of Housing and Urban Development’s (HUD) Fair Market Rent series (FMR). Source Saiz (2007)

forvalues i=90(1)99 {
rename fmr`i'_2 fmr2`i'
}

reshape long fmr fmr2 msa, i(fips2010) j(year)
destring (fmr2), replace
destring(state), replace
destring(pop2010), replace

//drop if msa=="10000" //dropping counties outside metropolitan areas

collapse (mean) fmr2 [aw=pop2010], by(state year) /// NOTE: ideally this collapse should be with 2000 or 1990 data

replace year=year+1900

ren fmr2 rent_40pct
replace rent_40pct=ln(rent_40pct)
ren state statefip

xi: reg rent_40pct i.statefip*year i.year  if year<1995
predict rent_40pct_res

save "data/Rental_statefip", replace

keep if year>=1994 & year<=1995
*replace year=1995 if year>=1996 //simple way to check longer-time horizons
save "data/Rental_statefip_1995", replace

forvalues i=1996(1)1999 {
use "data/Rental_statefip", replace

replace year=1995 if year>=1995 & year<=`i'
keep if year>=1994 & year<=1995

collapse (mean) rent_40pct rent_40pct_res,by(statefip year)

ren rent_40pct rent_40pct_1994`i'
ren rent_40pct_res rent_40pct_res_1994`i'

save "data/Rental_statefip_`i'", replace
}

use "data/Rental_statefip", replace

replace year=1995 if year<=1992
keep if year>=1994 & year<=1995
collapse (mean) rent_40pct rent_40pct_res ,by(statefip year)

ren rent_40pct rent_40pct_19941992
ren rent_40pct_res rent_40pct_res_19941992

save "data/Rental_statefip_1992", replace

** METAREA

import excel "source/FMR_2Bed_1983_2018-1.xlsx", sheet("1999-1990") firstrow clear //Data for rents in MSAs is the Department of Housing and Urban Development’s (HUD) Fair Market Rent series (FMR). Source Saiz (2007)

forvalues i=90(1)99 {
rename fmr`i'_2 fmr2`i'
}

reshape long fmr fmr2 msa, i(fips2010) j(year)
destring (fmr2), replace
destring(state), replace
destring(pop2010), replace

drop if msa=="10000" //dropping counties outside metropolitan areas

destring(msa), replace
replace msa=int(msa/10)

collapse (mean) fmr2 [aw=pop2010], by(msa year) /// NOTE: ideally this collapse should be with 2000 or 1990 data

replace year=year+1900

ren fmr2 rent_40pct
replace rent_40pct=ln(rent_40pct)
ren msa metarea

xi: reg rent_40pct i.metarea*year i.year  if year<1995
predict rent_40pct_res

save "data/Rental_metarea", replace

keep if year>=1994 & year<=1995
*replace year=1995 if year>=1996 //simple way to check longer-time horizons
save "data/Rental_metarea_1995", replace

forvalues i=1996(1)1999 {
use "data/Rental_metarea", replace

replace year=1995 if year>=1995 & year<=`i'
keep if year>=1994 & year<=1995

collapse (mean) rent_40pct rent_40pct_res,by(metarea year)

ren rent_40pct rent_40pct_1994`i'
ren rent_40pct_res rent_40pct_res_1994`i'

save "data/Rental_metarea_`i'", replace
}

use "data/Rental_metarea", replace

replace year=1995 if year<=1992
keep if year>=1994 & year<=1995
collapse (mean) rent_40pct rent_40pct_res ,by(metarea year)

ren rent_40pct rent_40pct_19941992
ren rent_40pct_res rent_40pct_res_19941992

save "data/Rental_metarea_1992", replace

end

cap program drop merge_data
program define merge_data

syntax ,  geo(string) 


use "data/wages_1994-1995.dta", clear
merge 1:1 `geo' year using "data/labor_1994-1995", nogen
merge 1:1 `geo' year using "data/labor_mexican_1994-1995", nogen
replace labor_high_skilled_mexican=0 if labor_high_skilled_mexican==.
replace labor_low_skilled_mexican=0 if labor_low_skilled_mexican==.
merge 1:1 `geo' year using "data/labor_native_1994-1995", nogen
merge 1:1 `geo' year using "data/population_1994-1995.dta", nogen
merge 1:1 `geo' year using "data/HPI_`geo'", nogen 
merge 1:1 `geo' year using "data/Rental_`geo'_1995", nogen

merge 1:1 `geo' year using "data/HPI_`geo'_1996", nogen 
merge 1:1 `geo' year using "data/HPI_`geo'_1997", nogen 
merge 1:1 `geo' year using "data/HPI_`geo'_1998", nogen 
merge 1:1 `geo' year using "data/HPI_`geo'_1999", nogen 
merge 1:1 `geo' year using "data/HPI_`geo'_1992", nogen 

merge 1:1 `geo' year using "data/Rental_`geo'_1996", nogen
merge 1:1 `geo' year using "data/Rental_`geo'_1997", nogen
merge 1:1 `geo' year using "data/Rental_`geo'_1998", nogen
merge 1:1 `geo' year using "data/Rental_`geo'_1999", nogen
merge 1:1 `geo' year using "data/Rental_`geo'_1992", nogen

if ("`geo'"=="metarea") {
preserve
crosswalk_metarea_statefip
restore
merge m:1 metarea using "data/crosswalk_metare_statefip.dta", nogen
drop if metarea==999
merge m:1 metarea using "data/crosswalk_metare_region.dta", nogen
}
else {
merge m:1 statefip using "data/crosswalk_state_region.dta", nogen
}

merge m:1 statefip year using "source/GDP_US_state_1991-1999.dta", keep(3) nogen
drop state_name exports code gdp_10 
gen ln_state_gdp=ln(gdp_state)
gen ln_labor_high_skilled=ln(labor_high_skilled)
gen ln_labor_low_skilled=ln(labor_low_skilled) 

gen ln_emp_high_skilled=ln(labor_high_skilled/pop_high_skilled)
gen ln_emp_low_skilled=ln(labor_low_skilled/pop_low_skilled)

drop gdp_state

label var ln_state_gdp "(log) State GDP"
label var share_exports "Share of exports to Mexico (over GDP)"
label var ln_exports "(log) State Exports to Mexico"
label var ln_labor_low_skilled "(log) low skilled labor"
label var ln_labor_high_skilled "(log) high skilled labor"

gen wage_gap=wage_high_skilled_9294-wage_low_skilled_9294
gen wage_gap_HSG_HSDO=wage_HSG-wage_HSDO
gen rental_HPI_gap=rent_40pct_res-ln_HPI_res


label var wage_gap "Wage Gap, High-Low"
label var wage_gap_HSG_HSDO "Wage Gap, HSG-HSDO"

gen ratio_high_low=ln(labor_high_skilled/labor_low_skilled)

label var ratio_high_low "Ratio high to low skilled"

merge m:1 `geo' using "data/Mexican_distribution_low_skilled_1980.dta", nogen keep(3)
merge m:1 `geo' using "data/Mexican_distribution_high_skilled_1980.dta", nogen keep(3)
merge m:1 `geo' using "data/Mexican_distribution_1980.dta", nogen keep(3)
merge m:1 `geo' using "data/Mexican_distribution_1990.dta", nogen 
merge m:1 `geo' using "data/Mexican_shock_census.dta", nogen keep(3)

/***********************
** EXTRA VARIABLES NEEDED
***********************/

drop if wage_low_skilled==.
bysort `geo': egen check=sum(1)
keep if check==2
drop check

gen republican=0
replace republican = 1 if statefip == 4 | statefip == 49 | statefip == 16 | statefip == 56 | statefip == 38 | statefip == 46 | statefip == 31 | statefip == 20 | statefip == 40 | statefip == 48 | statefip == 18 | statefip == 28 | statefip == 1 | statefip == 12 | statefip == 45 | statefip == 37 | statefip == 51

gen border=0
replace border = 1 if statefip == 6 | statefip == 48 | statefip == 4 | statefip == 35
tsset `geo' year

gen mexican_shock=mexican_flow_census/labor_low_skilled_native

gen share_mexicans_low_skilled=(labor_low_skilled_mexican)/labor_low_skilled
gen share_mexicans_high_skilled=(labor_high_skilled_mexican)/labor_high_skilled
gen share_mexicans_low_skilled_hat=(labor_low_skilled_mexican)/labor_low_skilled
replace share_mexicans_low_skilled_hat=(labor_low_skilled_mexican*1.05)/labor_low_skilled if year==1995

gen ratio_low_skilled=ln(labor_low_skilled/labor_high_skilled)

label var share_mexicans_low_skilled "Share of Mexicans, LS "
label var share_mexicans_low_skilled_hat "Share of Mexicans, LS (5% undercount in 95)"
label var share_mexicans_high_skilled "Share of Mexicans, HS"

gen obs_pop=obs_wages_low_skilled+obs_wages_high_skilled
label var obs_pop "Number of observations total population"

/***********************
** FIRST DIFFERENCING THE VARIABLES
***********************/

local varlist "ratio_low_skilled rent_40pct rent_40pct_res rental_HPI_gap ln_HPI ln_HPI_res wage_low_skilled wage_low_skilled_no_state_trend wage_high_skilled  wage_HSDO wage_HSDO_no_state_trend wage_HSG wage_HSG_no_state_trend wage_low_skilled_nat wage_low_skilled_nat_no_trend wage_low_skilled_9193 wage_low_skilled_9294 wage_low_skilled_9296 wage_low_skilled_9297 wage_low_skilled_9298 wage_low_skilled_9299 wage_high_skilled_9294 share_exports ln_exports ln_state_gdp ln_labor_high_skilled ln_labor_low_skilled wage_gap wage_gap_HSG_HSDO ratio_high_low share_mexicans_low_skilled share_mexicans_high_skilled ln_emp_low_skilled ln_emp_high_skilled"
foreach var of local varlist{
gen D`var'=D.`var'
}

gen Dwage_high_skilled_no_trend=D.wage_high_skilled_no_state_trend
gen Dshare_mexicans_LS_UC=D.share_mexicans_low_skilled_hat
gen Dwagegap = (wage_high_skilled_9294-wage_low_skilled_9294)
replace Dwagegap = D.Dwagegap

label var Dwage_low_skilled "$\Delta$ Wage low skilled"
label var Dwage_low_skilled_no_state_trend "$\Delta Wage low skilled no state trend"
label var Dwage_high_skilled "$\Delta$ Wage high skilled " 
label var Dwage_HSDO "$\Delta$ Wage HSDO"
label var Dwage_HSDO_no_state_trend "$\Delta$ Wage HSDO no state trend"
label var Dwage_HSG "$\Delta$ Wage HSG "
label var Dwage_HSG_no_state_trend "$\Delta$ Wage HSG no state trend" 
label var Dwage_low_skilled_nat "$\Delta$ Wage low skilled natives"
label var Dwage_low_skilled_nat_no_trend "$\Delta$ Wage low skilled natives no state trend"
label var Dwage_low_skilled_9294 "$\Delta$ Wage low skilled net of pers. characteristics and state trends"
label var Dwage_high_skilled_9294 "$\Delta$ Wage high skilled net of pers. characteristics and state trends"
label var Dshare_exports "$\Delta$ Share of exports to Mexico"
label var Dln_exports "$\Delta$ (log) exports to Mexico"
label var Dln_state_gdp "$\Delta$ (log) state GDP"
label var Dln_labor_high_skilled "$\Delta$ (log) high skilled labor"
label var Dln_labor_low_skilled "$\Delta$ (log) low skilled labor"
label var Dwage_gap "$\Delta$ High/low wage gap"
label var Dwage_gap_HSG_HSDO "$\Delta$ HSG/HSDO wage gap" 
label var Dratio_high_low "$\Delta$ Relative labor supply"
label var Dshare_mexicans_low_skilled "$\Delta$ Share of Mexicans, LS"
label var Dshare_mexicans_high_skilled "$\Delta$ Share of Mexicans, HS"
label var Dshare_mexicans_LS_UC "$\Delta$ Adj. Share of Mexicans, LS"
label var Dwage_high_skilled_no_trend "$\Delta$ Wage high skilled no state trend"
label var Dwagegap "$\Delta$ Wage Gap"
label var Dln_emp_low_skilled "$\Delta$ (ln) Employ. rate, LS"
label var Dln_emp_high_skilled "$\Delta$ (ln) Employ. rate, HS"
label var mexican_shock "$\Delta$ Share of Mexicans, LS"
label var Dln_HPI "$\Delta$ House Price Index" 
label var Dln_HPI_res "$\Delta$ House Price Index, detrended"

label data "Data set for the estimation of short-run effects on wages"
save "data/Estimation_data_set_short_run_wages.dta", replace

end


cap program drop population_9199
program define population_9199

syntax using/,  geo(string) 

/***********************
** TEMPORARY DATA FILES
***********************/

tempfile t1 t2

/***********************
** LOAD DATA
***********************/

** low-skilled

use "`using'", clear

keep if age >= 18 
keep if school<3
keep if statefip<100
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen obs_pop_low_skilled=1

collapse (sum) wtsupp obs, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp pop_low_skilled

keep year `geo' pop obs

save `t1', replace

** high-skilled

use "`using'", clear

keep if age >= 18
keep if school>=3
keep if statefip<100
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen obs_pop_high_skilled=1

collapse (sum) wtsupp obs, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp pop_high_skilled

keep year `geo' pop obs

merge 1:1 year `geo' using `t1'
drop _merge

keep if (year>=1991)
keep if (year<=1999)

label var pop_low_skilled "Low-skilled population"
label var pop_high_skilled "High-skilled population"

label var obs_pop_low_skilled "Number of observations low-skilled population"
label var obs_pop_high_skilled "Number of observations high-skilled population"

label data "Population by skill, 1991-1999"
save "data/population_1991-1999.dta", replace

end


cap program drop native_9199
program define native_9199

syntax using/,  geo(string) 


tempfile t1 t2

/***********************
** LOAD DATA
***********************/

** low-skilled

use "`using'", clear

keep if age >= 18
keep if school<3
keep if statefip<100
drop if bpl>=20000
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen obs_nat_low_skilled=1

collapse (sum) wtsupp obs, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp nat_low_skilled

keep year `geo' nat obs

save `t1', replace

** high-skilled

use "`using'", clear

keep if age >= 18
keep if school>=3
keep if statefip<100
drop if bpl>=20000
drop if gq==2
if ("`geo'"=="metarea") {
drop if metarea==9997 | metarea==9998
sort metarea
replace metarea = int(metarea/10) //Making metarea at 3 digit.
}

gen obs_nat_high_skilled=1

collapse (sum) wtsupp obs, by(`geo' year)

keep if year>1990 & year <2001
ren wtsupp nat_high_skilled

keep year `geo' nat obs

merge 1:1 year `geo' using `t1'
drop _merge

keep if (year>=1991)
keep if (year<=1999)

label var nat_low_skilled "Low-skilled population, native"
label var nat_high_skilled "High-skilled population, native"

label var obs_nat_low_skilled "Number of observations low-skilled population, native"
label var obs_nat_high_skilled "Number of observations high-skilled population, native"

label data "Native population by skill, 1991-1999"
save "data/natives_1991-1999.dta", replace

end


cap program drop merge_data_relocation
program define merge_data_relocation

syntax ,  geo(string) 

use "data/population_1991-1999.dta", clear
merge 1:1 `geo' year using "data/pop_mexican_1994-1999.dta", nogen
replace labor_high_skilled_mexican=0 if labor_high_skilled_mexican==.
replace labor_low_skilled_mexican=0 if labor_low_skilled_mexican==.
replace obs_low_skilled_mexican=0 if obs_low_skilled_mexican==.
replace obs_high_skilled_mexican=0 if obs_high_skilled_mexican==.
merge 1:1 `geo' year using "data/natives_1991-1999.dta", nogen


if ("`geo'"=="metarea") {
preserve
crosswalk_metarea_statefip
restore
merge m:1 metarea using "data/crosswalk_metare_statefip.dta", nogen
drop if metarea==999
}


if ("`geo'"=="metarea") {
merge m:1 statefip year using "data/GDP_US_state_1991-1999.dta", keep(3) nogen
}
else{
merge 1:1 statefip year using "data/GDP_US_state_1991-1999.dta", keep(3) nogen
}

merge m:1 `geo' using "data/Mexican_shock_census.dta", nogen


drop state_name exports code gdp_10 
gen ln_state_gdp=ln(gdp_state)
gen ln_pop_high_skilled=ln(pop_high_skilled)
gen ln_pop_low_skilled=ln(pop_low_skilled)
gen ln_mex_low_skilled=ln(labor_low_skilled_mexican)
drop gdp_state

label var ln_state_gdp "(log) State GDP"
label var share_exports "Share of exports to Mexico (over GDP)"
label var ln_exports "(log) State Exports to Mexico"
label var ln_pop_low_skilled "(log) low skilled labor"
label var ln_pop_high_skilled "(log) high skilled labor"


merge m:1 `geo' using "data/Mexican_distribution_low_skilled_1980.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_high_skilled_1980.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_1980.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_low_skilled_1990.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_high_skilled_1990.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_1990.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_low_skilled_2000.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_high_skilled_2000.dta", nogen
merge m:1 `geo' using "data/Mexican_distribution_2000.dta", nogen

gen Dshare_mexican_1990_2000=share_mexican_2000-share_mexican_1990

/***********************
** EXTRA VARIABLES NEEDED
***********************/

sort `geo' year

tsset `geo' year

gen y1994=0
replace y1994=1 if year==1994

gen atot_pop_1994=(pop_low_skilled+pop_high_skilled)
replace atot_pop_1994=atot_pop_1994*y1994
bysort statefip: egen tot_pop_1994=max(atot_pop_1994)
drop y1994 atot_pop_1994


tsset `geo' year

label var tot_pop_1994 "Total population in 1994"

*gen share_mexicans=(labor_low_skilled_mexican)/(pop_low_skilled+pop_high_skilled)
gen share_mexicans=(obs_low_skilled_mexican)/(obs_pop_low_skilled+obs_pop_high_skilled)

gen mexican_shock_aux=-100
replace mexican_shock_aux=mexican_flow_census/((obs_pop_low_skilled+obs_pop_high_skilled)*500) if year==1995
replace mexican_shock_aux=0 if mexican_shock_aux==. & year==1995
bysort `geo': egen mexican_shock=max(mexican_shock_aux)
drop mexican_shock_aux

label var share_mexicans "Share of Mexicans (over population)"

gen mexicans_low_skilled_growth=(obs_low_skilled_mexican-L.obs_low_skilled_mexican)/(L.obs_pop_low_skilled)
label var mexicans_low_skilled_growth "Mexicans growth rate"
gen mexicans_low_skilled_growth_2=(obs_low_skilled_mexican-L.obs_low_skilled_mexican)/(L2.obs_pop_low_skilled)
label var mexicans_low_skilled_growth "Mexicans growth rate, 2 years"
gen mexicans_low_skilled_growth_3=(obs_low_skilled_mexican-L3.obs_low_skilled_mexican)/(L3.obs_pop_low_skilled)
label var mexicans_low_skilled_growth "Mexicans growth rate, 3 years"
gen mexicans_low_skilled_growth_4=(obs_low_skilled_mexican-L4.obs_low_skilled_mexican)/(L4.obs_pop_low_skilled)
label var mexicans_low_skilled_growth "Mexicans growth rate, 4 years"

*gen share_low_skilled=pop_low_skilled/(pop_low_skilled+pop_high_skilled)
gen share_low_skilled=obs_pop_low_skilled/(obs_pop_low_skilled+obs_pop_high_skilled)
label var share_low_skilled "Share of low skilled"

gen ln_ratio_low_skilled=ln(pop_low_skilled/pop_high_skilled)
label var share_low_skilled "Share of low skilled"

*gen share_native_low_skilled=nat_low_skilled/(nat_low_skilled+nat_high_skilled)
gen share_native_low_skilled=obs_nat_low_skilled/(obs_nat_low_skilled+obs_nat_high_skilled)
label var share_native_low_skilled "Share of native low skilled"

gen obs_pop=obs_pop_low_skilled+obs_pop_high_skilled
label var obs_pop "Number of observations, population"

gen share_low_skilled_1980=(low_skilled_pop_1980)/(low_skilled_pop_1980+high_skilled_pop_1980)
label var share_low_skilled_1980 "Share of low skilled, 1980"

gen time=year-1990
xi: reg share_low_skilled i.`geo'*time if year> 1990 & year<1995 [aw=obs_pop]
predict share_low_skilled_detrend, res

/***********************
** FIRST DIFFERENCING THE VARIABLES
***********************/

local varlist "ln_ratio_low_skilled share_exports ln_exports ln_state_gdp share_mexicans share_low_skilled share_native_low_skilled share_low_skilled_detrend"
foreach var of local varlist{
gen D`var'=D.`var'
}

label var Dshare_exports "$\Delta$ Share of exports to Mexico (FD)"
label var Dln_exports "$\Delta$ (log) exports to Mexico"
label var Dln_state_gdp "$\Delta$ (log) state GDP"
label var Dshare_mexicans "$\Delta$ Share of Mexicans"
label var Dshare_mexican_1990_2000 "$\Delta$ Share of Mexicans, 1990-2000"
label var Dshare_low_skilled "$\Delta$ Share of low skilled"
label var Dshare_native_low_skilled "$\Delta$ Share LS, natives"
label var Dln_ratio_low_skilled "$\Delta$ (log) Skill Ratio"
gen Lmexicans_low_skilled_growth=L.mexicans_low_skilled_growth
label var Lmexicans_low_skilled_growth "Lagged Mexicans growth rate"

gen LDshare_mexicans = L.D.share_mexicans
label var LDshare_mexicans "Lagged share of Mexicans (FD)"

gen LDln_state_gdp  = L.D.ln_state_gdp
label var LDln_state_gdp "Lagged (log) state GDP (FD)"

gen LDln_exports  = L.D.ln_exports
label var LDln_exports "Lagged (log) exports to Mexico (FD)"

gen LDshare_native_low_skilled = L.Dshare_native_low_skilled
label var LDshare_native_low_skilled "Lagged share of native low skilled (FD)"
label var Dshare_native_low_skilled "Share of native low skilled (FD)"

gen LS_growth_rate=(obs_pop_low_skilled-L.obs_pop_low_skilled)/L.obs_pop_low_skilled
label var LS_growth_rate "Low skilled popuilation growth rate"
gen LS_growth_rate_2=(obs_pop_low_skilled-L2.obs_pop_low_skilled)/L2.obs_pop_low_skilled
label var LS_growth_rate "Low skilled popuilation growth rate, 2 years"
gen LS_growth_rate_3=(obs_pop_low_skilled-L3.obs_pop_low_skilled)/L3.obs_pop_low_skilled
label var LS_growth_rate "Low skilled popuilation growth rate, 3 years"
gen LS_growth_rate_4=(obs_pop_low_skilled-L4.obs_pop_low_skilled)/L4.obs_pop_low_skilled
label var LS_growth_rate "Low skilled popuilation growth rate, 4 years"

gen mexican_trend=share_mexican_low_skilled_2000-share_mexican_low_skilled_1990
label var mexican_trend "Change in Share LS Mexican 1990-2000"

gen LS_growth_rate_pre_aux=-100
replace LS_growth_rate_pre_aux=(1+LS_growth_rate_3)^(1/3)-1 if year==1994

bysort `geo': egen LS_growth_rate_pre=max(LS_growth_rate_pre_aux)

if "`geo'"=="metarea" {
merge m:1 metarea using "data/good_msa.dta", keep(3) nogen
}

tsset `geo' year

label data "Data set for the estimation of short-run effects on relocation"
save "data/Estimation_data_set_short_run_relocation.dta", replace



end


cap program drop crosswalk_metarea_statefip
program define crosswalk_metarea_statefip

use "data/CPS_data.dta", clear
keep if year>1990 & year<2000
keep metarea statefip wtsupp
replace metarea=int(metarea/10)

collapse (sum) wtsupp, by(metarea statefip)
bysort metarea: egen tot=sum(wtsup)
gen share=wtsupp/tot
keep statefip metarea share
bysort metarea: egen max_share=max(share)
keep if max_share==share
keep metarea statefip

save "data/crosswalk_metare_statefip.dta", replace

use "data/CPS_data.dta", clear
keep if year>1990 & year<2000
keep metarea region wtsupp
replace metarea=int(metarea/10)
collapse (sum) wtsupp, by(metarea region)
bysort metarea: egen tot=sum(wtsup)
gen share=wtsupp/tot
keep region metarea share
bysort metarea: egen max_share=max(share)
keep if max_share==share
keep metarea region

save "data/crosswalk_metare_region.dta", replace

use "data/CPS_data.dta", clear
keep statefip region
duplicates drop
save "data/crosswalk_state_region.dta", replace

end

cap program drop mexican_distribution
program define mexican_distribution

syntax ,  geo(string) 

foreach i in 1980 1990 2000{

/***********************
** low skilled
***********************/

use data/Immigration_`i'.dta, clear

keep if school<3
keep if age>=25 & age<=65

gen mexican=0
replace mexican=perwt if bpld==20000

gen nomexican=0
replace nomexican=perwt if bpld!=20000

gen obs_low_skilled_`i'=1

collapse (sum) nomexican mexican obs, by(`geo' year)
label var obs "Number of observations in `i', low skilled"

egen tot_mexican=sum(mexican)

gen low_skilled_pop_`i'=nomexican+mexican
gen low_skilled_mexican_`i'=mexican
label var low_skilled_pop_`i' "Low skilled population `i'"
label var low_skilled_mexican_`i' "Low skilled Mexicans `i'"

gen share_mexican_low_skilled_`i'=mexican/nomexican
label var share_mexican_low_skilled_`i' "Share of Mexicans in `i', LS"

gen mexican_distr_low_skilled_`i'=mexican/tot_mexican
label var mexican_distr_low_skilled_`i' "Geo. distr. of Mexicans in `i', LS"

keep `geo' year mexican_dist share_mex low_skilled_pop low_skilled_mexican obs
label data "Geographic distribution and share of Mexicans in `i' accros states, low skilled" 
save "data/Mexican_distribution_low_skilled_`i'.dta", replace

/***********************
** high skilled
***********************/

use data/Immigration_`i'.dta, clear
keep if school>=3
keep if age>=25 & age<=65

gen mexican=0
replace mexican=perwt if bpld==20000

gen nomexican=0
replace nomexican=perwt if bpld!=20000
gen obs_high_skilled_`i'=1

collapse (sum) nomexican mexican obs, by(`geo' year)
label var obs "Number of observations in `i', high skilled"

egen tot_mexican=sum(mexican)

gen high_skilled_pop_`i'=nomexican+mexican
gen high_skilled_mexican_`i'=mexican
label var high_skilled_pop_`i' "High skilled population `i'"
label var high_skilled_mexican_`i' "High skilled Mexicans `i'"

gen share_mexican_high_skilled_`i'=mexican/nomexican
label var share_mexican_high_skilled_`i' "Share of Mexicans in `i', HS"

gen mexican_distr_high_skilled_`i'=mexican/tot_mexican
label var mexican_distr_high_skilled_`i' "Geo. distr. of Mexicans in `i', HS"

keep `geo' year mexican_dist share_mex high_skilled_pop high_skilled_mexican obs
label data "Geographic distribution and share of Mexicans in `i' accros states, high skilled" 
save "data/Mexican_distribution_high_skilled_`i'.dta", replace

/***********************
** all
***********************/

use data/Immigration_`i'.dta, clear
keep if age>=25 & age<=65

gen mexican=0
replace mexican=perwt if bpld==20000

gen mexican_low_skilled=0
replace mexican_low_skilled=perwt if (bpld==20000)&(school<3)

gen nomexican=0
replace nomexican=perwt if bpld!=20000

gen obs_`i'=1

collapse (sum) nomexican mexican** obs, by(`geo' year)

label var obs "Number of observations in `i'"

egen tot_mexican=sum(mexican)


gen pop_`i'=nomexican+mexican
gen mexican_`i'=mexican
label var pop_`i' "Population `i'"
label var mexican_`i' "Mexicans `i'"

gen share_mexican_`i'=mexican/nomexican
label var share_mexican_`i' "Share of Mexicans in `i'"

gen low_skilled_share_mexican_`i'=mexican_low_skilled/nomexican
label var low_skilled_share_mexican_`i' "Share of low skilled Mexicans in `i'"

gen mexican_distribution_`i'=mexican/tot_mexican
label var mexican_distribution_`i' "Geo. distr. of Mexicans in `i'"

keep `geo' year mexican_dist share_mex low pop_`i' mexican_`i' obs
label data "Geographic distribution and share of Mexicans in `i' accros states" 
save "data/Mexican_distribution_`i'.dta", replace
}

end


cap program drop mexican_shock_census
program define mexican_shock_census

syntax ,  geo(string) 

tempfile tf_cps

use "data/CPS_data.dta", clear
keep if year==1994 | year==1995
gen mexican=0
replace mexican=wtsupp if bpl==20000
collapse (sum) mexican, by(year)
gen flow=mexica-mexican[_n-1]
keep flow
drop if flow==.
gen year=2000
save `tf_cps'.dta, replace

use data/Immigration_2000.dta, clear

keep if yrimmig==1995 
keep if school<3
keep if age>=23 & age<=70

gen mexican=0
replace mexican=perwt if bpld==20000

gen obs_low_skilled_`i'=1

if ("`geo'"=="metarea") {
replace migmet5 = int(migmet5/10) //Making migmet5 at 3 digit.
replace metarea=migmet5
}

if ("`geo'"=="statefip") {
replace statefip=migplac5
}


collapse (sum) mexican obs, by(`geo' year)
label var obs "Number of observations in `i', low skilled"

merge m:1 year using `tf_cps'.dta

egen tot_mexican=sum(mexican)

gen low_skilled_mexican_census=mexican
label var low_skilled_mexican_census "Low skilled Mexicans, census data"

gen mexican_distr_low_skilled_census=mexican/tot_mexican
label var mexican_distr_low_skilled_census "Geo. distr. of Mexicans in census 2000, LS"
gen mexican_flow_census=(mexican/tot_mexican)*flow

keep `geo' mexican_dist low_skilled_mexican obs mexican_flow_census
label data "Geographic distribution of Mexicans in 1995 from 2000 Census, low skilled" 
save "data/Mexican_shock_census.dta", replace

end


cap program drop good_msa
program define good_msa

** this program selects metropolitan areas with complete wage info. Keeps consistency with wage results into relocation results. 

use "data/Estimation_data_set_short_run_wages.dta", clear
drop if metarea==0
drop if metarea==.
drop if metarea==306 // This metropolitan area is too small and doesn't have a single observation of high skilled workers. I drop it from analysis. 
keep metarea
duplicates drop
save "data/good_msa.dta", replace

end

cap program drop comparison
program define comparison

use "data/CPS_data.dta", clear
keep if age >=20
//keep if school<3

keep if statefip<100
gen mexican=0
replace mexican=1 if bpl==20000

gen hispanic=0
replace hispanic=1 if hispan==108

*keep if wage_flag==1
drop if gq==2

keep if year==1994 | year==1995 | year==1996
gen female = 0
replace female = 1 if sex==2
replace black = 0 
replace black =1 if race == 200
gen married =0
replace married =1  if marst == 1

label var wtsupp "weight"
label var eduyears "Years of education"
label var occ_agg "Occupation code"
label var ind_agg "Industry code"
label var realhourwage "Real hourly wage"
drop if occ_agg==.
drop if ind_agg==.

iebaltab age femal black married mexican eduyears occ_agg ind_agg wtsupp if hispanic==1, grpvar(year) savetex(tables/comparison.tex) replace rowvarlabels  

iebaltab age femal black married mexican eduyears occ_agg ind_agg wtsupp if hispanic==0, grpvar(year) savetex(tables/comparison_natives.tex) replace rowvarlabels  
    
end

/***********************
** CALLS
***********************/

set matsize 800

local geography="statefip"
*local geography="metarea"


/************* WAGE and EMPLOYMENT ***************/

wages using "data/CPS_data.dta", geo(`geography')

labor_supply using "data/CPS_data.dta", geo(`geography')

labor_supply_mexicans using "data/CPS_data.dta", geo(`geography')

labor_supply_native using "data/CPS_data.dta", geo(`geography')

population using "data/CPS_data.dta", geo(`geography')

mexican_distribution, geo(`geography')

mexican_shock_census, geo(`geography')

clean_house_prices

clean_house_rental_prices 

merge_data, geo(`geography')



/************* INTERNAL MIGRATION ***************/


if "`geography'"=="metarea" {
good_msa
}

population_9199 using "data/CPS_data.dta", geo(`geography')

native_9199 using "data/CPS_data.dta", geo(`geography')

labor_supply_mexicans using "data/CPS_data.dta", geo(`geography')

mexican_distribution, geo(`geography')

mexican_shock_census, geo(`geography')

merge_data_relocation, geo(`geography')


/************* REGRESSIONS ***************/


do "do/REGRESSIONS_wages_short_run.do"
do "do/REGRESSIONS_relocation_short_run.do"


//comparison //This program creates a comparison table for the appendix. 
