
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** TEMPORARY DATA FILES
***********************/

tempfile t1_1990 t2_1990 t1_2000 t2_2000 t3_1990 t3_2000 t4_1990 t4_2000
foreach i in 1990 2000 {

/***********************
** LOAD DATA
***********************/

use "data/Immigration_`i'.dta", clear


/***********************
** Wages low skilled
***********************/

drop if age>65
keep if age >=20

keep if (wkswork1>=40)
keep if uhrswork>=35 
keep if uhrswork<=60 
keep if empstat==1 

keep if school<3

keep if weekly>0

bysort age: egen tot_mex=sum(perwt) if bpld==20000
bysort age: egen tot_nat=sum(perwt) if bpld<20000
bysort age: egen tot_pop=sum(perwt)

gen mex=.
replace mex=perwt*ln(weekly) if bpld==20000

gen nat=.
replace nat=perwt*ln(weekly) if bpld<20000

gen obs_`i'=1

collapse (sum) mex nat obs (mean) tot_**  , by(age)

label var obs_`i' "Number of observations in `i'"

replace mex=mex/tot_mex
replace nat=nat/tot_nat
rename mex mex_wage_low_skilled_`i'
rename nat nat_wage_low_skilled_`i'

label var mex_wage_low_skilled_`i' "Average Mexican low skilled wage in `i'"
label var nat_wage_low_skilled_`i' "Average native low skilled wage in `i'"

ren tot_mex mex_workers_low_skilled_`i'
ren tot_nat nat_workers_low_skilled_`i'
ren tot_pop workers_low_skilled_`i'

label var mex_workers_low_skilled_`i' "Mexican low skilled workers in `i'"
label var nat_workers_low_skilled_`i' "Native low skilled workers in `i'"
label var workers_low_skilled_`i' "Total low skilled workers in `i'"

keep mex_wage_low_skilled_`i' nat_wage_low_skilled_`i' workers_low_skilled_`i' mex_workers_low_skilled_`i' nat_workers_low_skilled_`i' age obs

sort age
save `t1_`i'', replace

/***********************
** LOAD DATA
***********************/

use "data/Immigration_`i'.dta", clear

/***********************
** Labor force
***********************/

drop if age>65
keep if school<3
keep if age >=20

bysort age: egen tot_mex=sum(perwt) if bpld==20000
bysort age: egen new_mexicans_low_skilled_`i'=sum(perwt) if bpld==20000 & yrimmig>1990
bysort age: egen tot_nat=sum(perwt) if bpld<20000
bysort age: egen tot_pop=sum(perwt)
bysort age: egen tot_emp=sum(perwt) if empstat==1
bysort age: egen tot_emp_nat=sum(perwt) if empstat==1 & bpld<20000

collapse (mean) tot_** new_mex, by(age)

ren tot_mex mex_low_skilled_`i'
ren tot_nat nat_low_skilled_`i'
ren tot_pop pop_low_skilled_`i'
ren tot_emp emp_low_skilled_`i'
ren tot_emp_nat emp_nat_low_skilled_`i'

label var mex_low_skilled_`i' "Mexican low skilled population"
label var nat_low_skilled_`i' "Native low skilled population"
label var pop_low_skilled_`i' "Total low skilled population"
label var new_mexicans_low_skilled_`i' "Mexican arrivals since 1990"
label var emp_low_skilled_`i' "Total low skilled employment'"
label var emp_nat_low_skilled_`i' "Native low skilled employment'"

keep pop_ nat_ mex_ age new emp**

sort age

save `t2_`i'', replace

}


/***********************
** LOAD DATA
***********************/

foreach i in 1990 2000 {

use "data/Immigration_`i'.dta", clear

/***********************
** Wages high skilled
***********************/

drop if age>65
keep if age >=25

keep if (wkswork1>=40)
keep if uhrswork>=35 
keep if uhrswork<=60 
keep if empstat==1 

keep if school>=3

keep if weekly>0

bysort age: egen tot_mex=sum(perwt) if bpld==20000
bysort age: egen tot_nat=sum(perwt) if bpld<20000
bysort age: egen tot_pop=sum(perwt)

gen mex=.
replace mex=perwt*ln(weekly) if bpld==20000

gen nat=.
replace nat=perwt*ln(weekly) if bpld<20000

gen obs_`i'=1

collapse (sum) mex nat obs (mean) tot_**  , by(age)

label var obs_`i' "Number of observations in `i'"

replace mex=mex/tot_mex
replace nat=nat/tot_nat
rename mex mex_wage_high_skilled_`i'
rename nat nat_wage_high_skilled_`i'

label var mex_wage_high_skilled_`i' "Average Mexican high skilled wage in `i'"
label var nat_wage_high_skilled_`i' "Average native high skilled wage in `i'"

ren tot_mex mex_workers_high_skilled_`i'
ren tot_nat nat_workers_high_skilled_`i'
ren tot_pop workers_high_skilled_`i'


keep mex_wage_high_skilled_`i' nat_wage_high_skilled_`i' age

sort age
save `t3_`i'', replace


/***********************
** LOAD DATA
***********************/

use "data/Immigration_`i'.dta", clear

/***********************
** Labor force
***********************/

drop if age>65
keep if school>=3
keep if age >=25

bysort age: egen tot_mex=sum(perwt) if bpld==20000
bysort age: egen new_mexicans_`i'=sum(perwt) if bpld==20000 & yrimmig>1990
bysort age: egen tot_nat=sum(perwt) if bpld<20000
bysort age: egen tot_pop=sum(perwt)
bysort age: egen tot_emp=sum(perwt) if empstat==1
bysort age: egen tot_emp_nat=sum(perwt) if empstat==1 & bpld<20000

collapse (mean) tot_** , by(age)

ren tot_mex mex_high_skilled_`i'
ren tot_nat nat_high_skilled_`i'
ren tot_pop pop_high_skilled_`i'
ren tot_emp emp_high_skilled_`i'
ren tot_emp_nat emp_nat_high_skilled_`i'

label var mex_high_skilled_`i' "Mexican high skilled population"
label var nat_high_skilled_`i' "Native high skilled population"
label var pop_high_skilled_`i' "Total high skilled population"
label var emp_high_skilled_`i' "Total high skilled employment'"
label var emp_nat_high_skilled_`i' "Native high skilled employment'"

keep pop_ nat_ mex_  age emp_high emp_nat

sort age

save `t4_`i'', replace
}

/***************************************************************************
** Age migration
****************************************************************************/

tempfile t5 t6 t7

/***********************
** LOAD DATA
***********************/

use "data/Immigration_2000.dta", clear

drop if age>65
keep if school<3
*keep if weekly>0
keep if yrimmig>1990
keep if age >=20

gen age_migration=age-(2000-yrimmig)
bysort age_migration: gen mex_age_migration=sum(perwt) if bpld==20000 
collapse (mean) mex_age_migration, by(age_migration)

egen tot_mex=sum(mex_age_migration)
gen share_mexicans_age_migration=mex_age_migration/tot_mex
label var share_mexicans_age_migration "Share of Mexicans that migrated at that age"

*keep if age>=18
ren age_migration age
keep age share

save `t5', replace

/*
clear
set obs 9
gen year=_n+1990
gen mexican_inflow_passel=.
replace mexican_inflow_passel=700000 if year==1999
replace mexican_inflow_passel=600000 if year==1998
replace mexican_inflow_passel=470000 if year==1997
replace mexican_inflow_passel=490000 if year==1996
replace mexican_inflow_passel=570000 if year==1995
replace mexican_inflow_passel=430000 if year==1994
replace mexican_inflow_passel=370000 if year==1993
replace mexican_inflow_passel=400000 if year==1992
replace mexican_inflow_passel=370000 if year==1991
*/

use "data/Immigration_1990.dta", replace
keep if bpld==20000
keep if school<3

collapse (sum) perwt, by(year)

ren perwt low_skilled_mexican

save `t7', replace

use "data/CPS_data.dta", replace
keep if bpl==20000
keep if school<3

collapse (sum) wtsupp, by(year)

keep if year>1990 & year <2001
ren wtsupp low_skilled_mexican

append using `t7'
tset year
tsfill
gen y1994=0
replace y1994=1 if year==1994
gen aux=low*y1994
egen max=max(aux)
replace low_skilled=max if (year==1991)|(year==1992)|(year==1993)
drop aux max y1994

gen inflow=low-L.low
replace inflow=inflow/4 if year==1991
replace inflow=L.inflow if year==1992
replace inflow=L2.inflow if year==1993
replace inflow=L3.inflow if year==1994

egen tot_inflow=sum(inflow)
replace inflow=inflow*2666640/tot_inflow //Adjusting to have the exact same inflows as when doing the cross-state comparisons. 
drop tot_inflow

append using `t5'

fillin year age

bysort year: egen mex_max=max(inflow)
bysort age: egen share_max=max(share)
keep if _fillin==1
keep age year mex_max share_max
gen mexicans_age_2000=mex_max*share_max
replace age=age-(year-2000)

collapse (sum) mexicans, by(age)

label var mexicans_age_2000 "Mexicans entering for each age cohort"

save `t5', replace

/***************************************************************************
** Merge data
****************************************************************************/

use `t1_1990', clear
merge 1:1 age using `t2_1990', nogen 
merge 1:1 age using `t1_2000', nogen 
merge 1:1 age using `t2_2000', nogen
merge 1:1 age using `t3_1990', nogen
merge 1:1 age using `t3_2000', nogen
merge 1:1 age using `t4_1990', nogen
merge 1:1 age using `t4_2000', nogen
merge 1:1 age using `t5', nogen


gen wage_low_skilled_2000_1990=nat_wage_low_skilled_2000-nat_wage_low_skilled_1990
gen wage_high_skilled_2000_1990=nat_wage_high_skilled_2000-nat_wage_high_skilled_1990
gen share_mexicans_2000_1990=(mex_low_skilled_2000-mex_low_skilled_1990)/(workers_low_skilled_1990)
gen share_mexpop_2000_1990=(mex_low_skilled_2000-mex_low_skilled_1990)/(pop_low_skilled_1990)
gen share_mexwork_2000_1990=(mex_workers_low_skilled_2000-mex_workers_low_skilled_1990)/(workers_low_skilled_1990)
gen rel_inflow_2000=(new_mexicans_low_skilled_2000)/(workers_low_skilled_1990)
egen tot_mex_2000=sum(mex_workers_low_skilled_2000)
egen tot_mex_1990=sum(mex_workers_low_skilled_1990)
gen pred_share_mexicans_2000_1990=mexicans_age_2000/(pop_low_skilled_1990)
gen ln_emp_low_nat_rate_2000_1990=ln(emp_nat_low_skilled_2000/nat_low_skilled_2000)-ln(emp_nat_low_skilled_1990/nat_low_skilled_1990)
gen ln_emp_high_nat_rate_2000_1990=ln(emp_nat_high_skilled_2000/nat_high_skilled_2000)-ln(emp_nat_high_skilled_1990/nat_high_skilled_1990)

drop tot**

label var pred_share_mexicans_2000_1990 "Predicted migrants for each cohort"
label var wage_low_skilled_2000_1990 "Change in native low skilled wages, 1990 - 2000"
label var wage_high_skilled_2000_1990 "Change in native high skilled wages, 1990 - 2000"
label var share_mexicans_2000_1990 "Relative Inflow of Mexican population (relative to low skilled workers), 1990 - 2000"
label var share_mexpop_2000_1990 "Relative Inflow of Mexican, 1990 - 2000"
label var share_mexwork_2000_1990 "Relative Inflow of Mexican workers, 1990 - 2000"
label var rel_inflow "Relative Inflow of Mexicans in 2000 Census"

label data "Low and skilled wages and population, 1990 - 2000 by age cohorts"
save data/est_long_run_age.dta, replace
