
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"



/***********************
** TEMPORARY DATA FILES
***********************/

tempfile t1_1990 t2_1990 t1_2000 t2_2000 t3_1990 t3_2000 t4_1990 t4_2000 t5

foreach i in 1990 2000 {

/***********************
** LOAD DATA
***********************/

use "data/Immigration_`i'.dta", clear


/***********************
** Wages low skilled
***********************/

drop if age>65
keep if age >=20


keep if (wkswork1>=40)
keep if uhrswork>=35 
keep if uhrswork<=60 
keep if empstat==1 

keep if school<3

keep if weekly>0

bysort metarea: egen tot_mex=sum(perwt) if bpld==20000
bysort metarea: egen tot_nat=sum(perwt) if bpld<20000
bysort metarea: egen tot_pop=sum(perwt)
bysort metarea: egen tot_nat_const=sum(perwt) if bpld<20000 & ind1990==60
bysort metarea: egen tot_const=sum(perwt) if ind1990==60

gen mex=.
replace mex=perwt*ln(weekly) if bpld==20000

gen nat=.
replace nat=perwt*ln(weekly) if bpld<20000

gen const_nat=.
replace const_nat=perwt*ln(weekly) if ind1990==60 & bpld<20000

gen const=.
replace const=perwt*ln(weekly) if ind1990==60 

gen obs_`i'=1

collapse (sum) mex nat obs const_nat const (mean) tot_**  , by(metarea)

label var obs_`i' "Number of observations in `i'"

replace mex=mex/tot_mex
replace nat=nat/tot_nat
replace const_nat=const_nat/tot_nat_cons
replace const=const/tot_cons

rename mex mex_wage_low_skilled_`i'
rename nat nat_wage_low_skilled_`i'
rename const_nat wage_low_skilled_nat_cons_`i'
rename const wage_low_skilled_cons_`i'

label var mex_wage_low_skilled_`i' "Average Mexican low skilled wage in `i'"
label var nat_wage_low_skilled_`i' "Average native low skilled wage in `i'"

ren tot_mex mex_workers_low_skilled_`i'
ren tot_nat nat_workers_low_skilled_`i'
ren tot_pop workers_low_skilled_`i'

label var mex_workers_low_skilled_`i' "Mexican low skilled workers in `i'"
label var nat_workers_low_skilled_`i' "Native low skilled workers in `i'"
label var workers_low_skilled_`i' "Total low skilled workers in `i'"

keep mex_wage_low_skilled_`i' nat_wage_low_skilled_`i' workers_low_skilled_`i' mex_workers_low_skilled_`i' nat_workers_low_skilled_`i' metarea obs wage_low_skilled_cons_`i' wage_low_skilled_nat_cons_`i'

sort metarea
save `t1_`i'', replace

/***********************
** LOAD DATA
***********************/

use "data/Immigration_`i'.dta", clear

/***********************
** Labor force
***********************/

drop if age>65
keep if school<3
keep if age >=20

bysort metarea: egen tot_mex=sum(perwt) if bpld==20000
bysort metarea: egen new_mexicans_`i'=sum(perwt) if bpld==20000 & yrimmig>1990
bysort metarea: egen tot_nat=sum(perwt) if bpld<20000
bysort metarea: egen tot_pop=sum(perwt)
bysort metarea: egen tot_emp=sum(perwt) if empstat==1
bysort metarea: egen tot_emp_nat=sum(perwt) if empstat==1 & bpld<20000
bysort metarea: egen tot_emp_const=sum(perwt) if empstat==1 & ind1990==60 
bysort metarea: egen tot_emp_nat_const=sum(perwt) if empstat==1 & ind1990==60 & bpld<20000
bysort metarea: egen tot_emp_mex_const=sum(perwt) if empstat==1 & ind1990==60 & bpld==20000
bysort metarea: egen tot_pop_const=sum(perwt) if ind1990==60

collapse (mean) tot_** new_mex, by(metarea)

ren tot_mex mex_low_skilled_`i'
ren tot_nat nat_low_skilled_`i'
ren tot_pop pop_low_skilled_`i'
ren tot_emp emp_low_skilled_`i'
ren tot_emp_nat emp_nat_low_skilled_`i'
ren tot_pop_const cons_low_skilled_`i'

ren tot_emp_const emp_const_ls_`i'
ren tot_emp_nat_const emp_const_ls_nat_`i'
ren tot_emp_mex_const emp_const_ls_mex_`i'

label var mex_low_skilled_`i' "Mexican low skilled population"
label var nat_low_skilled_`i' "Native low skilled population"
label var pop_low_skilled_`i' "Total low skilled population"
label var new_mexicans_`i' "Mexican arrivals since 1990"
label var emp_low_skilled_`i' "Total low skilled employment'"
label var emp_nat_low_skilled_`i' "Native low skilled employment'"

keep pop_ nat_ mex_  cons_ metarea new emp_low emp_nat emp_const_**

sort metarea

save `t2_`i'', replace
}


/***********************
** LOAD DATA
***********************/

foreach i in 1990 2000 {

use "data/Immigration_`i'.dta", clear

/***********************
** Wages high skilled
***********************/

drop if age>65
keep if age >=25

keep if (wkswork1>=40)
keep if uhrswork>=35 
keep if uhrswork<=60 
keep if empstat==1 

keep if school>=3

keep if weekly>0

bysort metarea: egen tot_mex=sum(perwt) if bpld==20000
bysort metarea: egen tot_nat=sum(perwt) if bpld<20000
bysort metarea: egen tot_pop=sum(perwt)
bysort metarea: egen tot_nat_cons=sum(perwt) if bpld<20000 & ind1990==60

gen mex=.
replace mex=perwt*ln(weekly) if bpld==20000

gen nat=.
replace nat=perwt*ln(weekly) if bpld<20000

gen const_nat=.
replace const_nat=perwt*ln(weekly) if ind1990==60 & bpld<20000


collapse (sum) mex nat cons (mean) tot_**  , by(metarea)

replace mex=mex/tot_mex
replace nat=nat/tot_nat
replace const_nat=const_nat/tot_nat_cons

rename mex mex_wage_high_skilled_`i'
rename nat nat_wage_high_skilled_`i'
rename const_nat wage_high_skilled_cons_`i'

label var mex_wage_high_skilled_`i' "Average Mexican high skilled wage in `i'"
label var nat_wage_high_skilled_`i' "Average native high skilled wage in `i'"

ren tot_mex mex_workers_high_skilled_`i'
ren tot_nat nat_workers_high_skilled_`i'
ren tot_pop workers_high_skilled_`i'


keep mex_wage_high_skilled_`i' nat_wage_high_skilled_`i' metarea wage_high_skilled_cons_`i'

sort metarea
save `t3_`i'', replace

/***********************
** LOAD DATA
***********************/

use "data/Immigration_`i'.dta", clear

/***********************
** Labor force
***********************/

drop if age>65
keep if school>=3
keep if age >=25

bysort metarea: egen tot_mex=sum(perwt) if bpld==20000
bysort metarea: egen new_mexicans_`i'=sum(perwt) if bpld==20000 & yrimmig>1990
bysort metarea: egen tot_nat=sum(perwt) if bpld<20000
bysort metarea: egen tot_pop=sum(perwt)
bysort metarea: egen tot_emp=sum(perwt) if empstat==1
bysort metarea: egen tot_emp_nat=sum(perwt) if empstat==1 & bpld<20000

collapse (mean) tot_** , by(metarea)

ren tot_mex mex_high_skilled_`i'
ren tot_nat nat_high_skilled_`i'
ren tot_pop pop_high_skilled_`i'
ren tot_emp emp_high_skilled_`i'
ren tot_emp_nat emp_nat_high_skilled_`i'

label var mex_high_skilled_`i' "Mexican high skilled population"
label var nat_high_skilled_`i' "Native high skilled population"
label var pop_high_skilled_`i' "Total high skilled population"
label var emp_high_skilled_`i' "Total high skilled employment'"
label var emp_nat_high_skilled_`i' "Native high skilled employment'"

keep pop_ nat_ mex_  metarea emp_high emp_nat

sort metarea

save `t4_`i'', replace


}

/***************************************************************************
** 1980
****************************************************************************/

/***********************
** LOAD DATA
***********************/

use "data/Immigration_1980.dta", clear

drop if age>65
keep if age >=20
keep if school<3
*keep if weekly>0

bysort metarea: egen tot_mex=sum(perwt) if bpld==20000
bysort metarea: egen tot_nat=sum(perwt) if bpld<20000
bysort metarea: egen tot_pop=sum(perwt) 
bysort metarea: egen mex_metarea_1980=sum(perwt) if bpld==20000 
bysort metarea: egen tot_emp_nat_const=sum(perwt) if ind1990==60 & bpld<20000
bysort metarea: egen tot_emp_mex_const=sum(perwt) if ind1990==60 & bpld==20000

egen tot_mex_1980=sum(perwt) if bpld==20000 


collapse (mean) tot_** mex_metarea_1980, by(metarea)

replace tot_mex=0 if tot_mex==.

gen share_mexican_low_skilled_1980=tot_mex/(tot_pop)

label var share_mexican_low_skilled_1980 "Share of Mexican low skilled population"

ren tot_pop pop_low_skilled_1980
ren tot_nat nat_low_skilled_1980
ren tot_mex mex_low_skilled_1980
ren tot_emp_nat_const nat_const_1980
ren tot_emp_mex_const mex_const_1980

label var mex_low_skilled_1980 "Mexican low skilled population in 1980"
label var nat_low_skilled_1980 "Native low skilled population in 1980"
label var pop_low_skilled_1980 "Total low skilled population in 1980"

sort metarea
save `t5', replace

/***************************************************************************
** Merge data
****************************************************************************/

use `t1_1990', clear
merge 1:1 metarea using `t2_1990', nogen 
merge 1:1 metarea using `t1_2000', nogen 
merge 1:1 metarea using `t2_2000', nogen
merge 1:1 metarea using `t3_1990', nogen
merge 1:1 metarea using `t3_2000', nogen
merge 1:1 metarea using `t4_1990', nogen
merge 1:1 metarea using `t4_2000', nogen
merge 1:1 metarea using `t5', nogen

replace emp_const_ls_mex_2000=0 if emp_const_ls_mex_2000==.
replace emp_const_ls_mex_1990=0 if emp_const_ls_mex_1990==.
replace mex_const_1980=0 if mex_const_1980==.
replace nat_const_1980=0 if nat_const_1980==.

replace mex_low_skilled_2000=0 if mex_low_skilled_2000==.
replace mex_low_skilled_1990=0 if mex_low_skilled_1990==.

gen wage_low_skilled_2000_1990=nat_wage_low_skilled_2000-nat_wage_low_skilled_1990
gen wage_low_skilled_cons_2000_1990=wage_low_skilled_cons_2000-wage_low_skilled_cons_1990

gen wage_ls_nat_cons_2000_1990=wage_low_skilled_nat_cons_2000-wage_low_skilled_nat_cons_1990

gen wage_high_skilled_2000_1990=nat_wage_high_skilled_2000-nat_wage_high_skilled_1990
gen wage_high_skilled_cons_2000_1990=wage_high_skilled_cons_2000-wage_high_skilled_cons_1990

gen share_mexicans_2000_1990=(mex_low_skilled_2000-mex_low_skilled_1990)/(workers_low_skilled_1990)

gen share_mexpop_2000_1990=(mex_low_skilled_2000-mex_low_skilled_1990)/(pop_low_skilled_1990)

gen share_mexwork_2000_1990=(mex_workers_low_skilled_2000-mex_workers_low_skilled_1990)/(workers_low_skilled_1990)
gen rel_inflow=(new_mexicans_2000)/(workers_low_skilled_1990)
gen ln_emp_low_nat_rate_2000_1990=ln(emp_nat_low_skilled_2000/nat_low_skilled_2000)-ln(emp_nat_low_skilled_1990/nat_low_skilled_1990)
gen ln_emp_high_nat_rate_2000_1990=ln(emp_nat_high_skilled_2000/nat_high_skilled_2000)-ln(emp_nat_high_skilled_1990/nat_high_skilled_1990)
gen emp_construction_nat_2000_1990=emp_const_ls_nat_2000/(workers_low_skilled_2000)-emp_const_ls_nat_1990/(workers_low_skilled_1990)

*gen emp_construction_2000_1990=(emp_const_ls_2000)/(workers_low_skilled_1990)-(emp_const_ls_1990)/(workers_low_skilled_2000)
gen emp_construction_2000_1990=cons_low_skilled_2000/(workers_low_skilled_2000)-cons_low_skilled_1990/(workers_low_skilled_1990)

gen emp_construction_mex_2000_1990=(emp_const_ls_mex_2000-emp_const_ls_mex_1990)/(cons_low_skilled_1990)

gen mex_const_share_1990=(emp_const_ls_mex_1990)/(emp_const_ls_1990)

gen mex_const_share_2000_1990=(emp_const_ls_mex_2000)/(emp_const_ls_2000)-(emp_const_ls_mex_1990)/(emp_const_ls_1990)

gen mex_const_share_1980=(mex_const_1980)/(nat_const_1980+mex_const_1980)

label var wage_low_skilled_2000_1990 "Change in native low skilled wages, 1990 - 2000"
label var wage_high_skilled_2000_1990 "Change in native high skilled wages, 1990 - 2000"
label var share_mexicans_2000_1990 "Relative Inflow of Mexican population (relative to low skilled workers), 1990 - 2000"
label var share_mexpop_2000_1990 "Relative Inflow of Mexican, 1990 - 2000"
label var share_mexwork_2000_1990 "Relative Inflow of Mexican workers, 1990 - 2000"
label var rel_inflow "Relative Inflow of low skilled Mexicans in 2000 Census"
label var wage_low_skilled_cons_2000_1990 "Change in low-skilled natives' wages in construction, 1990-2000"

label data "Low and skilled wages, 1990 - 2000"
save "data/est_long_run_metarea.dta", replace
