/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** LOAD DATA
***********************/
tempfile t1

use "source/GDP_US_state_1991-1999.dta", clear
keep if year==1991
keep gdp_state statefip
save `t1'.dta, replace


tempfile t2 t3
use "data/housing_supply_elasticity.dta", clear
gen metarea=int(pmsa/10)
collapse (mean) elasticity [aw=population], by(metarea)
save `t2'.dta, replace

use "source/Census_1990_rent.dta", clear
keep if year==1990
*use "source/Census_1980_rent.dta", clear //Using 1980 instead of 1990 makes virtually no difference
*keep if year==1980
merge m:1 metarea using "data/crosswalk_metare_statefip.dta", nogen
merge m:1 metarea using `t2'.dta, nogen

collapse (mean) elasticity [aw=perwt], by(statefip)

egen min_elast=min(elasticity)
replace elasticity=min_elast if elasticity==.

save `t3'.dta, replace

use "source/Census_1990_rent.dta", clear
*use "source/Census_1980_rent.dta", clear

replace rent=rent/4.3 //Making it weekly rent.  

/***********************
** KEEP EMPLOYED
***********************/

keep if empstat==1
keep if uhrswork>=35
gen low_skill=0
replace low_skill=1 if educ<7
keep if age<66
keep if classwkr==2
drop if wkswork1<40

gen workers=perwt
gen wage=ln(incwage/wkswork1)
drop if wage==.
drop if wage<0
replace wage=wage*perwt

gen mexican=perwt if bpl==200
replace rent=. if rent==0

collapse (sum) workers wage mexican (mean) rent [aw=perwt], by(year statefip low_skill)

replace wage=wage/workers

drop year 

reshape wide wage workers mexican rent, i(statefip) j(low_skill)

egen tot_mex1 = sum(mexican1)
egen tot_mex0 = sum(mexican0)
egen tot_nat1 = sum(workers1)
egen tot_nat0 = sum(workers0)
gen mexican_share_1990=(mexican0+mexican1)/(tot_mex0+tot_mex1)
gen share_1990=(tot_mex1)/(tot_nat1)

ren wage0 wage_h
ren wage1 wage_l

ren rent0 rent_h
ren rent1 rent_l


replace wage_l=exp(wage_l)
replace wage_h=exp(wage_h)

ren workers0 worker_h
ren workers1 worker_l

replace worker_h=worker_h/1000
replace worker_l=worker_l/1000
gen mexican_stock=(mexican1+mexican0)/1000

replace wage_l=wage_l/100
replace wage_h=wage_h/100


gen rent = (worker_l)/(worker_l+worker_h)*rent_l+ (worker_h)/(worker_l+worker_h)*rent_h

gen rel_wage_bill=(wage_l*worker_l)/(wage_h*worker_h)
gen tot_wage_bill=wage_l*worker_l+wage_h*worker_h

gen share_high_skill=worker_h/(worker_l+worker_h)

gen theta=1/(1+rel_wage_bill)

reg theta share_high_skill

merge m:1 statefip using `t1'.dta, nogen

gen y=(worker_h^theta)*(worker_l^(1-theta))

gen B=(tot_wage_bill/y)

drop y

merge 1:m statefip using "data/Estimation_data_set_short_run_wages.dta"  
keep if year==1995
drop year

replace rental=(exp(rental/4.33))

replace rent =rent/100 //making it like in wages

merge 1:1 statefip using `t3'.dta, nogen

gen epsilon=1/elasticity
//replace epsilon=0.58 // This option is to use the estimates in the paper instead of Saiz. 


keep statefip wage_h wage_l worker_h worker_l Dshare_mexicans_low_skilled mexican_shock rel_wage_bill tot_wage_bill share_high_skill theta B mexican_share_1990 rent epsilon mexican_stock

replace mexican_stock=. if mexican_stock==0 //The matlab program requires positve mexican stocks. only relevant for Rhode Island in 1980. 
egen min_mex=min(mexican_stock)
replace mexican_stock=min_mex if mexican_stock==.
drop min_mex

save "matlab/initial_distribution.dta", replace  //This is the input file for the matlab program
export delimited  using "matlab/initial_distribution.csv", replace  nolabel
/*export delimited  using "matlab/initial_distribution_1980.csv", replace  nolabel
save "matlab/initial_distribution_1980.dta", replace  


foreach var of varlist _all {
ren `var' `var'1990
}
ren statefip1990 statefip
merge 1:1 statefip using "$dropbox/matlab/initial_distribution_1980.dta"

twoway (scatter wage_l wage_l1990), scheme(s1mono) ytitle("Wage low-skilled 1980") xtitle("Wage low-skilled 1990")
graph export figures/wage_l_9080.png, replace

twoway (scatter theta theta1990), scheme(s1mono) ytitle("Theta 1980") xtitle("Theta 1990")
graph export figures/theta_9080.png, replace

twoway (scatter B B1990), scheme(s1mono) ytitle("TFP 1980") xtitle("TFP 1990")
graph export figures/TFP_9080.png, replace

twoway (scatter share_high_skill share_high_skill1990), scheme(s1mono)  ytitle("Share high-skilled 1980") xtitle("Share high-skilled 1990")
graph export figures/Share_high_skilled_9080.png, replace
*/


/***********************
** VARIABLE GENERATION
***********************/


/// matlab produces files to make these graphs

set more off

local varlistest "base nohouse"

foreach est of local varlistest {
local varlist "pop_rent value_rent pop_own value_own wage rent_gap pop_rentH value_rentH pop_ownH value_ownH wageH rent pop_rent_cft1 value_rent_cft1 pop_own_cft1 value_own_cft1 wage_cft1 rent_gap_cft1 pop_rentH_cft1 value_rentH_cft1 pop_ownH_cft1 value_ownH_cft1 wageH_cft1 rent_cft1 pop_rent_cft2 value_rent_cft2 pop_own_cft2 value_own_cft2 wage_cft2 rent_gap_cft2 pop_rentH_cft2 value_rentH_cft2 pop_ownH_cft2 value_ownH_cft2 wageH_cft2 rent_cft2 pop_rent_cft3 value_rent_cft3 pop_own_cft3 value_own_cft3 wage_cft3 rent_gap_cft3 pop_rentH_cft3 value_rentH_cft3 pop_ownH_cft3 value_ownH_cft3 wageH_cft3 rent_cft3 pop_rent_cft4 value_rent_cft4 pop_own_cft4 value_own_cft4 wage_cft4 rent_gap_cft4 pop_rentH_cft4 value_rentH_cft4 pop_ownH_cft4 value_ownH_cft4 wageH_cft4 rent_cft4 pop_rent_cft5 value_rent_cft5 pop_own_cft5 value_own_cft5 wage_cft5 rent_gap_cft5 pop_rentH_cft5 value_rentH_cft5 pop_ownH_cft5 value_ownH_cft5 wageH_cft5 rent_cft5"

		
foreach var of local varlist{
import delimited "matlab/simulated_data_evolution_`var'_`est'.csv", clear 
ren v1 statefip

reshape long v, i(statefip) j(period)
replace period=period-1
ren v `var'

save "data/simulated_data_evolution_`var'.dta", replace
}


use "data/simulated_data_evolution_pop_rent.dta", clear
merge 1:1 statefip period using "data/simulated_data_evolution_pop_own.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_rent.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_own.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_wage.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_pop_rentH.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_pop_ownH.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_rentH.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_ownH.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_wageH.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_rent_gap.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_rent.dta", nogen
forvalues i=1(1)6 {
merge 1:1 statefip period using "data/simulated_data_evolution_pop_rent_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_pop_own_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_rent_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_own_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_wage_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_pop_rentH_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_pop_ownH_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_rentH_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_value_ownH_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_wageH_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_rent_gap_cft`i'.dta", nogen
merge 1:1 statefip period using "data/simulated_data_evolution_rent_cft`i'.dta", nogen
}

gen share_low_skilled=pop_rent+pop_own/(pop_rent+pop_own+pop_rentH+pop_ownH)
gen year=period+1986


label var wage "Low skilled wage, CA"
label var wage_cft1 "Low skilled wage, CA, no shock"
two (line wage year if statefip==6 & period>=5 & period<14)(line wage_cft1 year if statefip==6 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono)  saving(figures/tmpg1.gph, replace)yscale(range(1 .92)) ylabel(1(0.02).92)

label var wage "Low skilled wage, NY"
label var wage_cft1 "Low skilled wage, NY, no shock"
two (line wage year if statefip==36 & period>=5 & period<14)(line wage_cft1 year if statefip==36 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono)  saving(figures/tmpg2.gph, replace)yscale(range(1 .98)) ylabel(1(0.01).98)

two (connected wage year if statefip==6 & period>=5 & period<14)(connected wage_cft1 year if statefip==6 & period>=5 & period<14)(connected wage year if statefip==36 & period>=5 & period<14)(connected wage_cft1 year if statefip==36 & period>=5 & period<14),  scheme(s1mono)

gr combine figures/tmpg1.gph figures/tmpg2.gph, col(1)scheme(s1mono)
graph export "figures/low_skilled_wages_model_cftl1`est'.eps", replace


label var wage_cft2 "Low skilled wage, CA"
label var wage_cft3 "Low skilled wage, CA, no shock"
two (line wage_cft2 year if statefip==6 & period>=5 & period<14)(line wage_cft3 year if statefip==6 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono)  saving(figures/tmpg1.gph, replace)yscale(range(1.04 .92)) ylabel(1.04(0.03).92)

label var wage_cft2 "Low skilled wage, NY"
label var wage_cft3 "Low skilled wage, NY, no shock"
two (line wage_cft2 year if statefip==36 & period>=5 & period<14)(line wage_cft3 year if statefip==36 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono)  saving(figures/tmpg2.gph, replace)yscale(range(1.02 .98)) ylabel(1.02(0.01).98)

gr combine figures/tmpg1.gph figures/tmpg2.gph, col(1)scheme(s1mono)
graph export "figures/low_skilled_wages_model_cftl2`est'.eps", replace

label var wage "Low skilled wage, AZ"
label var wage_cft4 "Low skilled wage, AZ, restr. law"
two (line wage year if statefip==4 & period>=1 & period<25)(line wage_cft4 year if statefip==4 & period>=1 & period<25,  lpattern(dash)),  scheme(s1mono)  saving(figures/tmpg1.gph, replace)yscale(range(1 .95)) ylabel(1(0.02).95)
graph export "figures/low_skilled_wages_model_AZ_cftl3`est'.eps", replace

label var wage_cft2 "Low skilled wage, AZ"
label var wage_cft5 "Low skilled wage, AZ, restr. law"
two (line wage_cft2 year if statefip==4 & period>=1 & period<25)(line wage_cft5 year if statefip==4 & period>=1 & period<25,  lpattern(dash)),  scheme(s1mono)  saving(figures/tmpg2.gph, replace)yscale(range(1.01 .98)) ylabel(1.01(0.01).98)
graph export "figures/low_skilled_wages_model_AZ2_cftl3`est'.eps", replace

gr combine figures/tmpg1.gph figures/tmpg2.gph, col(1)scheme(s1mono)
graph export "figures/low_skilled_wages_model_cftl3`est'.eps", replace

label var wage_cft3 "no shock"
label var wage_cft6 "no shock, reduced future migration"
two (line wage_cft3 year if statefip==6 & period>=5 & period<14)(line wage_cft6 year if statefip==6 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono) yscale(range(1.02 .98)) ylabel(1.02(0.01).98)
graph export "figures/reduced_future_migration.eps", replace


foreach var of local varlist{
ren `var' `var'_`est' 
}

save "data/wages_coutnerfactuals_`est'.dta", replace
}


use "data/wages_coutnerfactuals_base.dta", clear
merge 1:1 statefip year using "data/wages_coutnerfactuals_nohouse.dta"


label var wage_cft2_base "LS wage, CA"
label var wage_cft3_base "LS wage, CA, no shock "
label var wage_cft2_nohouse "LS wage, CA, nohouse"
label var wage_cft3_nohouse "LS wage, CA, no shock nohouse"

two (line wage_cft2_base year if statefip==6 & period>=5 & period<14)(line wage_cft3_base year if statefip==6 & period>=5 & period<14,  lpattern(dash)) ///
    (line wage_cft2_nohouse year if statefip==6 & period>=5 & period<14)(line wage_cft3_nohouse year if statefip==6 & period>=5 & period<14,  lpattern(dash)) ///
     ,  scheme(s1mono)legend(off) ytitle("Wage")  saving(figures/tmpg1.gph, replace)yscale(range(1.04 .92)) ylabel(1.04(0.03).92)

label var value_rent_cft2_base "Value CA"
label var value_rent_cft3_base "Value CA, no shock "
label var value_rent_cft2_nohouse "Value CA, no house"
label var value_rent_cft3_nohouse "Value CA, no shock no house"

two (line value_rent_cft2_base year if statefip==6 & period>=5 & period<14)(line value_rent_cft3_base year if statefip==6 & period>=5 & period<14,  lpattern(dash)) ///
    (line value_rent_cft2_nohouse year if statefip==6 & period>=5 & period<14)(line value_rent_cft3_nohouse year if statefip==6 & period>=5 & period<14,  lpattern(dash)) ///
     ,  scheme(s1mono)  ytitle("Value")  saving(figures/tmpg1.gph, replace)
graph export "figures/low_skilled_value_model_housing_CA.eps", replace

label var value_rent_cft2_base "Value NY"
label var value_rent_cft3_base "Value NY, no shock "
label var value_rent_cft2_nohouse "Value NY, no house"
label var value_rent_cft3_nohouse "Value NY, no shock no house"

two (line value_rent_cft2_base year if statefip==36 & period>=5 & period<14)(line value_rent_cft3_base year if statefip==36 & period>=5 & period<14,  lpattern(dash)) ///
    (line value_rent_cft2_nohouse year if statefip==36 & period>=5 & period<14)(line value_rent_cft3_nohouse year if statefip==36 & period>=5 & period<14,  lpattern(dash)) ///
     ,  scheme(s1mono)  ytitle("Value")  saving(figures/tmpg2.gph, replace)
graph export "figures/low_skilled_value_model_housing_NY.eps", replace

gr combine figures/tmpg1.gph figures/tmpg2.gph, col(1)scheme(s1mono)
graph export "figures/low_skilled_value_model_housing.eps", replace

label var rent_gap_base "Rental gap"
two (line rent_gap_base year if statefip==6 & period>=5 & period<14)(line rent_gap_base year if statefip==36 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono) legen(label(1 "California")label(2 "New York")) 

two (line rent_gap_base year if statefip==6 & period>=5 )(line rent_gap_cft1_base year if statefip==6 & period>=5 ,  lpattern(dash)),  scheme(s1mono) legen(label(1 "Rent Gap California")label(2 "Rent Gap California, no shock")) 

two (line rent_gap_base year if statefip==6 & period>=5 & period<14)(line rent_gap_cft1_base year if statefip==6 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono) legen(label(1 "Rent Gap California")label(2 "Rent Gap California, no shock")) yscale(range(1.04 .98)) ylabel(1.04(0.03).98)saving(figures/tmpg1.gph, replace)
graph export figures/rent_gap_model.png, replace
two (line rent_base year if statefip==6 & period>=5 & period<14)(line rent_cft1_base year if statefip==6 & period>=5 & period<14,  lpattern(dash)),  scheme(s1mono) legen(label(1 "Rent California")label(2 "Rent California, no shock")) yscale(range(1.02 .98)) ylabel(1.02(0.02).98)saving(figures/tmpg2.gph, replace)
graph export "figures/rent_model.eps", replace

gr combine figures/tmpg1.gph figures/tmpg2.gph, col(1)scheme(s1mono)
graph export "figures/rent_model_housing.eps", replace





