
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** LOAD DATA
***********************/

clear
 
use "data/CPS_data.dta", clear

/***********************
** Checking weights
***********************/

keep if school<3
keep if year<2001
keep if year>1989

/*
twoway (histogram wtsupp if bpl==20000 & year==1994, fcolor(green)xtitle("Supplement Weight, 1994") frac xlabel(5000 15000)) ///
       (histogram wtsupp if bpl!=20000 & year==1994, saving("$cps/graphs/gr1", replace) frac graphregion(color(white)) ///
	   color(none) lcolor(black)), legend(order(1 "Mexicans" 2 "Non-Mexicans" )) 
twoway (histogram wtsupp if bpl==20000 & year==1995, fcolor(green) xtitle("Supplement Weight, 1995") frac xlabel(5000 15000)) ///
       (histogram wtsupp if bpl!=20000 & year==1995, saving("$cps/graphs/gr2", replace) frac graphregion(color(white)) ///
	   color(none) lcolor(black)), legend(order(1 "Mexicans" 2 "Non-Mexicans" ))
twoway (histogram wtsupp if bpl==20000 & year==1996, fcolor(green) xtitle("Supplement Weight, 1996") frac xlabel(5000 15000)) ///
       (histogram wtsupp if bpl!=20000 & year==1996,  saving("$cps/graphs/gr3", replace)frac graphregion(color(white)) ///
	   color(none) lcolor(black)), legend(order(1 "Mexicans" 2 "Non-Mexicans" ))
twoway (histogram wtsupp if bpl==20000 & year==1997, fcolor(green) xtitle("Supplement Weight, 1997") frac  xlabel(5000 15000) ) ///
       (histogram wtsupp if bpl!=20000 & year==1997,  saving("$cps/graphs/gr4", replace)frac graphregion(color(white)) ///
	   color(none) lcolor(black)), legend(order(1 "Mexicans" 2 "Non-Mexicans" ))
	   	   
gr combine "$cps/graphs/gr1.gph" "$cps/graphs/gr2.gph" "$cps/graphs/gr3.gph" "$cps/graphs/gr4.gph", graphregion(color(white))
*/
		
twoway (histogram wtsupp if hispan==108 & year<=1995, fcolor(green)xtitle("Supplement Weight, 1990-1995") frac xlabel(5000 15000)) ///
       (histogram wtsupp if hispan!=108 & year<=1995, saving("figures/gr1", replace) frac graphregion(color(white)) ///
	color(none) lcolor(black)), legend(order(1 "Mexicans" 2 "Non-Mexicans" ))
graph export figures/cps_weigths_pre1995.png, replace

twoway (histogram wtsupp if hispan==108 & year>1995, fcolor(green)xtitle("Supplement Weight, 1996-2000") frac xlabel(5000 15000)) ///
       (histogram wtsupp if hispan!=108 & year>1995, saving("figures/gr2", replace) frac graphregion(color(white)) ///
	color(none) lcolor(black)), legend(order(1 "Mexicans" 2 "Non-Mexicans" ))
graph export figures/cps_weigths_post1995.png, replace


gr combine "figures/gr1.gph" "figures/gr2.gph", graphregion(color(white)) 

/***********************
** Building figures without taking into account the weights because of the change in weights in 1995 to 1996
***********************/

gen weights=wtsupp
replace wtsupp=1
gen mexican=0
replace mexican=wtsupp if bpl==20000
gen mexican1=0
replace mexican1=wtsupp if (hispan==108)

gen mexican_w_pre_1995=.
replace mexican_w_pre_1995=weights if (hispan==108) & year<1996
gen mexican_w_post_1995=.
replace mexican_w_post_1995=weights if (hispan==108) & year>=1996

gen overall_w=.
replace overall_w=weights

gen mexican_w=0
replace mexican_w=weights if (hispan==108) 

collapse (sum) mexican mexican1 wtsupp weights mexican2=mexican_w (mean) mexican_w** overall_w, by(year)

egen m_mexican_w_pre_1995=mean(mexican_w_pre_1995)
egen m_mexican_w_post_1995=mean(mexican_w_post_1995)
egen m_overall_w=mean(overall_w)

gen mexican_share=(mexican/wtsupp)*(m_mexican_w_post_1995/m_overall_w)
gen mexican1_share=mexican1/wtsupp*(m_mexican_w_post_1995/m_overall_w)
gen mexican2_share=mexican2/weight


keep if year>=1990 & year<=2000
replace mexican_share=. if year<1994
replace mexican2_share=. if year<1994
replace mexican=. if year<1994
replace mexican1=. if year==1995
label variable mexican_share "Share of LS Mex (bpl)"
label variable mexican1_share "Share of LS Mex (hispan)"
label variable mexican2_share "Share of LS Mex (wtsupp bpl)"
label variable mexican "LS Mex (obs in bpl)"
label variable mexican1 "LS Mex (obs in hispan)"
label variable year "year"
two (connected mexican1_share year, xline(1994))(connected mexican1 year, xline(1994)yaxis(2)), scheme(s1mono)

two (connected mexican1_share year, xline(1994))(connected mexican_share year, xline(1994)) (connected mexican2_share year, xline(1994)), scheme(s1mono)
graph export figures/f1a.eps, replace

reg mexican1_share year if year<1995
predict mexican1_share_hat, xb
label variable mexican1_share_hat "Predicted Share of LS Mex"
label variable mexican1_share "Share of LS Mex"

two (connected mexican1_share year, xline(1994))(line mexican1_share_hat year, xline(1994)lpattern(dash)) , scheme(s1mono)
graph export figures/f1b.eps, replace


tsset year
gen mexican_levels1=mexican1_share*weight*m_mexican_w_pre_1995/m_overall_w
gen mexican_levels2=mexican1_share*weight*m_mexican_w_post_1995/m_overall_w
gen mexican_inflow1=mexican_levels1-L.mexican_levels1
gen mexican_inflow2=mexican_levels2-L.mexican_levels2
gen mexican_inflow3=mexican2-L.mexican2

two (connected weight year, xline(1994)), scheme(s1mono)

drop if year>1999
two (connected mexican_inflow2 year, xline(1994)), scheme(s1mono) ytitle("Net Mexican Inflows, est. from CPS data")
graph export figures/f1c.eps, replace


/***********************
** Passel Data
***********************/

gen mexican_inflow_passel=.
replace mexican_inflow_passel=700000 if year==1999
replace mexican_inflow_passel=600000 if year==1998
replace mexican_inflow_passel=470000 if year==1997
replace mexican_inflow_passel=490000 if year==1996
replace mexican_inflow_passel=570000 if year==1995
replace mexican_inflow_passel=430000 if year==1994
replace mexican_inflow_passel=370000 if year==1993
replace mexican_inflow_passel=400000 if year==1992
replace mexican_inflow_passel=370000 if year==1991

label var mexican_inflow_passel "Mexican Inflow, Passel et al (2012)"
label var mexican_inflow2 "Mexican Inflow, est. CPS"
two (connected mexican_inflow_passel year, xline(1994))(connected mexican_inflow2 year if year<2000, xline(1994)), scheme(s1mono)
two (connected mexican_inflow_passel year, xline(1994)), scheme(s1mono)
graph export graphs/Passel.png, replace

egen average_inflows=mean(mexican_inflow2)
reg mexican_inflow2 year if year!=1995 &year!=1996 
predict predicted_inflows, xb

egen average_inflows2=mean(mexican_inflow2) if year!=1995 &year!=1996



/***********************
** Sumary stats table
***********************/

clear
 
use "data/CPS_data.dta", clear


keep if school<3
keep if year<1997
keep if year>1993

gen mexican1=0
replace mexican1=1 if (hispan==108)

gen mexican=0
replace mexican=1 if bpl==20000
replace mexican=. if year==1993

gen pre_1995=1 if year<1995
replace pre_1995=0 if year>=1995
gen maried=1 if marst==1
replace maried=0 if marst!=1
gen fulltime=0
replace fulltime=1 if employment==1
gen salary_worker=0
replace salary_worker=1 if classwkr==21
keep if age>17
ttable2 age male white maried fulltime eduyears salary_worker wage_flag occ_agg ind_agg mexican1 wtsupp if mexican==0, by(pre_1995)
ttable2 age male white maried fulltime eduyears salary_worker wage_flag occ_agg ind_agg mexican1 wtsupp if mexican==1, by(pre_1995) 

logout, save(tables/Tab_comparison_nat) excel replace: ttable2 age male white maried fulltime eduyears salary_worker wage_flag occ_agg ind_agg mexican1 wtsupp if mexican==0, by(pre_1995)
logout, save(tables/Tab_comparison) excel replace: ttable2 age male white maried fulltime eduyears salary_worker wage_flag occ_agg ind_agg mexican1 wtsupp if mexican==1, by(pre_1995)

