
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"

 
/***********************
** LOAD DATA
***********************/

clear
set more off


tempfile t2

import excel "source/FMR_2Bed_1983_2018-1.xlsx", sheet("2009-2000") firstrow clear //Data for rents in MSAs is the Department of Housing and Urban Development’s (HUD) Fair Market Rent series (FMR). Source Saiz (2007)

forvalues i=0(1)9 {
rename fmr0`i'_2 fmr20`i'
}

reshape long fmr0 fmr20 msa, i(fips2010) j(year)
destring (fmr2), replace
destring(state), replace
destring(pop2010), replace


collapse (mean) fmr20 [aw=pop2010], by(state year) 

replace year=year+2000

ren fmr2 rent_40pct
replace rent_40pct=ln(rent_40pct)
ren state statefip

save `t2'.dta, replace
use "data/Rental_statefip", replace
drop rent_40pct_res
append using `t2'.dta
sort statefip year

xi: reg rent_40pct year i.statefip*year i.year  if year<1995
predict rent_40pct_res, 
replace rent_40pct=rent_40pct-rent_40pct_res

save "data/Rental_statefip_1991_2009", replace

tempfile t1

use "data/CPS_data.dta", clear
keep if year>=1990 & year<=2000

keep if age >= 18 
keep if statefip<100
drop if gq==2
gen obs=1
collapse (sum) wtsupp obs, by(statefip year)
ren wtsupp pop
keep year statefip pop obs

save `t1'.dta, replace

use "data/Rental_statefip_1991_2009", replace
merge 1:1 statefip year using "data/HPI_statefip_1990_20000", keep(3) nogen
merge 1:1 statefip year using `t1'.dta, keep(3) nogen
drop _I**

gen rent_gap=rent_40pct-ln_HPI_res
hist rent_gap

gen high_imm_state=0
replace high_imm_state=1 if statefip==6 | statefip==4 |statefip==35 | statefip==32 | statefip==48 | statefip==49 //California (6), Arizona(4), Texas(48), Nevada(32), New Mexico (35).  



keep if year>=1991 & year<=2000

xi: reg rent_gap i.year*high_imm_state high_imm_state i.high_imm_state*year [aw=obs],  
xtset statefip year 
xi: xtgls rent_gap i.year*high_imm_state high_imm_state i.high_imm_state*year [aw=obs], panels(correlated)  


gen b=.
gen se=.

local varlist "1992 1993 1994 1995 1996 1997 1998 1999 2000"
local aux=2

replace b=0 in  1
replace se=0 in 1
gen year_graph=.

foreach var of local varlist{
if (`var'!=1994) {
replace b=_b[_IyeaXhig_`var'] in `aux'
replace se=_se[_IyeaXhig_`var'] in `aux'
replace year_graph=`var' in `aux'
local aux=`aux'+1
}
else{
replace b=0 in `aux'
replace se=. in `aux'
replace year_graph=`var' in `aux'
local aux=`aux'+1
}
}



keep b se year_graph

*gen upper_confidence_interval=b+1.63*se
*gen lower_confidence_interval=b-1.63*se
gen upper_confidence_interval=b+1.96*se
gen lower_confidence_interval=b-1.96*se
drop if b==.

keep if year<2001
sort year

label variable b "Differencial effect on HIS"
label variable lower_confidence_interval "90% CI"
label variable upper_confidence_interval "90% CI"
label variable year "Differencial effect on HIS"


two (connected b year if year>=1990& year <=2000, xline(1994) )(rcap upper_confidence_interval lower_confidence_interval year if year>=1990 & year <=2000, lpattern(dash)lcolor(grey)  yline(0)), scheme(s1mono) legend(off)
graph export "figures/f3b.eps", replace




