
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"

 
/***********************
** LOAD DATA
***********************/

clear
set more off
use "data/CPS_data.dta", clear

replace year=year-1

gen high_imm_state=0
replace high_imm_state=1 if statefip==6 | statefip==4 |statefip==35 | statefip==32 | statefip==48 | statefip==49 //California (6), Arizona(4), Texas(48), Nevada(32), New Mexico (35).  



keep if year>=1990 & year<=2000


gen wage=ln(weekly)

gen age2=age*age
gen age3=age2*age

egen cluster_group=group(year metarea)

char year[omit] 1994 


gen time=year-1990

gen urban=1
replace urban=0 if metarea>=9997

gen married=0
replace married=1 if marst<3


xi: areg wage i.year*high_imm_state high_imm_state i.high_imm_state*year age age2 age3 i.school*age i.school*age2 i.school*age3 i.race i.marst i.urban if school<3 & wage_flag==1 & employment==1 & year<=2000 [pw=wtsupp], robust a(occ1990) cluster(metarea)


gen b=.
gen se=.

local varlist "1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000"
local aux=2

replace b=0 in  1
replace se=0 in 1
gen year_graph=.

foreach var of local varlist{
if (`var'!=1994) {
replace b=_b[_IyeaXhig_`var'] in `aux'
replace se=_se[_IyeaXhig_`var'] in `aux'
replace year_graph=`var' in `aux'
local aux=`aux'+1
}
else{
replace b=0 in `aux'
replace se=. in `aux'
replace year_graph=`var' in `aux'
local aux=`aux'+1
}
}

xi:areg wage i.year age age2 age3 i.race i.marst i.school*age i.school*age2 i.school*age3 if school<3 & wage_flag==1 & employment==1 & high_imm==1 &year<=2000 [pw=wtsupp], a(occ1990) robust //cluster(metarea)

local varlist "1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000"
local aux=2


gen b1=.
gen se1=.

replace b1=0 in  1
replace se1=0 in 1

foreach var of local varlist{
if (`var'!=1994) {
replace b1=_b[_Iyear_`var'] in `aux'
replace se1=_se[_Iyear_`var'] in `aux'
local aux=`aux'+1
}
else{
replace b1=0 in `aux'
replace se1=. in `aux'
local aux=`aux'+1
}
}


keep b b1 se se1 year_graph

gen upper_confidence_interval=b+1.63*se
gen lower_confidence_interval=b-1.63*se
gen upper_confidence_interval1=b1+1.63*se1
gen lower_confidence_interval1=b1-1.63*se1
drop if b==.

keep if year<2001
sort year

label variable b "Differencial effect on HIS"
label variable lower_confidence_interval "90% CI"
label variable upper_confidence_interval "90% CI"
label variable lower_confidence_interval1 "90% CI"
label variable upper_confidence_interval1 "90% CI"
label variable year "Differencial effect on HIS"


two (connected b year if year>=1990& year <=2000, xline(1994) )(rcap upper_confidence_interval lower_confidence_interval year if year>=1990 & year <=2000, lpattern(dash)lcolor(grey)  yline(0)), scheme(s1mono) legend(off)
graph export "figures/f3a.eps", replace



