
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** LOAD DATA
***********************/

use data/Estimation_data_set_short_run_wages.dta, clear
count 

if `r(N)'==328 {
global metro="_msa"
drop if metarea==0
drop if metarea==.
drop if metarea==306 // This metropolitan area is too small and doesn't have a single observation of high skilled workers. I drop it from analysis. 
gen b=.
gen se=.
ivreg2  Dwage_low_skilled_9193 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 1
replace se=_se[mexican_shock] in 1
replace b=0 in 2
replace se=0 in 2
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 3
replace se=_se[mexican_shock] in 3
ivreg2  Dwage_low_skilled_9296 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 4
replace se=_se[mexican_shock] in 4
ivreg2  Dwage_low_skilled_9297 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 5
replace se=_se[mexican_shock] in 5
ivreg2  Dwage_low_skilled_9298 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 6
replace se=_se[mexican_shock] in 6
ivreg2  Dwage_low_skilled_9299 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 7
replace se=_se[mexican_shock] in 7

gen post_periods=_n+1992
replace b=-.469 if post_period==1999
replace se=.221 if post_period==1999

replace post_period=1991 if post_period==1993

gen se_u=b+1.96*se
gen se_l=b-1.96*se
label var post "Computed local labor demand elasticity, using various numbers of years"

two (connected b post_periods if post_periods<2000)(rcap se_u se_l post_periods if post_periods<2000 & post_periods>1990, lcolor(greay) lpattern(dash)), scheme(s1mono)legend(off)

keep b post_periods se_u se_l
keep if post_periods<2000
ren b b_msa
ren se_u se_u_msa
ren se_l se_l_msa
save "data/cumulative_msa.dta", replace
listtex using "tables/elasticities_metro.tex", replace

}
else {
global metro=""

gen b=.
gen se=.
ivreg2  Dwage_low_skilled_9193 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 1
replace se=_se[mexican_shock] in 1
replace b=0 in 2
replace se=0 in 2
ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 3
replace se=_se[Dshare_mexicans_low_skilled] in 3
ivreg2  Dwage_low_skilled_9296 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 4
replace se=_se[Dshare_mexicans_low_skilled] in 4
ivreg2  Dwage_low_skilled_9297 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 5
replace se=_se[Dshare_mexicans_low_skilled] in 5
ivreg2  Dwage_low_skilled_9298 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 6
replace se=_se[Dshare_mexicans_low_skilled] in 6
ivreg2  Dwage_low_skilled_9299 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 7
replace se=_se[Dshare_mexicans_low_skilled] in 7

gen post_periods=_n+1992
replace b=-.355 if post_period==1999
replace se=.169 if post_period==1999
replace post_period=1991 if post_period==1993

gen se_u=b+se
gen se_l=b-se
label var post "Computed local labor demand elasticity, using various numbers of post years"

two (connected b post_periods if post_periods<2000)(rcap se_u se_l post_periods if post_periods<2000 & post_periods>1990, lcolor(greay) lpattern(dash)), scheme(s1mono)legend(off)
graph export figures/cumulative_effect.png, replace

keep b post_periods se_u se_l
keep if post_periods<2000
save "data/cumulative_state.dta", replace
listtex using "tables/elasticities_state.tex", replace

}

use "data/cumulative_state.dta", clear
merge 1:1 post_periods using "data/cumulative_msa.dta", nogen

two (connected b post_periods if post_periods<2000)(rcap se_u se_l post_periods if post_periods<2000 & post_periods>1990, lcolor(greay) lpattern(dash))(connected b_msa post_periods if post_periods<2000)(rcap se_u_msa se_l_msa post_periods if post_periods<2000 & post_periods>1994, lcolor(greay) lpattern(dash)), scheme(s1mono) ///
legend(label(1 "Inv. Labor demand elasticity, state") label(2 "se") label(3 "Inv. Labor demand elasticity, msa") label(4 "se"))

