
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"




/***********************
** LOAD DATA
***********************/

use data/Estimation_data_set_short_run_wages.dta, clear
count 

if `r(N)'==328 {
global metro="_msa"
drop if metarea==0
drop if metarea==.
drop if metarea==306 // This metropolitan area is too small and doesn't have a single observation of high skilled workers. I drop it from analysis. 

forvalues i=1996(1)1999 {
gen rental_HPI_gap_1994`i'=rent_40pct_res_1994`i'-ln_HPI_res_1994`i'
gen Drental_HPI_gap_1994`i'=D.rental_HPI_gap_1994`i'
}
gen rental_HPI_gap_19941992=rent_40pct_res_19941992-ln_HPI_res_19941992
gen Drental_HPI_gap_19941992=D.rental_HPI_gap_19941992


gen b=.
gen se=.


ivreg2  Drental_HPI_gap_19941992 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 1
replace se=_se[mexican_shock] in 1
replace b=0 in 2
replace se=0 in 2
ivreg2  Drental_HPI_gap (mexican_shock=share_mexican_low_skilled_1980)   Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 3
replace se=_se[mexican_shock] in 3
ivreg2  Drental_HPI_gap_19941996 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 4
replace se=_se[mexican_shock] in 4
ivreg2  Drental_HPI_gap_19941997 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 5
replace se=_se[mexican_shock] in 5
ivreg2  Drental_HPI_gap_19941998 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 6
replace se=_se[mexican_shock] in 6
ivreg2  Drental_HPI_gap_19941999 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[mexican_shock] in 7
replace se=_se[mexican_shock] in 7

gen post_periods=_n+1992
replace b=-.469 if post_period==1999
replace se=.221 if post_period==1999

replace post_period=1991 if post_period==1993

gen se_u=b+1.96*se
gen se_l=b-1.96*se
label var post "Computed local labor demand elasticity, using various numbers of years"

two (connected b post_periods if post_periods<2000)(rcap se_u se_l post_periods if post_periods<2000 & post_periods>1990, lcolor(greay) lpattern(dash)), scheme(s1mono)legend(off)
keep b post_periods se_u se_l
keep if post_periods<2000
ren b b_msa
ren se_u se_u_msa
ren se_l se_l_msa
save "data/cumulative_msa_housing.dta", replace
listtex using "tables/elasticities_metro_housing.tex", replace

}
else {
global metro=""

forvalues i=1996(1)1999 {
gen rental_HPI_gap_1994`i'=rent_40pct_res_1994`i'-ln_HPI_res_1994`i'
gen Drental_HPI_gap_1994`i'=D.rental_HPI_gap_1994`i'
}
gen rental_HPI_gap_19941992=rent_40pct_res_19941992-ln_HPI_res_19941992
gen Drental_HPI_gap_19941992=D.rental_HPI_gap_19941992

gen b=.
gen se=.
ivreg2  Drental_HPI_gap_19941992 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 1
replace se=_se[Dshare_mexicans_low_skilled] in 1
replace b=0 in 2
replace se=0 in 2
ivreg2  Drental_HPI_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 3
replace se=_se[Dshare_mexicans_low_skilled] in 3
ivreg2  Drental_HPI_gap_19941996 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 4
replace se=_se[Dshare_mexicans_low_skilled] in 4
ivreg2  Drental_HPI_gap_19941997 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 5
replace se=_se[Dshare_mexicans_low_skilled] in 5
ivreg2  Drental_HPI_gap_19941998 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 6
replace se=_se[Dshare_mexicans_low_skilled] in 6
ivreg2  Drental_HPI_gap_19941999 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust  
replace b=_b[Dshare_mexicans_low_skilled] in 7
replace se=_se[Dshare_mexicans_low_skilled] in 7

gen post_periods=_n+1992
replace post_period=1992 if post_period==1993

gen se_u=b+1.96*se
gen se_l=b-1.96*se
label var post "Computed local labor demand elasticity, using various numbers of post years"

two (connected b post_periods if post_periods<2000)(rcap se_u se_l post_periods if post_periods<2000 & post_periods>1990, lcolor(greay) lpattern(dash)), scheme(s1mono)legend(off)

keep b post_periods se_u se_l
keep if post_periods<2000
save "data/cumulative_state_housing.dta", replace
listtex using "tables/elasticities_state_housing.tex", replace

}

