
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** LOAD DATA
***********************/

use "data/Estimation_data_set_short_run_relocation.dta", clear
count

if `r(N)'==1467 {
global metro="_msa"
drop if metarea==0
drop if metarea==.
drop if metarea==306 // This metropolitan area is too small and doesn't have a single observation of high skilled workers. I drop it from analysis. 
}
else {
global metro=""
}

/***********************
** TABLE: Table_relocation
***********************/

reg share_low_skilled share_mexicans if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", replace drop(_I** time) nocons tex(frag) label addtext("First Differenced","no") ctitle("Share", "LS, 1995", "OLS") nonotes  noaster
ivreg2 share_low_skilled (share_mexicans=share_mexican_1980) if year==1995 [aw=obs_pop], robust first cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","no")  ctitle("Share", "LS, 1995","IV") e(widstat) nonotes noaster

reg Dshare_low_skilled Dshare_mexicans if year==1995  [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons tex(frag) label  addtext("First Differenced","yes") ctitle("Share", "LS, 1995","OLS") nonotes noaster
reg Dshare_low_skilled Dshare_mexicans Dln_exports Dln_state_gdp if year==1995  [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "LS, 1995","OLS")  nonotes noaster
ivreg2 Dshare_low_skilled (Dshare_mexicans=share_mexican_1980) Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes") ctitle("Share", "LS, 1995","IV") e(widstat) nonotes noaster
ivreg2 Dshare_low_skilled (Dshare_mexicans=share_mexican_1980) Dshare_native_low_skilled Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes") ctitle("Share", "LS, 1995","IV") e(widstat) nonotes noaster

reg Dshare_low_skilled LDshare_mexicans  if year==1996  [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "LS, 1996","OLS") nonotes noaster
reg Dshare_low_skilled LDshare_mexicans LDln_exports LDln_state_gdp if year==1996 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons  tex(frag) label addtext("First Differenced","yes") ctitle("Share", "LS, 1996","OLS")  nonotes noaster
ivreg2 Dshare_low_skilled (LDshare_mexicans=share_mexican_1980) LDln_state_gdp LDln_exports if year==1996 [aw=L.obs_pop], first cluster(statefip) robust
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes") ctitle("Share", "LS, 1996","IV") e(widstat)  nonotes noaster
ivreg2 Dshare_low_skilled (LDshare_mexicans=share_mexican_1980) LDshare_native_low_skilled LDln_state_gdp LDln_exports if year==1996 [aw=L.obs_pop],  cluster(statefip) robust
outreg2 using "tables/Table_relocation$metro.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes") ctitle("Share", "LS, 1996","IV") e(widstat)  nonotes noaster

/***********************
** TABLE: Table_relocation_native
***********************/


reg share_native_low_skilled share_mexicans if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation_native$metro.txt", replace drop(_I** time) nocons tex(frag) label addtext("First Differenced","no") ctitle("Share", "native LS, 1995", "OLS") nonotes  noaster
ivreg2 share_native_low_skilled (share_mexicans=share_mexican_1980) if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation_native$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","no") ctitle("Share", "native LS, 1995","IV") e(widstat) nonotes noaster

reg Dshare_native_low_skilled Dshare_mexicans if year==1995  [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation_native$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "native LS, 1995","OLS") nonotes noaster
reg Dshare_native_low_skilled Dshare_mexicans Dln_exports Dln_state_gdp if year==1995  [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation_native$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "native LS, 1995","OLS")  nonotes noaster
ivreg2 Dshare_native_low_skilled (Dshare_mexicans=share_mexican_1980) Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip)  
outreg2 using "tables/Table_relocation_native$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "native LS, 1995","IV")  e(widstat) nonotes noaster

reg Dshare_native_low_skilled LDshare_mexicans if year==1996  [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation_native$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "native LS, 1996","OLS") nonotes noaster
reg Dshare_native_low_skilled LDshare_mexicans LDln_exports LDln_state_gdp if year==1996 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_relocation_native$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "native LS, 1996","OLS")  nonotes noaster
ivreg2 Dshare_native_low_skilled (LDshare_mexicans=share_mexican_1980) LDln_state_gdp LDln_exports if year==1996 [aw=obs_pop], robust cluster(statefip)  
outreg2 using "tables/Table_relocation_native$metro.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes") ctitle("Share", "native LS, 1996","IV") e(widstat)  nonotes noaster

/*

/***********************
** TABLE: growth rates
***********************/

erase "tables/Table_relocation_growth.txt"
reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 if year==1995 [aw=obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth.txt", drop(_I** time) nocons tex(frag) label ctitle("Mexicans", "growth rate, 1995", "OLS") nonotes  noaster
reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 if year==1996 [aw=L.obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth.txt", drop(_I** time) nocons tex(frag) label ctitle("Mexicans", "growth rate, 1996", "OLS") nonotes  noaster
reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 LDln_state_gdp LDln_exports if year==1996 [aw=L.obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth.txt", drop(_I** time) nocons tex(frag) label ctitle("Mexicans", "growth rate, 1996", "OLS") nonotes  noaster


erase "tables/Table_relocation_growth_1.txt"
reg LS_growth_rate low_skilled_share_mexican_1980 if year==1995 [aw=obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth_1.txt", drop(_I** time) nocons tex(frag) label ctitle("Low skilled", "growth rate, 1995", "OLS") nonotes noaster
reg LS_growth_rate low_skilled_share_mexican_1980 if year==1996 [aw=L.obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth_1.txt", drop(_I** time) nocons tex(frag) label ctitle("Low skilled", "growth rate, 1996", "OLS") nonotes noaster
reg LS_growth_rate low_skilled_share_mexican_1980 LDln_state_gdp LDln_exports if year==1996 [aw=L.obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth_1.txt", drop(_I** time) nocons tex(frag) label ctitle("Low skilled", "growth rate, 1996", "OLS") nonotes noaster


erase "tables/Table_relocation_growth_2.txt"
reg LS_growth_rate Lmexicans_low_skilled_growth if year==1996  [aw=L.obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth_2.txt", drop(_I** time) nocons tex(frag) label ctitle("Low skilled", "growth rate, 1996", "OLS") nonotes noaster
reg LS_growth_rate Lmexicans_low_skilled_growth LDln_state_gdp LDln_exports if year==1996  [aw=L.obs_pop_low_skilled], robust
outreg2 using "tables/Table_relocation_growth_2.txt", drop(_I** time) nocons tex(frag) label ctitle("Low skilled", "growth rate, 1996", "OLS") e(widstat)  nonotes noaster
ivreg2 LS_growth_rate (Lmexicans_low_skilled_growth=low_skilled_share_mexican_1980) LDln_state_gdp LDln_exports if year==1996 [aw=L.obs_pop_low_skilled], robust 
outreg2 using "tables/Table_relocation_growth_2.txt", drop(_I** time) nocons tex(frag) label ctitle("Low skilled", "growth rate, 1996", "IV") e(widstat)  nonotes noaster

ivreg2 LS_growth_rate (mexicans_low_skilled_growth=low_skilled_share_mexican_1980) Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 

reg LS_growth_rate mexicans_low_skilled_growth Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate_2 mexicans_low_skilled_growth_2 D2.ln_state_gdp D2.ln_exports if year==1996 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate_2 mexicans_low_skilled_growth_2 L.mexicans_low_skilled_growth D2.ln_state_gdp D2.ln_exports if year==1996 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate_3 mexicans_low_skilled_growth_3 D3.ln_state_gdp D3.ln_exports if year==1997 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate_4 mexicans_low_skilled_growth_4 D4.ln_state_gdp D4.ln_exports if year==1998 [aw=obs_pop_low_skilled], robust 


reg LS_growth_rate_2 L.mexicans_low_skilled_growth L.Dln_state_gdp L.Dln_exports if year==1996 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate_3 L2.mexicans_low_skilled_growth L2.Dln_state_gdp L2.Dln_exports if year==1997 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate_4 L3.mexicans_low_skilled_growth L3.Dln_state_gdp L3.Dln_exports if year==1998 [aw=obs_pop_low_skilled], robust 

reg LS_growth_rate low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 
reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate mexicans_low_skilled_growth Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate L.mexicans_low_skilled_growth L.Dln_state_gdp L.Dln_exports if year==1996 [aw=L.obs_pop_low_skilled], robust 

reg LS_growth_rate low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate low_skilled_share_mexican_1980 LS_growth_rate_pre Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate low_skilled_share_mexican_1980 LS_growth_rate_pre Dln_state_gdp Dln_exports if year==1996 [aw=obs_pop_low_skilled], robust 

reg LS_growth_rate low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1996 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate low_skilled_share_mexican_1980 LS_growth_rate_pre Dln_state_gdp Dln_exports if year==1997 [aw=obs_pop_low_skilled], robust 
reg LS_growth_rate low_skilled_share_mexican_1980 Dln_state_gdp LS_growth_rate_pre Dln_exports if year==1998 [aw=obs_pop_low_skilled], robust 

reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop_low_skilled], robust 
reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1996 [aw=obs_pop_low_skilled], robust 
reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1997 [aw=obs_pop_low_skilled], robust 
reg mexicans_low_skilled_growth low_skilled_share_mexican_1980 Dln_state_gdp Dln_exports if year==1998 [aw=obs_pop_low_skilled], robust 

two (scatter mexicans_low_skilled_growth low_skilled_share_mexican_1980 if year==1995)(lfit mexicans_low_skilled_growth low_skilled_share_mexican_1980 if year==1995 [aw=obs_pop_low_skilled])
two (scatter mexicans_low_skilled_growth low_skilled_share_mexican_1980 if year==1996)(lfit mexicans_low_skilled_growth low_skilled_share_mexican_1980 if year==1996 [aw=obs_pop_low_skilled])

two (scatter LS_growth_rate low_skilled_share_mexican_1980 if year==1995)(lfit LS_growth_rate low_skilled_share_mexican_1980 if year==1995 [aw=obs_pop_low_skilled])
two (scatter LS_growth_rate low_skilled_share_mexican_1980 if year==1996)(lfit LS_growth_rate low_skilled_share_mexican_1980 if year==1996 [aw=obs_pop_low_skilled])
two (scatter LS_growth_rate low_skilled_share_mexican_1980 if year==1998, mlabel(statefip))(lfit LS_growth_rate low_skilled_share_mexican_1980 if year==1998 [aw=obs_pop_low_skilled])

drop if year==1991
xi: reg ln_pop_low_skilled i.statefip if year<=1995 [aw=obs_pop_low_skilled], robust 
predict e_ln_pop_low_skilled, residuals
two (connected e_ln_pop_low_skilled year if statefip==6)


xi: reg ln_pop_high_skilled i.statefip if year<=1995 [aw=obs_pop_low_skilled], robust 
predict e_ln_pop_high_skilled, residuals
two (connected e_ln_pop_high_skilled year if statefip==6)

xi: reg ln_mex_low_skilled i.statefip [aw=obs_pop_low_skilled], robust 
predict e_ln_mex_low_skilled, residuals
two (connected e_ln_mex_low_skilled year if statefip==6) (connected ln_mex_low_skilled year if statefip==6, yaxis(2))

reg e_ln_pop_low_skilled L.e_ln_mex_low_skilled i.year if year==1996 [aw=obs_pop_low_skilled], robust 


/***********************
** Further checks
***********************/

reg D.share_low_skilled D.share_native_low_skilled share_mexican_1980  if year==1995  [aw=obs_pop], robust
reg D.share_low_skilled D.share_native_low_skilled share_mexican_1980 if year==1996  [aw=obs_pop], robust
reg D.share_low_skilled D.share_native_low_skilled share_mexican_1980 if year==1997  [aw=obs_pop], robust
reg D.share_low_skilled D.share_native_low_skilled share_mexican_1980 if year==1998  [aw=obs_pop], robust
reg D.share_low_skilled share_mexican_1980 if year==1999  [aw=obs_pop], robust

reg D.share_native_low_skilled share_mexican_1980 if year==1995  [aw=obs_pop], robust
reg D.share_native_low_skilled share_mexican_1980 if year==1996  [aw=obs_pop], robust
reg D.share_native_low_skilled share_mexican_1980 if year==1997  [aw=obs_pop], robust

reg D.share_mexicans share_mexican_1980 if year==1995  [aw=obs_pop], robust
reg D.share_mexicans share_mexican_1980 if year==1996  [aw=obs_pop], robust
reg D.share_mexicans share_mexican_1980 if year==1997  [aw=obs_pop], robust

reg D.share_low_skilled share_mexican_1980  if year==1995  [aw=obs_pop], robust
reg D.share_low_skilled share_mexican_1980 if year==1996  [aw=obs_pop], robust
reg D.share_low_skilled share_mexican_1980 if year==1997  [aw=obs_pop], robust

reg D.share_low_skilled D.share_mexicans  D.ln_exports D.ln_state_gdp  if year==1995  [aw=obs_pop], robust
reg D.share_low_skilled L.D.share_mexicans  D.ln_exports D.ln_state_gdp  if year==1996  [aw=obs_pop], robust
reg D.share_low_skilled L2.D.share_mexicans  D.ln_exports D.ln_state_gdp  if year==1997  [aw=obs_pop], robust

reg D.share_mexicans D.share_mexicans  D.ln_exports D.ln_state_gdp  if year==1995  [aw=obs_pop], robust
reg D.share_mexicans L.D.share_mexicans  D.ln_exports D.ln_state_gdp  if year==1996  [aw=obs_pop], robust
reg D.share_mexicans L2.D.share_mexicans  D.ln_exports D.ln_state_gdp  if year==1997  [aw=obs_pop], robust

reg D.share_native_low_skilled share_mexican_1980  D.ln_exports D.ln_state_gdp  if year==1995  [aw=obs_pop], robust
reg D.share_native_low_skilled share_mexican_1980  D.ln_exports D.ln_state_gdp  if year==1996  [aw=obs_pop], robust
reg D.share_native_low_skilled share_mexican_1980  D.ln_exports D.ln_state_gdp  if year==1997  [aw=obs_pop], robust

reg D.share_mexicans share_mexican_1980  D.ln_exports D.ln_state_gdp if year==1995  [aw=obs_pop], robust
reg D.share_mexicans share_mexican_1980  D.ln_exports D.ln_state_gdp if year==1996  [aw=obs_pop], robust
reg D.share_mexicans share_mexican_1980  D.ln_exports D.ln_state_gdp if year==1997  [aw=obs_pop], robust

