
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** Table_long_run_state
***********************/
//erase "tables/Table_long_run_first_stage.txt"
//erase "tables/Table_long_run_wages.txt"
//erase "tables/Table_long_run_wages_high.txt"

use data/est_long_run_state.dta, clear

reg share_mexpop_2000_1990 share_mexican_low_skilled_1980 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_first_stage.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "Mexican, LS", "OLS") nonotes noaster

reg wage_low_skilled_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "OLS") nonotes noaster
ivreg2 wage_low_skilled_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 )  [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "IV")e(widstat)  nonotes noaster

reg wage_high_skilled_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust  
outreg2 using "tables/Table_long_run_wages_high.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, HS", "OLS") nonotes noaster
ivreg2 wage_high_skilled_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 )  [aw=obs_1990], robust  first
outreg2 using "tables/Table_long_run_wages_high.txt", drop(_I** time) nocons nor2  tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, HS", "IV")e(widstat)  nonotes noaster


use "data/est_long_run_metarea.dta", clear

replace share_mexican_low_skilled_1980=0 if share_mexican_low_skilled_1980==. //dropping metareas without data for 1980
drop if metarea==0
merge 1:1 metarea using "data/good_msa.dta",  keep(3) // use the same metropolitan areas than short-run results. No difference if using full sample. 
merge m:1 metarea using "data/crosswalk_metare_statefip.dta", nogen

reg share_mexpop_2000_1990 share_mexican_low_skilled_1980 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_first_stage.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "Mexican, LS", "OLS") nonotes noaster

reg wage_low_skilled_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "OLS") nonotes noaster
ivreg2 wage_low_skilled_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 )  [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "IV")e(widstat)  nonotes noaster

reg wage_high_skilled_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust  
outreg2 using "tables/Table_long_run_wages_high.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, HS", "OLS") nonotes noaster
ivreg2 wage_high_skilled_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980)  [aw=obs_1990], robust  first
outreg2 using "tables/Table_long_run_wages_high.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, HS", "IV")e(widstat)  nonotes noaster

use data/est_long_run_age.dta, clear

reg share_mexpop_2000_1990 pred_share_mexicans_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_first_stage.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "Mexican, LS", "OLS") nonotes noaster

reg wage_low_skilled_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust  
outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ Wage", "native, LS", "OLS") nonotes noaster
ivreg2 wage_low_skilled_2000_1990 (share_mexpop_2000_1990=pred_share_mexicans_2000_1990 )  [aw=obs_1990], robust  first
outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ Wage", "native, LS", "IV") nonotes noaster e(widstat) 

reg wage_high_skilled_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust 
outreg2 using "tables/Table_long_run_wages_high.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ Wage", "native, HS", "OLS") nonotes noaster
ivreg2 wage_high_skilled_2000_1990 (share_mexpop_2000_1990=pred_share_mexicans_2000_1990)  [aw=obs_1990], robust  first
outreg2 using "tables/Table_long_run_wages_high.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ Wage", "native, HS", "IV") nonotes noaster e(widstat) 




/***********************
** Table_long_run_state: employment
***********************/


use data/est_long_run_state.dta, clear

reg ln_emp_low_nat_rate_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_emp.txt", drop(_I** time) nocons tex(frag) replace label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, LS", "OLS") nonotes noaster
ivreg2 ln_emp_low_nat_rate_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 )  [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_emp.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, LS", "IV")e(widstat)  nonotes noaster

reg ln_emp_high_nat_rate_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust  
outreg2 using "tables/Table_long_run_emp_high.txt", drop(_I** time) nocons tex(frag) replace label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, HS", "OLS") nonotes noaster
ivreg2 ln_emp_high_nat_rate_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 )  [aw=obs_1990], robust  first
outreg2 using "tables/Table_long_run_emp_high.txt", drop(_I** time) nocons nor2  tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, HS", "IV")e(widstat)  nonotes noaster


use data/est_long_run_metarea.dta, clear

drop if share_mexican_low_skilled_1980==. //dropping metareas without data for 1980
drop if metarea==0
merge 1:1 metarea using "data/good_msa.dta", keep(3) // use the same metropolitan areas than short-run results. No difference if using full sample. 
merge m:1 metarea using "data/crosswalk_metare_statefip.dta", nogen

reg ln_emp_low_nat_rate_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_emp.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, LS", "OLS") nonotes noaster
ivreg2 ln_emp_low_nat_rate_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_emp.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, LS", "IV")e(widstat)  nonotes noaster

reg ln_emp_high_nat_rate_2000_1990 share_mexpop_2000_1990 , robust   
outreg2 using "tables/Table_long_run_emp_high.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, HS", "OLS") nonotes noaster
ivreg2 ln_emp_high_nat_rate_2000_1990  (share_mexpop_2000_1990=share_mexican_low_skilled_1980)  [aw=obs_1990], robust  first
outreg2 using "tables/Table_long_run_emp_high.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "yes", "Cross-age", "no") ctitle("$\Delta$ (ln) Emp. rate", "native, HS", "IV")e(widstat)  nonotes noaster


use data/est_long_run_age.dta, clear

reg ln_emp_low_nat_rate_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_emp.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ (ln) Emp. rate", "native, LS", "OLS") nonotes noaster
ivreg2 ln_emp_low_nat_rate_2000_1990 (share_mexpop_2000_1990=pred_share_mexicans_2000_1990 ) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_emp.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ (ln) Emp. rate", "native, LS", "IV")e(widstat)  nonotes noaster

reg ln_emp_high_nat_rate_2000_1990 share_mexpop_2000_1990 , robust   
outreg2 using "tables/Table_long_run_emp_high.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ (ln) Emp. rate", "native, HS", "OLS") nonotes noaster
ivreg2 ln_emp_high_nat_rate_2000_1990  (share_mexpop_2000_1990=pred_share_mexicans_2000_1990)  [aw=obs_1990], robust  first
outreg2 using "tables/Table_long_run_emp_high.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "no", "Cross-msa", "no", "Cross-age", "yes") ctitle("$\Delta$ (ln) Emp. rate", "native, HS", "IV")e(widstat)  nonotes noaster



/***********************
** Table_long_run: rentals
***********************/

use data/est_long_run_state.dta, clear
merge 1:1 statefip using "$dropbox/data/Rental_statefip_long_run.dta", nogen keep(3) // This data set is created externally in DATA_PREPARATION_rental_long_run
merge 1:1 statefip using "$dropbox/data/House_prices_statefip_long_run.dta", keep(3)

gen ln_Gap_rent_price_2000_1990=rentals_1999_1990 - ln_HPI_2000_1990
gen share_others_1990 = (pop_high_skilled_1990 - mex_high_skilled_1990) / (pop_high_skilled_1990+ pop_low_skilled_1990 - mex_low_skilled_1990 - mex_high_skilled_1990)
gen share_others_2000 = (pop_high_skilled_2000 - mex_high_skilled_2000) / (pop_high_skilled_2000+ pop_low_skilled_2000 - mex_low_skilled_2000 - mex_high_skilled_2000)
gen share_others_2000_1990 = share_others_2000 - share_others_1990

reg rentals_1999_1990 share_mexpop_2000_1990  [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_rentals.txt", drop(_I** time) nocons tex(frag) replace label  ctitle("$\Delta$ (ln) Rent", "", "OLS") nonotes noaster
ivreg2 rentals_1999_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_rentals.txt", drop(_I** time) nocons nor2 tex(frag) label  ctitle("$\Delta$ (ln) Rent", "", "IV")e(widstat)  nonotes noaster

reg ln_HPI_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_rentals.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (ln) HPI", "", "OLS") nonotes noaster
ivreg2 ln_HPI_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_rentals.txt", drop(_I** time) nocons nor2 tex(frag) label  ctitle("$\Delta$ (ln) HPI", "", "IV")e(widstat)  nonotes noaster

reg ln_Gap_rent_price_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_rentals.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (ln) Rent. Gap", "", "OLS") nonotes noaster
ivreg2 ln_Gap_rent_price_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_rentals.txt", drop(_I** time) nocons nor2 tex(frag) label  ctitle("$\Delta$ (ln) Rent. Gap", "", "IV")e(widstat)  nonotes noaster

reg mex_const_share_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_housing.txt", replace drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Share", "Mex in Const. LS", "OLS") nonotes noaster
ivreg2 mex_const_share_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_housing.txt",  drop(_I** time) nocons nor2 tex(frag) label ctitle("$\Delta$ Share", "Mex in Const. LS", "IV") e(widstat) nonotes noaster

reg emp_construction_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_housing.txt",  drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Share", "Const. LS", "OLS") nonotes noaster
ivreg2 emp_construction_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980)  [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_housing.txt", drop(_I** time) nocons nor2 tex(frag) label ctitle("$\Delta$ Share", "Const. LS", "IV") e(widstat)  nonotes noaster

reg wage_ls_nat_cons_2000_1990  share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_housing.txt", drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ (ln) Wages (natives)", "Const. LS", "OLS") nonotes noaster
ivreg2 wage_ls_nat_cons_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_housing.txt", drop(_I** time) nocons nor2 tex(frag) label ctitle("$\Delta$ (ln) Wages (natives)", "Const. LS", "IV") e(widstat)  nonotes noaster



tempfile t1
use "$dropbox/data/housing_supply_elasticity.dta", clear
gen metarea=int(pmsa/10)
collapse (mean) elasticity [aw=population], by(metarea)
save `t1'.dta, replace

use data/est_long_run_metarea.dta, clear
merge 1:1 metarea using "$dropbox/data/good_msa.dta",  // use the same metropolitan areas than short-run results. No difference if using full sample. 
merge 1:1 metarea using "$dropbox/data/Rental_metarea_long_run.dta", nogen   // This data set is created externally in DATA_PREPARATION_rental_long_run
merge 1:1 metarea using "$dropbox/data/House_prices_metarea_long_run.dta",  nogen 
drop if metarea==0
merge 1:1 metarea using "$dropbox/data/crosswalk_metare_statefip.dta", nogen
//merge 1:1 metarea using `t1'.dta, nogen

gen ln_Gap_rent_price_2000_1990=rentals_1999_1990 - ln_HPI_2000_1990
gen share_others_1990 = (pop_high_skilled_1990 - mex_high_skilled_1990) / (pop_high_skilled_1990+ pop_low_skilled_1990 - mex_low_skilled_1990 - mex_high_skilled_1990)
gen share_others_2000 = (pop_high_skilled_2000 - mex_high_skilled_2000) / (pop_high_skilled_2000+ pop_low_skilled_2000 - mex_low_skilled_2000 - mex_high_skilled_2000)
gen share_others_2000_1990 = share_others_2000 - share_others_1990

replace share_mexpop_2000_1990=0 if share_mexpop_2000_1990==. //there a few observations with 0s in the numerator)

reg rentals_1999_1990 share_mexpop_2000_1990 if ln_Gap_rent_price_2000_1990!=. [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_rentals_msa.txt", drop(_I** time) nocons tex(frag) replace label  ctitle("$\Delta$ (ln) Rent", "", "OLS") nonotes noaster
ivreg2 rentals_1999_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) if ln_Gap_rent_price_2000_1990!=. [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_rentals_msa.txt", drop(_I** time) nocons nor2 tex(frag) label  ctitle("$\Delta$ (ln) Rent", "", "IV")e(widstat)  nonotes noaster


reg ln_HPI_2000_1990 share_mexpop_2000_1990 if ln_Gap_rent_price_2000_1990!=. [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_rentals_msa.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (ln) HPI", "", "OLS") nonotes noaster
ivreg2 ln_HPI_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) if ln_Gap_rent_price_2000_1990!=. [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_rentals_msa.txt", drop(_I** time) nocons nor2 tex(frag) label  ctitle("$\Delta$ (ln) HPI", "", "IV")e(widstat)  nonotes noaster

reg ln_Gap_rent_price_2000_1990 share_mexpop_2000_1990 if ln_Gap_rent_price_2000_1990!=. [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_rentals_msa.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (ln) Rent. Gap", "", "OLS") nonotes noaster
ivreg2 ln_Gap_rent_price_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) if ln_Gap_rent_price_2000_1990!=. [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_rentals_msa.txt", drop(_I** time) nocons nor2 tex(frag) label  ctitle("$\Delta$ (ln) Rent. Gap", "", "IV")e(widstat)  nonotes noaster

/***************************/

reg mex_const_share_2000_1990 share_mexpop_2000_1990  [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_housing_msa.txt", replace drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Share", "Mex in Const. LS", "OLS") nonotes noaster
ivreg2 mex_const_share_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980)  [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_housing_msa.txt",  drop(_I** time) nocons nor2 tex(frag) label ctitle("$\Delta$ Share", "Mex in Const. LS", "IV") e(widstat) nonotes noaster

reg emp_construction_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_housing_msa.txt",  drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Share", "Const. LS", "OLS") nonotes noaster
ivreg2 emp_construction_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980)  [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_housing_msa.txt", drop(_I** time) nocons nor2 tex(frag) label ctitle("$\Delta$ Share", "Const. LS", "IV") e(widstat)  nonotes noaster

reg wage_ls_nat_cons_2000_1990  share_mexpop_2000_1990 [aw=obs_1990], robust   
outreg2 using "tables/Table_long_run_housing_msa.txt", drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ (ln) Wages (natives)", "Const. LS", "OLS") nonotes noaster
ivreg2 wage_ls_nat_cons_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 ) [aw=obs_1990], robust first
outreg2 using "tables/Table_long_run_housing_msa.txt", drop(_I** time) nocons nor2 tex(frag) label ctitle("$\Delta$ (ln) Wages (natives)", "Const. LS", "IV") e(widstat)  nonotes noaster


**** SHARE EMPLOYED IN CONSTRUCTION


use data/est_long_run_state.dta, clear

reg emp_construction_nat_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
*outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "OLS") nonotes noaster
ivreg2 emp_construction_nat_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 )  [aw=obs_1990], robust first
*outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "IV")e(widstat)  nonotes noaster

reg emp_construction_mex_2000_1990 share_mexpop_2000_1990 [aw=obs_1990], robust   
*outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "OLS") nonotes noaster
ivreg2 emp_construction_mex_2000_1990 (share_mexpop_2000_1990=share_mexican_low_skilled_1980 )  [aw=obs_1990], robust first
*outreg2 using "tables/Table_long_run_wages.txt", drop(_I** time) nocons nor2 tex(frag) label addtext("First Differenced","yes", "Cross-state", "yes", "Cross-msa", "no", "Cross-age", "no") ctitle("$\Delta$ Wage", "native, LS", "IV")e(widstat)  nonotes noaster


