
/***********************
** METADATA
***********************/

/****
Created by: Joan Monras
Date: October 2019
****/


/***********************
** COMPUTING RESOURCES
***********************/

set more off
cd "/home/joan/Dropbox/Columbia/JPE_replication_code"


/***********************
** LOAD DATA
***********************/

use "data/Estimation_data_set_short_run_wages.dta", clear

count

if `r(N)'==328 {
global metro="_msa"
drop if metarea==0
drop if metarea==.
drop if metarea==306 // This metropolitan area is too small and doesn't have a single observation of high skilled workers. I drop it from analysis. 
}
else {
global metro=""
}
/*
sutex wage_low_skilled wage_high_skilled obs_wages_low_skilled obs_wages_high_skilled labor_low_skilled labor_high_skilled ln_labor_high_skilled share_mexicans_low_skilled share_mexican_1980 ln_exports ln_state_gdp
*/

/***********************
** TABLE: Table_short_run_first_stage
***********************/

reg share_mexicans_low_skilled share_mexican_low_skilled_1980 if year==1995 [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_short_run_first_stage$metro.txt", replace drop(_I** time) nocons tex(frag) label addtext("First Differenced","no") ctitle("Share", "Mexican, LS", "OLS") nonotes noaster
reg Dshare_mexicans_low_skilled share_mexican_low_skilled_1980 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_short_run_first_stage$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "Mexican, LS","OLS") nonotes noaster

reg share_mexicans_high_skilled share_mexican_high_skilled_1980 if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_short_run_first_stage$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","no") ctitle("Share", "Mexican, HS", "OLS") nonotes noaster
reg Dshare_mexicans_high_skilled share_mexican_high_skilled_1980 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_short_run_first_stage$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "Mexican, HS","OLS") nonotes noaster

reg share_mexicans_low_skilled share_mexican_low_skilled_1980 if year==1995 [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_short_run_first_stage_census$metro.txt", replace drop(_I** time) nocons tex(frag) label addtext("First Differenced","no") ctitle("Share", "Mexican, LS", "OLS") nonotes noaster
reg mexican_shock share_mexican_low_skilled_1980 if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_short_run_first_stage_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "Mexican, LS","OLS") nonotes noaster

reg share_mexicans_high_skilled share_mexican_high_skilled_1980 if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_short_run_first_stage_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","no") ctitle("Share", "Mexican, HS", "OLS") nonotes noaster
reg Dshare_mexicans_high_skilled share_mexican_high_skilled_1980 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_short_run_first_stage_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes") ctitle("Share", "Mexican, HS","OLS") nonotes noaster

*/

/***********************
** TABLE: Table_wages_short_run 
***********************/

**CPS data for mexican shock

reg wage_low_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run$metro.txt", drop(_I** time) replace nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "LS non-Mex", "OLS") nonotes  noaster
ivreg2 wage_low_skilled (share_mexicans_low_skilled=share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "LS non-Mex","IV") e(widstat) nonotes noaster
reg Dwage_low_skilled Dshare_mexicans_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "LS non-Mex","OLS") nonotes noaster
reg Dwage_low_skilled Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "LS non-Mex","OLS")  nonotes noaster
ivreg2 Dwage_low_skilled (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "LS non-Mex","IV")  nonotes noaster
ivreg2 Dwage_low_skilled_no_state_trend (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS non-Mex","IV") e(widstat) nonotes noaster
ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_wages_short_run$metro.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster

** Census data for Mexican shock

reg wage_low_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census$metro.txt", drop(_I** time) replace nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "LS non-Mex", "OLS") nonotes  noaster
ivreg2 wage_low_skilled (share_mexicans_low_skilled=share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "LS non-Mex","IV") e(widstat) nonotes noaster
reg Dwage_low_skilled mexican_shock  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census$metro.txt", drop(_I** time wage_low_skilled_9193) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "LS non-Mex","OLS") nonotes noaster
reg Dwage_low_skilled mexican_shock Dln_exports Dln_state_gdp  Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "LS non-Mex","OLS")  nonotes noaster
ivreg2 Dwage_low_skilled (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "LS non-Mex","IV")  nonotes noaster
ivreg2 Dwage_low_skilled_no_state_trend (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS non-Mex","IV") e(widstat) nonotes noaster
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_wages_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster

** Census data for Mexican shock + baseline

reg wage_low_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census_base$metro.txt", drop(_I** time) replace nocons tex(frag) label addtext("Wages detrended","no", "Baseline controls", "no") ctitle("Wage", "LS non-Mex", "OLS") nonotes  noaster
ivreg2 wage_low_skilled (share_mexicans_low_skilled=share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census_base$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no", "Baseline controls", "no") ctitle("Wage", "LS non-Mex","IV") e(widstat) nonotes noaster
reg Dwage_low_skilled mexican_shock wage_low_skilled_9193 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census_base$metro.txt", drop(_I** time wage_low_skilled_9193) nocons tex(frag) label addtext("Wages detrended","no", "Baseline controls", "yes") ctitle("$\Delta$ Wage", "LS non-Mex","OLS") nonotes noaster
reg Dwage_low_skilled mexican_shock Dln_exports Dln_state_gdp wage_low_skilled_9193 Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_census_base$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no", "Baseline controls", "yes") ctitle("$\Delta$ Wage", "LS non-Mex","OLS")  nonotes noaster
ivreg2 Dwage_low_skilled (mexican_shock=share_mexican_low_skilled_1980) wage_low_skilled_9193 Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_census_base$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","no", "Baseline controls", "yes") ctitle("$\Delta$ Wage", "LS non-Mex","IV")  nonotes noaster
ivreg2 Dwage_low_skilled_no_state_trend (mexican_shock=share_mexican_low_skilled_1980) wage_low_skilled_9193 Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_census_base$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","yes", "Baseline controls", "yes") ctitle("$\Delta$ Wage", "LS non-Mex","IV") e(widstat) nonotes noaster
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) wage_low_skilled_9193 Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_wages_short_run_census_base$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","yes", "Baseline controls", "yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster


/***********************
** TABLE: Table_wages_short_run_robustness
***********************/

reg Dwage_low_skilled_9294 Dshare_mexicans_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) replace nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "no") ctitle("Wage", "LS Ind. controls","OLS") nonotes noaster
reg Dwage_low_skilled_9294 Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Ind. controls","OLS") nonotes noaster

reg Dwage_low_skilled_no_state_trend Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS non-Mex","OLS") nonotes noaster

reg Dwage_low_skilled_nat_no_trend Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Non-FB","OLS") nonotes noaster

ivreg2 Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980)  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "no") ctitle("Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)

ivreg2 Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)

ivreg2 Dwage_low_skilled_no_state_trend (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS non-Mex","IV") nonotes noaster e(widstat)

ivreg2 Dwage_low_skilled_nat_no_trend (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Non-FB","IV") nonotes noaster e(widstat)

******

reg Dwage_low_skilled_9294 mexican_shock  wage_low_skilled_9193 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) replace nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "no") ctitle("Wage", "LS Ind. controls","OLS") nonotes noaster
reg Dwage_low_skilled_9294 mexican_shock Dln_exports Dln_state_gdp Dln_labor_high_skilled wage_low_skilled_9193 Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Ind. controls","OLS") nonotes noaster

reg Dwage_low_skilled_no_state_trend mexican_shock Dln_exports Dln_state_gdp Dln_labor_high_skilled wage_low_skilled_9193 Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS non-Mex","OLS") nonotes noaster

reg Dwage_low_skilled_nat_no_trend mexican_shock Dln_exports Dln_state_gdp wage_low_skilled_9193 Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Non-FB","OLS") nonotes noaster

ivreg2 Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) wage_low_skilled_9193 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "no") ctitle("Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)

ivreg2 Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980)  wage_low_skilled_9193 Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)

ivreg2 Dwage_low_skilled_no_state_trend (mexican_shock=share_mexican_low_skilled_1980)  wage_low_skilled_9193 Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS non-Mex","IV") nonotes noaster e(widstat)

ivreg2 Dwage_low_skilled_nat_no_trend (mexican_shock=share_mexican_low_skilled_1980) wage_low_skilled_9193 Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_census$metro.txt", drop(_I** time wage_low_skilled_9193) nor2 nocons tex(frag) label addtext("First Differenced","yes","Wages detrended","yes", "Controls", "yes") ctitle("Wage", "LS Non-FB","IV") nonotes noaster e(widstat)



/***********************
** TABLE: Table_wages_short_run_robustness_geo
***********************/


reg Dwage_low_skilled_9294 Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_geo$metro.txt", drop(_I** time) replace nocons tex(frag) label addtext( "State excl.","None") ctitle("$\Delta$ Wage", "LS Ind. controls","OLS") nonotes noaster
reg Dwage_low_skilled_9294 Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled if statefip!=6 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_geo$metro.txt", drop(_I** time)  nocons tex(frag) label addtext( "State excl.","CA") ctitle("$\Delta$ Wage", "LS Ind. controls","OLS") nonotes noaster
reg Dwage_low_skilled_9294 Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled if statefip!=48 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_geo$metro.txt", drop(_I** time) nocons tex(frag) label addtext("State excl.","TX") ctitle("$\Delta$ Wage", "LS Ind. controls","OLS") nonotes noaster


ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_wages_short_run_robustness_geo$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext( "State excl.","None") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)
ivreg2 Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled = share_mexican_low_skilled_1980) Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled if statefip!=6 [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_robustness_geo$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext( "State excl.","CA") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)
ivreg2 Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled = share_mexican_low_skilled_1980) Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled if statefip!=48 [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_robustness_geo$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext( "State excl.","TX") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)


reg Dwage_low_skilled_9294 mexican_shock Dln_exports Dln_state_gdp Dln_labor_high_skilled  Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_geo_census$metro.txt", replace drop(_I** time ) nocons tex(frag) label addtext( "State excl.","None") ctitle("$\Delta$ Wage", "LS Ind. controls","OLS") nonotes noaster
reg Dwage_low_skilled_9294 mexican_shock Dln_exports Dln_state_gdp Dln_labor_high_skilled  Dln_labor_low_skilled if statefip!=6 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_geo_census$metro.txt",  drop(_I** time ) nocons tex(frag) label addtext( "State excl.","CA") ctitle("$\Delta$ Wage", "LS Ind. controls","OLS") nonotes noaster
reg Dwage_low_skilled_9294 mexican_shock Dln_exports Dln_state_gdp Dln_labor_high_skilled  Dln_labor_low_skilled if statefip!=48 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_robustness_geo_census$metro.txt", drop(_I** time ) nocons tex(frag) label addtext("State excl.","TX") ctitle("$\Delta$ Wage", "LS Ind. controls","OLS") nonotes noaster


ivreg2 Dwage_low_skilled_9294 (mexican_shock = share_mexican_low_skilled_1980)  Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_robustness_geo_census$metro.txt", drop(_I** time ) nor2 nocons tex(frag) label addtext( "State excl.","None") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)
ivreg2 Dwage_low_skilled_9294 (mexican_shock = share_mexican_low_skilled_1980)  Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled if statefip!=6 [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_robustness_geo_census$metro.txt", drop(_I** time ) nor2 nocons tex(frag) label addtext( "State excl.","CA") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)
ivreg2 Dwage_low_skilled_9294 (mexican_shock = share_mexican_low_skilled_1980)  Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled if statefip!=48 [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_wages_short_run_robustness_geo_census$metro.txt", drop(_I** time ) nor2 nocons tex(frag) label addtext( "State excl.","TX") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") nonotes noaster e(widstat)



reg mexican_shock   Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled]
predict mexican_shock_res, res
reg share_mexican_low_skilled_1980   Dln_exports Dln_state_gdp Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled]
predict share_mexican_ls_1980_res, res

two (scatter mexican_shock_res share_mexican_ls_1980_res [aw=obs_wages_low_skilled] if statefip!=6 & statefip!=48 & Dwage_low_skilled_9294!=., msymbol(S) msize(vsmall)) ///
(scatter mexican_shock_res share_mexican_ls_1980_res [aw=obs_wages_low_skilled] if statefip==6 & Dwage_low_skilled_9294!=., msymbol(Oh)msize(vsmall) ) ///
(scatter mexican_shock_res share_mexican_ls_1980_res [aw=obs_wages_low_skilled] if  statefip==48 & Dwage_low_skilled_9294!=., msymbol(X) msize(vsmall)), scheme(s1mono) ytitle(Relative inflow in 1995) xtitle(Share of Mex. among low-skilled in 1980) legend(off) //  legend(label(1 RoUS) label(2 Cal) label(3 TX))
graph export "figures/first_stage.png", replace


/***********************
** TABLE: Table_wages_short_run_high_skilled
***********************/

reg wage_high_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled$metro.txt", drop(_I** time) replace nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "HS non-Mex", "OLS") nonotes noaster
ivreg2 wage_high_skilled (share_mexicans_low_skilled=share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "HS non-Mex","IV") e(widstat) nonotes noaster
reg Dwage_high_skilled Dshare_mexicans_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "HS non-Mex","OLS") nonotes noaster
reg Dwage_high_skilled Dshare_mexicans_low_skilled Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "HS non-Mex","OLS") nonotes noaster

ivreg2 Dwage_high_skilled (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "HS non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_high_skilled_no_trend (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "HS non-Mex","IV") e(widstat) nonotes noaster
ivreg2  Dwage_high_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_wages_short_run_high_skilled$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "HS Ind. controls","IV") e(widstat) nonotes noaster


reg wage_high_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled_census$metro.txt", replace drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "HS non-Mex", "OLS") nonotes noaster
ivreg2 wage_high_skilled (share_mexicans_low_skilled=share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("Wages detrended","no") ctitle("Wage", "HS non-Mex","IV") e(widstat) nonotes noaster
reg Dwage_high_skilled mexican_shock  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled_census$metro.txt", drop(_I** time wage_low_skilled_9193) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "HS non-Mex","OLS") nonotes noaster
reg Dwage_high_skilled mexican_shock Dln_state_gdp Dln_exports  Dln_labor_high_skilled Dln_labor_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled_census$metro.txt", drop(_I** time wage_low_skilled_9193) nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "HS non-Mex","OLS") nonotes noaster
ivreg2 Dwage_high_skilled (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled_census$metro.txt", drop(_I** time wage_low_skilled_9193) nor2 nocons tex(frag) label addtext("Wages detrended","no") ctitle("$\Delta$ Wage", "HS non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_high_skilled_no_trend (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wages_short_run_high_skilled_census$metro.txt", drop(_I** time wage_low_skilled_9193) nor2 nocons tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "HS non-Mex","IV") e(widstat) nonotes noaster
ivreg2  Dwage_high_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980)  Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_wages_short_run_high_skilled_census$metro.txt", drop(_I** time wage_low_skilled_9193) nor2 nocons tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "HS Ind. controls","IV") e(widstat) nonotes noaster


/***********************
** TABLE: Table_wage_gap 
***********************/

reg wage_gap share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) replace nocons tex(frag) label ctitle("Wage Gap","OLS")  nonotes noaster
ivreg2 wage_gap (share_mexicans_low_skilled=share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) nocons tex(frag)  label ctitle("Wage Gap","IV") e(widstat) nonotes noaster

reg Dwage_gap Dshare_mexicans_low_skilled [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) nocons tex(frag)  label ctitle("$\Delta$ Wage Gap","OLS")  nonotes noaster
reg Dwage_gap Dshare_mexicans_low_skilled Dratio_high [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Wage Gap","OLS")  nonotes noaster
reg Dwage_gap Dshare_mexicans_low_skilled Dln_state_gdp Dln_exports Dratio_high [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Wage Gap","OLS")  nonotes noaster

ivreg2 Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) nor2 nocons tex(frag)  label ctitle("$\Delta$ Wage Gap","IV") e(widstat) nonotes noaster
ivreg2 Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dratio_high  [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ Wage Gap","IV") e(widstat) nonotes noaster
ivreg2 Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dratio_high [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ Wage Gap","IV") e(widstat) nonotes noaster

reg wage_gap share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap_census$metro.txt", replace drop(_I** time) nocons tex(frag) label ctitle("Wage Gap","OLS") nonotes noaster
ivreg2 wage_gap (share_mexicans_low_skilled=share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap_census$metro.txt", drop(_I** time) nor2 nocons tex(frag)  label ctitle("Wage Gap","IV") e(widstat) nonotes noaster

reg Dwage_gap mexican_shock [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap_census$metro.txt", drop(_I** time) nocons tex(frag)  label ctitle("$\Delta$ Wage Gap","OLS")  nonotes noaster
reg Dwage_gap mexican_shock Dratio_high [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap_census$metro.txt", drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Wage Gap","OLS")  nonotes noaster
reg Dwage_gap mexican_shock Dln_state_gdp Dln_exports Dratio_high [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_wagegap_census$metro.txt", drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ Wage Gap","OLS")  nonotes noaster

ivreg2 Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap_census$metro.txt", drop(_I** time) nor2 nocons tex(frag)  label ctitle("$\Delta$ Wage Gap","IV") e(widstat) nonotes noaster
ivreg2 Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) Dratio_high  [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ Wage Gap","IV") e(widstat) nonotes noaster
ivreg2 Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dratio_high [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_wagegap_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ Wage Gap","IV") e(widstat) nonotes noaster


/***********************
** TABLE: Table_wages_hsdo_hsg
***********************/

reg Dwage_HSDO Dshare_mexicans_low_skilled Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSDO], robust
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) replace nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","no") ctitle("Wage", "HSDO non-Mex","OLS") nonotes noaster
reg Dwage_HSG Dshare_mexicans_low_skilled Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","no") ctitle("Wage", "HSG non-Mex","OLS")nonotes noaster
reg Dwage_HSDO_no_state_trend Dshare_mexicans_low_skilled Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSDO], robust
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","yes") ctitle("Wage", "HSDO non-Mex","OLS")nonotes noaster
reg Dwage_HSG_no_state_trend Dshare_mexicans_low_skilled Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","yes") ctitle("Wage", "HSG non-Mex","OLS")nonotes noaster
ivreg2 Dwage_HSDO (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSDO], robust
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","no") ctitle("Wage", "HSDO non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_HSG (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","no") ctitle("Wage", "HSG non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_HSDO_no_state_trend (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled  [aw=obs_wages_HSDO], robust first
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","yes") ctitle("Wage", "HSDO non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_HSG_no_state_trend (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust 
outreg2 using "tables/Table_wages_hsdo_hsg$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","yes") ctitle("Wage", "HSG non-Mex","IV") e(widstat) nonotes noaster

reg Dwage_HSDO mexican_shock Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSDO], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time)  replace nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","no") ctitle("Wage", "HSDO non-Mex","OLS") nonotes noaster
reg Dwage_HSG mexican_shock Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","no") ctitle("Wage", "HSG non-Mex","OLS")nonotes noaster
reg Dwage_HSDO_no_state_trend mexican_shock Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSDO], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","yes") ctitle("Wage", "HSDO non-Mex","OLS")nonotes noaster
reg Dwage_HSG_no_state_trend mexican_shock Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time) nocons tex(frag) label addtext("First Differenced","yes","Instrumented","no","Wages detrended","yes") ctitle("Wage", "HSG non-Mex","OLS")nonotes noaster
ivreg2 Dwage_HSDO (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSDO], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","no") ctitle("Wage", "HSDO non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_HSG (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","no") ctitle("Wage", "HSG non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_HSDO_no_state_trend (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled  [aw=obs_wages_HSDO], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","yes") ctitle("Wage", "HSDO non-Mex","IV") e(widstat) nonotes noaster
ivreg2 Dwage_HSG_no_state_trend (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_HSG], robust
outreg2 using "tables/Table_wages_hsdo_hsg_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label addtext("First Differenced","yes","Instrumented","yes","Wages detrended","yes") ctitle("Wage", "HSG non-Mex","IV") e(widstat) nonotes noaster



/***********************
** TABLE: Table_emp
***********************/


reg ln_emp_low_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) replace nocons tex(frag) label  ctitle("(log) Emp. rate", "LS native","OLS") nonotes noaster  addtext("Controls","no")
ivreg2 ln_emp_low_skilled (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("(log) Emp. rate", "LS native","IV") nonotes noaster e(widstat) addtext("Controls","no")
reg Dln_emp_low_skilled Dshare_mexicans_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "LS native","OLS") nonotes noaster addtext("Controls","no")
reg Dln_emp_low_skilled Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "LS native","OLS")  nonotes noaster addtext("Controls","yes")
ivreg2 Dln_emp_low_skilled (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_emp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "LS native","IV")  nonotes noaster e(widstat) addtext("Controls","yes")
 


reg ln_emp_low_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run_census$metro.txt", replace drop(_I** time) nocons tex(frag) label  ctitle("(log) Emp. rate", "LS native","OLS") nonotes noaster addtext("Controls","no")
ivreg2 ln_emp_low_skilled (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run_census$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nor2 nocons tex(frag) label  ctitle("(log) Emp. rate", "LS native","IV") nonotes noaster e(widstat) addtext("Controls","no")
reg Dln_emp_low_skilled mexican_shock  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run_census$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ Emp. rate", "LS native","OLS") nonotes noaster addtext("Controls","no")
reg Dln_emp_low_skilled mexican_shock Dln_exports Dln_state_gdp [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_emp_short_run_census$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "LS native","OLS")  nonotes noaster addtext("Controls","yes")
ivreg2 Dln_emp_low_skilled (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_emp_short_run_census$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "LS native","IV")  nonotes noaster e(widstat) addtext("Controls","yes")



reg ln_emp_high_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) replace nocons tex(frag) label  ctitle("(log) Emp. rate", "HS native","OLS") nonotes noaster addtext("Controls","no")
ivreg2 ln_emp_high_skilled (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nor2 nocons tex(frag) label  ctitle("(log) Emp. rate", "HS native","IV") nonotes noaster  e(widstat) addtext("Controls","no")
reg Dln_emp_high_skilled Dshare_mexicans_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "HS native","OLS") nonotes noaster addtext("Controls","no")
reg Dln_emp_high_skilled Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "HS native","OLS")  nonotes noaster addtext("Controls","yes")
ivreg2 Dln_emp_high_skilled (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_Hemp_short_run$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "HS native","IV")  nonotes noaster  e(widstat) addtext("Controls","yes")



reg ln_emp_high_skilled share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run_census$metro.txt", replace drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("(log) Emp. rate", "HS native","OLS") nonotes noaster addtext("Controls","no")
ivreg2 ln_emp_low_skilled (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run_census$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nor2 nocons tex(frag) label  ctitle("(log) Emp. rate", "HS native","IV") nonotes noaster  e(widstat) addtext("Controls","no")
reg Dln_emp_high_skilled mexican_shock  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run_census$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "HS native","OLS") nonotes noaster addtext("Controls","no")
reg Dln_emp_high_skilled mexican_shock Dln_exports Dln_state_gdp [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_Hemp_short_run_census$metro.txt", drop(_I** time Dln_exports Dln_state_gdp) nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "HS native","OLS")  nonotes noaster addtext("Controls","yes")
ivreg2 Dln_emp_high_skilled (mexican_shock=share_mexican_low_skilled_1980 Dln_exports Dln_state_gdp) Dln_state_gdp Dln_exports [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_Hemp_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Emp. rate", "HS native","IV")  nonotes noaster e(widstat) addtext("Controls","yes")



/***********************
** TABLE: Table_housprices
***********************/



reg ln_HPI_res share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run$metro.txt", drop(_I** time) replace nocons tex(frag) label  ctitle("(log) House Prices", "OLS") nonotes noaster
ivreg2 ln_HPI_res (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("(log) House Prices", "IV") nonotes noaster  e(widstat)
reg Dln_HPI_res Dshare_mexicans_low_skilled  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) House Prices","OLS") nonotes noaster
reg Dln_HPI_res Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) House Prices","OLS")  nonotes noaster
ivreg2 Dln_HPI_res (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_HPI_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) House Prices","IV")  nonotes noaster  e(widstat)

reg ln_HPI_res share_mexicans_low_skilled if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run_census$metro.txt", drop(_I** time) replace nocons tex(frag) label  ctitle("(log) House Prices","OLS") nonotes noaster
ivreg2 ln_HPI_res (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("(log) House Prices","IV") nonotes noaster  e(widstat)
reg Dln_HPI_res mexican_shock  [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run_census$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) House Prices","OLS") nonotes noaster
reg Dln_HPI_res mexican_shock Dln_exports Dln_state_gdp [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_HPI_short_run_census$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) House Prices","OLS")  nonotes noaster
ivreg2 Dln_HPI_res (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_HPI_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) House Prices","IV")  nonotes noaster  e(widstat)



/***********************
** TABLE: Table_rentals
***********************/

gen rent_gap = rent_40pct-ln_HPI_res

reg rent_40pct share_mexicans_low_skilled if year==1995 & ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run$metro.txt", drop(_I** time) replace nocons tex(frag) label  ctitle("(log) Rentals", "OLS") nonotes noaster
ivreg2 rent_40pct (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 & ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("(log) Rentals", "IV") nonotes noaster  e(widstat)
ivreg2 rent_gap (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 & ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("(log) Rent Gap", "IV") nonotes noaster  e(widstat)
reg Drent_40pct Dshare_mexicans_low_skilled if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) Rentals","OLS") nonotes noaster
reg Drent_40pct Dshare_mexicans_low_skilled Dln_exports Dln_state_gdp if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) Rentals","OLS")  nonotes noaster
ivreg2 Drent_40pct (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_rentals_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Rentals","IV")  nonotes noaster  e(widstat)
ivreg2 Drental_HPI_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_rentals_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Rent Gap","IV")  nonotes noaster  e(widstat)

reg rent_40pct share_mexicans_low_skilled if year==1995 & ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run_census$metro.txt", drop(_I** time) replace nocons tex(frag) label  ctitle("(log) Rentals","OLS") nonotes noaster
ivreg2 rent_40pct (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 & ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("(log) Rentals","IV") nonotes noaster  e(widstat)
ivreg2 rent_gap (share_mexicans_low_skilled = share_mexican_low_skilled_1980) if year==1995 & ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("(log) Rent Gap", "IV") nonotes noaster  e(widstat)
reg Drent_40pct mexican_shock if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run_census$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) Rentals","OLS") nonotes noaster
reg Drent_40pct mexican_shock Dln_exports Dln_state_gdp if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust
outreg2 using "tables/Table_rentals_short_run_census$metro.txt", drop(_I** time) nocons tex(frag) label  ctitle("$\Delta$ (log) Rentals","OLS")  nonotes noaster
ivreg2 Drent_40pct (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_rentals_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Rentals","IV")  nonotes noaster  e(widstat)
ivreg2 Drental_HPI_gap (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports if ln_HPI_res!=. [aw=obs_wages_low_skilled], robust 
outreg2 using "tables/Table_rentals_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label  ctitle("$\Delta$ (log) Rent Gap","IV")  nonotes noaster  e(widstat)


count

if `r(N)'==328 {
merge m:1 metarea using "$dropbox/data/share_manufacturing_msa.dta"
label var share_manufacturing "Share of manufacturing"
label var share_machinery_vehicles "Share of manufacturing, vehicles and machinery"

gen share_machinery_exp=share_machinery*Dln_exports
gen share_manufacturing_exp=share_manufacturing*Dln_exports

label var share_manufacturing_exp "Share of manufacturing x $\Delta$ ln exp"
label var share_machinery_exp "Share of manufacturing, vehicles and machinery x $\Delta$ ln exp"


ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster replace
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) share_machinery_ve Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) share_machinery_ve share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) share_manufacturing** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (mexican_shock=share_mexican_low_skilled_1980) share_machinery** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 

ivreg2  Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) share_machinery_ve Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) share_machinery_ve share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) share_manufacturin** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) share_machinery** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition_msa.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
}


count

if `r(N)'!=328 {
merge m:1 statefip using "$dropbox/data/share_manufacturing.dta"
label var share_manufacturing "Share of manufacturing"
label var share_machinery_vehicles "Share of manufacturing, vehicles and machinery"

gen share_machinery_exp=share_machinery*Dln_exports
gen share_manufacturing_exp=share_manufacturing*Dln_exports

label var share_manufacturing_exp "Share of manufacturing x $\Delta$ ln exp"
label var share_machinery_exp "Share of manufacturing, vehicles and machinery x $\Delta$ ln exp"


ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster replace
ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_machinery_ve Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_machinery_ve share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_manufacturing** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 
ivreg2  Dwage_low_skilled_9294 (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_machinery** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage", "LS Ind. controls","IV") e(widstat) nonotes noaster 

ivreg2  Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_machinery_ve Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_machinery_ve share_manufacturing Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_manufacturin** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
ivreg2  Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) share_machinery** Dln_state_gdp Dln_exports Dln_labor_high_skilled Dln_labor_low_skilled [aw=obs_wages_low_skilled], robust first 
outreg2 using "tables/Table_industr_composition.txt", drop(_I** time) nor2 nocons  tex(frag) label addtext("Wages detrended","yes") ctitle("$\Delta$ Wage Gap", "IV") e(widstat) nonotes noaster 
}



/***********************
** TABLE: Table_skill_ratios
***********************/


if "$metro"=="_msa" {
merge 1:1 metarea year using data/Estimation_data_set_short_run_relocation.dta, keep(3) //bringing in population data computed for relocation. 
}
else{
merge 1:1 statefip year using data/Estimation_data_set_short_run_relocation.dta, keep(3) //bringing in population data computed for relocation. 
}

reg Dln_ratio_low_skilled share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust 
outreg2 using "tables/Table_skill_ratios_short_run$metro.txt", drop(_I** time) nocons tex(frag) label replace ctitle("$\Delta$ (log) Skill Ratio","OLS")  nonotes noaster 
reg Dln_ratio_low_skilled Dshare_mexicans_low_skilled Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust 
outreg2 using "tables/Table_skill_ratios_short_run$metro.txt", drop(_I** time) nocons tex(frag) label ctitle("$\Delta$ (log) Skill Ratio","OLS")  nonotes noaster 
ivreg2 Dln_ratio_low_skilled (Dshare_mexicans_low_skilled=share_mexican_1980) Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_skill_ratios_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ (log) Skill Ratio","IV")  nonotes noaster  e(widstat)

reg Dwage_gap share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust 
outreg2 using "tables/Table_skill_ratios_short_run$metro.txt", drop(_I** time)  nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","OLS")  nonotes noaster  
reg Dwage_gap Dln_ratio_low_skilled Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_skill_ratios_short_run$metro.txt", drop(_I** time)  nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","OLS")  nonotes noaster 
ivreg2 Dwage_gap (Dln_ratio_low_skilled=share_mexican_1980) Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_skill_ratios_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","IV")  nonotes noaster  e(widstat)
ivreg2 Dwage_gap (Dshare_mexicans_low_skilled=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dratio_high [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_skill_ratios_short_run$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","IV")  nonotes noaster  e(widstat)


reg Dln_ratio_low_skilled share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust 
outreg2 using "tables/Table_skill_ratios_short_run_census$metro.txt", drop(_I** time)  nocons tex(frag) label replace ctitle("$\Delta$ (log) Skill Ratio","OLS")  nonotes noaster 
reg Dln_ratio_low_skilled mexican_shock Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust 
outreg2 using "tables/Table_skill_ratios_short_run_census$metro.txt", drop(_I** time)  nocons tex(frag) label ctitle("$\Delta$ (log) Skill Ratio","OLS")  nonotes noaster 
ivreg2 Dln_ratio_low_skilled (mexican_shock=share_mexican_1980) Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_skill_ratios_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ (log) Skill Ratio","IV")  nonotes noaster  e(widstat)

reg Dwage_gap share_mexican_1980 Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust 
outreg2 using "tables/Table_skill_ratios_short_run_census$metro.txt", drop(_I** time)  nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","OLS")  nonotes noaster  
reg Dwage_gap Dln_ratio_low_skilled Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_skill_ratios_short_run_census$metro.txt", drop(_I** time)  nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","OLS")  nonotes noaster 
ivreg2 Dwage_gap (Dln_ratio_low_skilled=share_mexican_1980) Dln_state_gdp Dln_exports if year==1995 [aw=obs_pop], robust cluster(statefip) 
outreg2 using "tables/Table_skill_ratios_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","IV")  nonotes noaster  e(widstat)
ivreg2 Dwage_gap (mexican_shock=share_mexican_low_skilled_1980) Dln_state_gdp Dln_exports Dratio_high [aw=obs_wages_low_skilled], robust first
outreg2 using "tables/Table_skill_ratios_short_run_census$metro.txt", drop(_I** time) nor2 nocons tex(frag) label ctitle("$\Delta$ (log) Wage Gap","IV")  nonotes noaster  e(widstat)

