%%%% CALCULATE CITY EVOLUTION %%%%%
%%%% By: Joan Monras %%%%%
clear all;
close all;
%clc;

option=optimset('MaxFunEvals',100000,'MaxIter',100000,'Display','iter');
rng(1);

global Num_MSAs lambda eta beta epsilonlabor

data = csv2mat_numeric('initial_distribution.csv');

cmsa=data.statefip;
L0m = data.worker_l;
H0m = data.worker_h;

Mex_shock_1 = data.Dshare_mexicans_low_skilled;
Mex_shock_2 = data.mexican_shock;

Mex_distribution = data.mexican_share_1990;

Bm = data.B;

Num_MSAs = length(cmsa);
L = sum(L0m);
H = sum(H0m);

[lambda, eta, alpha, epsilonlabor, beta] = parameters;

periods=100;

theta=data.theta;

epsilon=zeros([Num_MSAs 1]);

Am=ones([Num_MSAs 1]);
AHm=ones([Num_MSAs 1]);
ABm=ones([Num_MSAs 1]);

Pm=ones([Num_MSAs 1])*300;


Q0m=ones([Num_MSAs 1]);
W0m=ones([Num_MSAs 1]);
WH0m=ones([Num_MSAs 1]);

Q1m=ones([Num_MSAs 1]);
W1m=ones([Num_MSAs 1]);
WH1m=ones([Num_MSAs 1]);

for i=1:Num_MSAs 
    Q0m(i)=Bm(i)*(H0m(i)^(theta(i))*L0m(i)^(1-theta(i)));
    W0m(i)=(1-theta(i))*Q0m(i)*L0m(i)^(-1);
    WH0m(i)=(theta(i))*Q0m(i)*H0m(i)^(-1);
end



%% SOLVE MODEL

% Start with initial conditions

V0=0;
V0m=zeros([Num_MSAs 1]);
V1m=zeros([Num_MSAs 1]);
VH0=0;
VH0m=zeros([Num_MSAs 1]);
VH1m=zeros([Num_MSAs 1]);

L_finalm=zeros([Num_MSAs 1]);


share_value=zeros([Num_MSAs 1]);
share_value1=zeros([Num_MSAs 1]);
share_pop=zeros([Num_MSAs 1]);
level_pop=zeros([Num_MSAs 1]);

evolution_pop=zeros([Num_MSAs periods]);
evolution_value=zeros([Num_MSAs periods]);

evolution_popH=zeros([Num_MSAs periods]);
evolution_valueH=zeros([Num_MSAs periods]);

time=ones([1 periods]);
Am(1)=1;
AHm(1)=1;
L1m=zeros([Num_MSAs 1]);
H1m=zeros([Num_MSAs 1]);

for i=1:Num_MSAs 
    Am(i)=(L0m(i)^(lambda*(1-(1-eta)*beta))*W0m(1)*Pm(1)^(-alpha))/(L0m(1)^(lambda*(1-(1-eta)*beta))*W0m(i)*Pm(i)^(-alpha));
    AHm(i)=(H0m(i)^(lambda*(1-(1-eta)*beta))*WH0m(1)*Pm(1)^(-alpha))/(H0m(1)^(lambda*(1-(1-eta)*beta))*WH0m(i)*Pm(i)^(-alpha));
end


for i=1:Num_MSAs 
    V0=V0+(Am(i)*W0m(i)*Pm(i)^(-alpha))^(1/(lambda*(1-(1-eta)*beta)));
    VH0=VH0+(AHm(i)*WH0m(i)*Pm(i)^(-alpha))^(1/(lambda*(1-(1-eta)*beta)));
end

V0=V0^((lambda*(1-(1-eta)*beta))/(1-beta));
VH0=VH0^((lambda*(1-(1-eta)*beta))/(1-beta));


for i=1:Num_MSAs 
    V0m(i)=(Am(i)*W0m(i)*Pm(i)^(-alpha)*V0^(eta*beta))^(1/(1-(1-eta)*beta));
    VH0m(i)=(AHm(i)*WH0m(i)*Pm(i)^(-alpha)*VH0^(eta*beta))^(1/(1-(1-eta)*beta));
end

share_pop_initial=L0m/L;

share_value_initial=(V0m/V0).^(1/lambda);

%plot(share_pop_initial, share_value_initial);


V_initial=V0;
V_initialm=V0m;
L_initialm=L0m;




%% Pre-shock periods forward

for t=1:4

for i=1:Num_MSAs 
    Q1m(i)=Bm(i)*(H0m(i)^(theta(i))*L0m(i)^(1-theta(i)));
    W1m(i)=(1-theta(i))*Q1m(i)*L0m(i)^(-1);
    WH1m(i)=(theta(i))*Q1m(i)*H0m(i)^(-1);
    Pm(i)=Pm(i);
end

for i=1:Num_MSAs
    L1m(i)=eta*(V0m(i)/V0)^(1/lambda)*L+(1-eta)*L0m(i);
    H1m(i)=eta*(VH0m(i)/VH0)^(1/lambda)*H +(1-eta)*H0m(i);
end

V1=0;
VH1=0;

for i=1:Num_MSAs 
    V1=V1+(V0m(i)/(Am(i)*W1m(i)*Pm(i)^(-alpha)))^(1/(beta*lambda*(1-eta)));
    VH1=VH1+(VH0m(i)/(AHm(i)*WH1m(i)*Pm(i)^(-alpha)))^(1/(beta*lambda*(1-eta)));
end

for i=1:Num_MSAs 
   V1m(i)=(Am(i)*W1m(i)*Pm(i)^(-alpha))*V0m(i)^(beta*(1-eta))*V0^(eta*beta);
   VH1m(i)=(AHm(i)*WH1m(i)*Pm(i)^(-alpha))*VH0m(i)^(beta*(1-eta))*VH0^(eta*beta);
end

V1=(V1)^(lambda*(1-eta));
VH1=(VH1)^(lambda*(1-eta));


share_value=(V1m/V1).^(1/lambda);
share_pop=L1m/L;
level_pop=L1m;

share_valueH=(VH1m/VH1).^(1/lambda);
share_popH=H1m/L;
level_popH=H1m;

V0m=V1m;
V0=V1;
L0m=L1m;

VH0m=VH1m;
VH0=VH1;
H0m=H1m;

for i=1:Num_MSAs 
    evolution_pop(i,t)=level_pop(i);
    evolution_value(i,t)=share_value(i);    

    evolution_popH(i,t)=level_popH(i);
    evolution_valueH(i,t)=share_valueH(i);    
end



time(t)=t;

end


%% Shock to the system

for i=1:Num_MSAs 
    L0m(i)=L0m(i)*(1+Mex_shock_1(i));
    H1m(i)=H0m(i);
end
L = sum(L0m);


for i=1:Num_MSAs 
    Q1m(i)=Bm(i)*(H0m(i)^(theta(i))*L0m(i)^(1-theta(i)));
    W1m(i)=(1-theta(i))*Q1m(i)*L0m(i)^(-1);
    WH1m(i)=(theta(i))*Q1m(i)*H0m(i)^(-1);
    Pm(i)=Pm(i);
end

for k=1:100

V1=0;
VH1=0;

for i=1:Num_MSAs 
    V1=V1+(V0m(i))^(1/lambda);
    VH1=VH1+(VH0m(i))^(1/lambda);
end

V1=(V1)^(lambda);
VH1=(VH1)^(lambda);

for i=1:Num_MSAs 
   V1m(i)=(Am(i)*W1m(i)*Pm(i)^(-alpha))*V0m(i)^(beta*(1-eta))*V0^(eta*beta);
   VH1m(i)=(AHm(i)*WH1m(i)*Pm(i)^(-alpha))*VH0m(i)^(beta*(1-eta))*VH0^(eta*beta);
end

V0m=V1m;
V0=V1;

VH0m=VH1m;
VH0=VH1;
    
end


%% Post shock periods



for t=5:periods

for i=1:Num_MSAs 
    Q1m(i)=Bm(i)*(H0m(i)^(theta(i))*L0m(i)^(1-theta(i)));
    W1m(i)=(1-theta(i))*Q1m(i)*L0m(i)^(-1);
    WH1m(i)=(theta(i))*Q1m(i)*H0m(i)^(-1);
    Pm(i)=Pm(i);
end


V1=0;
VH1=0;

for i=1:Num_MSAs 
    V1=V1+(V0m(i)/(Am(i)*W1m(i)*Pm(i)^(-alpha)))^(1/(beta*lambda*(1-eta)));
    VH1=VH1+(VH0m(i)/(AHm(i)*WH1m(i)*Pm(i)^(-alpha)))^(1/(beta*lambda*(1-eta)));
end

for i=1:Num_MSAs 
   V1m(i)=(Am(i)*W1m(i)*Pm(i)^(-alpha))*V0m(i)^(beta*(1-eta))*V0^(eta*beta);
   VH1m(i)=(AHm(i)*WH1m(i)*Pm(i)^(-alpha))*VH0m(i)^(beta*(1-eta))*VH0^(eta*beta);
end

V1=(V1)^(lambda*(1-eta));
VH1=(VH1)^(lambda*(1-eta));


for i=1:Num_MSAs
    L1m(i)=eta*(V0m(i)/V0)^(1/lambda)*L+(1-eta)*L0m(i);
    H1m(i)=eta*(VH0m(i)/VH0)^(1/lambda)*H+(1-eta)*H0m(i);
end


share_value=(V1m/V1).^(1/lambda);
share_pop=L1m/L;
level_pop=L1m;

share_valueH=(VH1m/VH1).^(1/lambda);
share_popH=H1m/L;
level_popH=H1m;

V0m=V1m;
V0=V1;
L0m=L1m;

VH0m=VH1m;
VH0=VH1;
H0m=H1m;

for i=1:Num_MSAs 
    evolution_pop(i,t)=level_pop(i);
    evolution_value(i,t)=share_value(i);    

    evolution_popH(i,t)=level_popH(i);
    evolution_valueH(i,t)=share_valueH(i);    

end

time(t)=t;

end


%% output

evolution_pop_graph=ones([periods 1]);
evolution_value_graph=ones([periods 1]);

evolution_pop_graph2=ones([periods 1]);
evolution_value_graph2=ones([periods 1]);

for t=1:periods
    evolution_pop_graph(t)=evolution_pop(5,t)
    evolution_value_graph(t)=evolution_value(5,t)
    evolution_pop_graph2(t)=evolution_pop(33,t)
    evolution_value_graph2(t)=evolution_value(33,t)
end

evolution_pop_graph=transpose(evolution_pop_graph);
evolution_pop_graph(1)=Inf;
evolution_value_graph=transpose(evolution_value_graph);
evolution_value_graph(1)=Inf;

evolution_pop_graph2=transpose(evolution_pop_graph2);
evolution_pop_graph2(1)=Inf;
evolution_value_graph2=transpose(evolution_value_graph2);
evolution_value_graph2(1)=Inf;

plot(time,evolution_pop_graph);
%plot(time,evolution_value_graph);

%plot(time,evolution_pop_graph2);
%plot(time,evolution_value_graph2);

%V_finalm=V_finalm/median(V_finalm);
%V_initialm=V_initialm/median(V_initialm);
%V_intermediatem=V_intermediatem/median(V_intermediatem);

%export_data=[cmsa L_initialm V_initialm  epsilon share_pop_initial share_value_initial]; 

%filename = sprintf('%s_%d','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data',l);
%filename = strcat(filename,'.csv');

%dlmwrite(filename,export_data);

aux=evolution_value(:,4);
aux2=evolution_pop(:,4);

auxH=evolution_valueH(:,4);
aux2H=evolution_popH(:,4);

for t=1:periods
    for i=1:Num_MSAs 
        evolution_value(i,t)=evolution_value(i,t)/aux(i);
%        evolution_pop(i,t)=evolution_pop(i,t)/aux2(i);

        evolution_valueH(i,t)=evolution_valueH(i,t)/auxH(i);
%        evolution_popH(i,t)=evolution_popH(i,t)/aux2H(i);
    end
end


export_data2=[cmsa evolution_pop]; 
filename2 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_population');
filename2 = strcat(filename2,'.csv');
dlmwrite(filename2,export_data2);

export_data3=[cmsa evolution_value]; 
filename3 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_value');
filename3 = strcat(filename3,'.csv');
dlmwrite(filename3,export_data3);

export_data4=[cmsa evolution_popH]; 
filename4 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_populationH');
filename4 = strcat(filename4,'.csv');
dlmwrite(filename4,export_data4);

export_data5=[cmsa evolution_valueH]; 
filename5 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_valueH');
filename5 = strcat(filename5,'.csv');
dlmwrite(filename5,export_data5);


