%%%% CALCULATE CITY EVOLUTION %%%%%
%%%% By: Joan Monras %%%%%
close all;
%clc;

option=optimset('MaxFunEvals',100000,'MaxIter',100000,'Display','iter');
rng(1);

global Num_MSAs lambda eta beta epsilonlabor gamma psi

data = csv2mat_numeric('initial_distribution.csv');

cmsa=data.statefip;
L0m_rent = data.worker_l;
H0m_rent = data.worker_h;

L0m_own = data.worker_l;
H0m_own = data.worker_h;

LFm_rent = data.worker_l;
HFm_rent = data.worker_h;

LFm_own = data.worker_l;
HFm_own = data.worker_h;

Mex_Stock_m=data.mexican_stock;

L0m=L0m_rent+L0m_own;
H0m=H0m_rent+H0m_own;

Mex_shock_1 = data.Dshare_mexicans_low_skilled;
Mex_shock_2 = data.mexican_shock;

Mex_distribution = data.mexican_share_1990;

P0m_rent=data.rent;
P0m_own=data.rent;

P1m_rent=data.rent;
P1m_own=data.rent;

PFm_rent=data.rent;
PFm_own=data.rent;

Bm = data.B;

Num_MSAs = length(cmsa);
L_rent = sum(L0m_rent);
H_rent = sum(H0m_rent);
L_own = sum(L0m_own);
H_own = sum(H0m_own);
L=L_rent+L_own;
H=H_rent+H_own;

[lambda, gamma, eta, alpha, epsilonlabor, beta, psi, parameterset] = parameters;

periods=60;

theta=data.theta;

epsilon=data.epsilon;

Am_rent=ones([Num_MSAs 1]);
AHm_rent=ones([Num_MSAs 1]);

Am_own=ones([Num_MSAs 1]);
AHm_own=ones([Num_MSAs 1]);

Q0m=ones([Num_MSAs 1]);
W0m=ones([Num_MSAs 1]);
WH0m=ones([Num_MSAs 1]);

QFm=ones([Num_MSAs 1]);
WFm=ones([Num_MSAs 1]);
WHFm=ones([Num_MSAs 1]);

Cm_rent=ones([Num_MSAs 1]);
Cm_own=ones([Num_MSAs 1]);

for i=1:Num_MSAs 
    Q0m(i)=Bm(i)*((H0m_rent(i)+H0m_own(i))^(theta(i))*(L0m_rent(i)+L0m_own(i))^(1-theta(i)));
    W0m(i)=(1-theta(i))*Q0m(i)*(L0m_rent(i)+L0m_own(i))^(-1);
    WH0m(i)=(theta(i))*Q0m(i)*(H0m_rent(i)+H0m_own(i))^(-1);
    Cm_rent(i)=P0m_rent(i)/((L0m_rent(i)+H0m_rent(i))^(epsilon(i))*((Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi)));
    Cm_own(i)=P0m_own(i)/((L0m_own(i)+H0m_own(i))^(epsilon(i))*((Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi)));
end

V0_rent=1;
V0m_rent=ones([Num_MSAs 1]);
VH0_rent=1;
VH0m_rent=ones([Num_MSAs 1]);

V0_own=1;
V0m_own=ones([Num_MSAs 1]);
VH0_own=1;
VH0m_own=ones([Num_MSAs 1]);

V0m=ones([Num_MSAs 1]);
VH0m=ones([Num_MSAs 1]);

V0=1;
VH0=1;

VF_rent=1;
VFm_rent=ones([Num_MSAs 1]);
VHF_rent=1;
VHFm_rent=ones([Num_MSAs 1]);

VF_own=1;
VFm_own=ones([Num_MSAs 1]);
VHF_own=1;
VHFm_own=ones([Num_MSAs 1]);

VFm=zeros([Num_MSAs 1]);
VHFm=zeros([Num_MSAs 1]);

VF=1;
VHF=1;

share_pop_initial=zeros([Num_MSAs 1]);
share_value_initial=zeros([Num_MSAs 1]);
share_pop_final=zeros([Num_MSAs 1]);
share_value_final=zeros([Num_MSAs 1]);

evolution_pop=zeros([Num_MSAs periods]);
evolution_pop_rent=zeros([Num_MSAs periods]);
evolution_pop_own=zeros([Num_MSAs periods]);

evolution_popH=zeros([Num_MSAs periods]);
evolution_pop_rentH=zeros([Num_MSAs periods]);
evolution_pop_ownH=zeros([Num_MSAs periods]);

evolution_value=zeros([Num_MSAs periods]);
evolution_value_rent=zeros([Num_MSAs periods]);
evolution_value_own=zeros([Num_MSAs periods]);

evolution_valueH=zeros([Num_MSAs periods]);
evolution_value_rentH=zeros([Num_MSAs periods]);
evolution_value_ownH=zeros([Num_MSAs periods]);

evolution_wage=zeros([Num_MSAs periods]);
evolution_wageH=zeros([Num_MSAs periods]);

evolution_rent_gap=zeros([Num_MSAs periods]);    
evolution_rent=zeros([Num_MSAs periods]);    

time=ones([1 periods]);

%% Solve for initial conditions

Am_rent(1)=1;
AHm_rent(1)=1;
%L1m_rent=zeros([Num_MSAs 1]);
%H1m_rent=zeros([Num_MSAs 1]);

Am_own(1)=Am_rent(1)*(L0m_own(1)/L0m_rent(1))^(gamma)*(P0m_own(1)/P0m_rent(1))^(alpha);
AHm_own(1)=AHm_rent(1)*(H0m_own(1)/H0m_rent(1))^(gamma)*(P0m_own(1)/P0m_rent(1))^(alpha);
%L1m_own=zeros([Num_MSAs 1]);
%H1m_own=zeros([Num_MSAs 1]);

for i=1:Num_MSAs 
    Am_rent(i)=(L0m(i)/L0m(1))^(lambda*(1-beta*(1-eta))-gamma)*(L0m_rent(i)/L0m_rent(1))^(gamma)*(Am_rent(1)*W0m(1)*P0m_rent(1)^(-alpha))/(W0m(i)*P0m_rent(i)^(-alpha));
    Am_own(i)=(L0m(i)/L0m(1))^(lambda*(1-beta*(1-eta))-gamma)*(L0m_own(i)/L0m_own(1))^(gamma)*(Am_own(1)*W0m(1)*P0m_own(1)^(-alpha))/(W0m(i)*P0m_own(i)^(-alpha));

    AHm_rent(i)=(H0m(i)/H0m(1))^(lambda*(1-beta*(1-eta))-gamma)*(H0m_rent(i)/H0m_rent(1))^(gamma)*(AHm_rent(1)*WH0m(1)*P0m_rent(1)^(-alpha))/(WH0m(i)*P0m_rent(i)^(-alpha));
    AHm_own(i)=(H0m(i)/H0m(1))^(lambda*(1-beta*(1-eta))-gamma)*(H0m_own(i)/H0m_own(1))^(gamma)*(AHm_own(1)*WH0m(1)*P0m_own(1)^(-alpha))/(WH0m(i)*P0m_own(i)^(-alpha));
end


for k=1:1400

for i=1:Num_MSAs 
    V0m_rent(i)=Am_rent(i)*W0m(i)*P0m_rent(i)^(-alpha)*V0^(eta*beta)*V0m(i)^((1-eta)*beta);
    VH0m_rent(i)=AHm_rent(i)*WH0m(i)*P0m_rent(i)^(-alpha)*VH0^(eta*beta)*VH0m(i)^((1-eta)*beta);

    V0m_own(i)=Am_own(i)*W0m(i)*P0m_own(i)^(-alpha)*V0^(eta*beta)*V0m(i)^((1-eta)*beta);
    VH0m_own(i)=AHm_own(i)*WH0m(i)*P0m_own(i)^(-alpha)*VH0^(eta*beta)*VH0m(i)^((1-eta)*beta);
end

for i=1:Num_MSAs 
    V0m(i)=((V0m_rent(i))^(1/gamma)+(V0m_own(i))^(1/gamma))^(gamma);   
    VH0m(i)=((VH0m_rent(i))^(1/gamma)+(VH0m_own(i))^(1/gamma))^(gamma);   
end
V0=0;
VH0=0;

for i=1:Num_MSAs 
    V0=V0+V0m(i)^(1/lambda);
    VH0=VH0+VH0m(i)^(1/lambda);
end

V0=V0^(lambda);
VH0=VH0^(lambda);

end


for i=1:Num_MSAs 
    share_pop_initial(i)=(L0m_rent(i))/(L);

    share_value_initial(i)=(V0m(i)/V0)^(1/lambda)*(V0m_rent(i)/V0m(i))^(1/gamma);
end

scatter(share_pop_initial, share_value_initial);


%% Pre-shock periods forward

for t=1:4

for i=1:Num_MSAs 
    Q0m(i)=Bm(i)*((H0m_rent(i)+H0m_own(i))^(theta(i))*(L0m_rent(i)+L0m_own(i))^(1-theta(i)));
    W0m(i)=(1-theta(i))*Q0m(i)^(1)*(L0m_rent(i)+L0m_own(i))^(-1);
    WH0m(i)=(theta(i))*Q0m(i)^(1)*(H0m_rent(i)+H0m_own(i))^(-1);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
end

[L1m_rent,L1m_own,H1m_rent,H1m_own,V1m_rent,V1m_own,VH1m_rent,VH1m_own,V1m,VH1m,V1,VH1] = evolve(Mex_Stock_m,Am_rent,Am_own,AHm_rent,AHm_own,L0m_rent,L0m_own,H0m_rent,H0m_own,V0m_rent,V0m_own,VH0m_rent,VH0m_own,P0m_rent,P0m_own,V0m,VH0m,V0,VH0,Q0m,W0m,WH0m,L,H,Cm_rent,Cm_own,Bm,theta,Num_MSAs, lambda, gamma, eta, beta, alpha, epsilon, psi);


V0m_rent=V1m_rent;
VH0m_rent=VH1m_rent;
V0m_own=V1m_own;
VH0m_own=VH1m_own;
V0m=V1m;
VH0m=VH1m;
V0=V1;
VH0=VH1;

L0m_rent=L1m_rent;
H0m_rent=H1m_rent;
L0m_own=L1m_own;
H0m_own=H1m_own;

L_rent = sum(L0m_rent);
H_rent = sum(H0m_rent);
L_own = sum(L0m_own);
H_own = sum(H0m_own);
L0m=L0m_rent+L0m_own;
H0m=H0m_rent+H0m_own;
L=L_rent+L_own;
H=H_rent+H_own;

time(t)=t;

for i=1:Num_MSAs 
    evolution_value(i,t)=(V1m(i)/V1)^(1/lambda);
    evolution_value_rent(i,t)=(V1m(i)/V1)^(1/lambda)*(V1m_rent(i)/V1m(i))^(1/gamma);
    evolution_value_own(i,t)=(V1m(i)/V1)^(1/lambda)*(V1m_own(i)/V1m(i))^(1/gamma);

    evolution_pop(i,t)=(L1m_own(i)+L1m_rent(i)); %/L;
    evolution_pop_rent(i,t)=L1m_rent(i); %/L;
    evolution_pop_own(i,t)=L1m_own(i); %/L;

    evolution_wage(i,t)=W0m(i);    
    
    evolution_rent_gap(i,t)=P0m_rent(i)/P0m_own(i);    
    evolution_rent(i,t)=P0m_rent(i);    

    evolution_valueH(i,t)=(VH1m(i)/VH1)^(1/lambda);
    evolution_value_rentH(i,t)=(VH1m(i)/VH1)^(1/lambda)*(VH1m_rent(i)/VH1m(i))^(1/gamma);
    evolution_value_ownH(i,t)=(VH1m(i)/VH1)^(1/lambda)*(VH1m_own(i)/VH1m(i))^(1/gamma);

    evolution_popH(i,t)=(H1m_own(i)+H1m_rent(i)); %/H;
    evolution_pop_rentH(i,t)=H1m_rent(i); %/H;
    evolution_pop_ownH(i,t)=H1m_own(i); %/H;

    evolution_wageH(i,t)=WH0m(i);    
end

end

%% Shock periods

Mex_distribution(3)=0;

for t=5:14

if t==5 
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((74318.25-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((74318.25-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==6 
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((192795.8-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((192795.8-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==7
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((154304-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((154304-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==8
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((169738.5-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((169738.5-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==9
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((237913-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((237913-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==10
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((273180.9-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((273180.9-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==11
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((355240.5-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((355240.5-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==12
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((248489.5-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((248489.5-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end

if t==13
   for i=1:Num_MSAs 
    L0m_rent(i)=L0m_rent(i)+Mex_distribution(i)*((435237-232874.8)/1000);
    Mex_Stock_m(i)=Mex_Stock_m(i)+Mex_distribution(i)*((435237-232874.8)/1000);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i))*(Mex_Stock_m(i)/(L0m_rent(i)+L0m_own(i)))^(-psi);
   end
end


L_rent = sum(L0m_rent);
H_rent = sum(H0m_rent);
L_own = sum(L0m_own);
H_own = sum(H0m_own);
L0m=L0m_rent+L0m_own;
H0m=H0m_rent+H0m_own;
L=L_rent+L_own;
H=H_rent+H_own;

   for i=1:Num_MSAs 
     Q0m(i)=Bm(i)*((H0m_rent(i)+H0m_own(i))^(theta(i))*(L0m_rent(i)+L0m_own(i))^(1-theta(i)));
     W0m(i)=(1-theta(i))*Q0m(i)^(1)*(L0m_rent(i)+L0m_own(i))^(-1);
     WH0m(i)=(theta(i))*Q0m(i)^(1)*(H0m_rent(i)+H0m_own(i))^(-1);
   end

for k=1:500 % This solves for the new initial conditions given the shock. 
   
    
for i=1:Num_MSAs 
    V1m_rent(i)=(Am_rent(i)*W0m(i)*P0m_rent(i)^(-alpha))*V0m(i)^(beta*(1-eta))*V0^(beta*eta);
    V1m_own(i)=(Am_own(i)*W0m(i)*P0m_own(i)^(-alpha))*V0m(i)^(beta*(1-eta))*V0^(beta*eta);

    VH1m_rent(i)=(AHm_rent(i)*WH0m(i)*P0m_rent(i)^(-alpha))*VH0m(i)^(beta*(1-eta))*VH0^(beta*eta);
    VH1m_own(i)=(AHm_own(i)*WH0m(i)*P0m_own(i)^(-alpha))*VH0m(i)^(beta*(1-eta))*VH0^(beta*eta);
end

for i=1:Num_MSAs 
   V1m(i)=(V1m_rent(i)^(1/gamma)+V1m_own(i)^(1/gamma))^(gamma);
   VH1m(i)=(VH1m_rent(i)^(1/gamma)+VH1m_own(i)^(1/gamma))^(gamma);
end

V1=0;
VH1=0;

for i=1:Num_MSAs 
   V1=V1+(V1m(i))^(1/lambda);
   VH1=VH1+(VH1m(i))^(1/lambda);
end

V1=V1^(lambda);
VH1=VH1^(lambda);

V0m_rent=V1m_rent;
V0m_own=V1m_own;

VH0m_rent=VH1m_rent;
VH0m_own=VH1m_own;

V0m=V1m;
VH0m=VH1m;

V0=V1;
VH0=VH1;

end

[L1m_rent,L1m_own,H1m_rent,H1m_own,V1m_rent,V1m_own,VH1m_rent,VH1m_own,V1m,VH1m,V1,VH1] = evolve(Mex_Stock_m,Am_rent,Am_own,AHm_rent,AHm_own,L0m_rent,L0m_own,H0m_rent,H0m_own,V0m_rent,V0m_own,VH0m_rent,VH0m_own,P0m_rent,P0m_own,V0m,VH0m,V0,VH0,Q0m,W0m,WH0m,L,H,Cm_rent,Cm_own,Bm,theta,Num_MSAs, lambda, gamma, eta, beta, alpha, epsilon, psi);

V0m_rent=V1m_rent;
VH0m_rent=VH1m_rent;
V0m_own=V1m_own;
VH0m_own=VH1m_own;
V0m=V1m;
VH0m=VH1m;
V0=V1;
VH0=VH1;

L0m_rent=L1m_rent;
H0m_rent=H1m_rent;
L0m_own=L1m_own;
H0m_own=H1m_own;

L_rent = sum(L0m_rent);
H_rent = sum(H0m_rent);
L_own = sum(L0m_own);
H_own = sum(H0m_own);
L0m=L0m_rent+L0m_own;
H0m=H0m_rent+H0m_own;
L=L_rent+L_own;
H=H_rent+H_own;



time(t)=t;

for i=1:Num_MSAs 
    evolution_value(i,t)=(V1m(i)/V1)^(1/lambda);
    evolution_value_rent(i,t)=(V1m(i)/V1)^(1/lambda)*(V1m_rent(i)/V1m(i))^(1/gamma);
    evolution_value_own(i,t)=(V1m(i)/V1)^(1/lambda)*(V1m_own(i)/V1m(i))^(1/gamma);

    evolution_pop(i,t)=(L1m_own(i)+L1m_rent(i)); %/L;
    evolution_pop_rent(i,t)=L1m_rent(i); %/L;
    evolution_pop_own(i,t)=L1m_own(i); %/L;

    evolution_wage(i,t)=W0m(i);    
    
    evolution_rent_gap(i,t)=P0m_rent(i)/P0m_own(i);    
    evolution_rent(i,t)=P0m_rent(i);    

    evolution_valueH(i,t)=(VH1m(i)/VH1)^(1/lambda);
    evolution_value_rentH(i,t)=(VH1m(i)/VH1)^(1/lambda)*(VH1m_rent(i)/VH1m(i))^(1/gamma);
    evolution_value_ownH(i,t)=(VH1m(i)/VH1)^(1/lambda)*(VH1m_own(i)/VH1m(i))^(1/gamma);

    evolution_popH(i,t)=(H1m_own(i)+H1m_rent(i)); %/H;
    evolution_pop_rentH(i,t)=H1m_rent(i); %/H;
    evolution_pop_ownH(i,t)=H1m_own(i); %/H;

    evolution_wageH(i,t)=WH0m(i);    i
end


end

%% Post shock periods

for t=14:periods

    
for i=1:Num_MSAs 
    Q0m(i)=Bm(i)*((H0m_rent(i)+H0m_own(i))^(theta(i))*(L0m_rent(i)+L0m_own(i))^(1-theta(i)));
    W0m(i)=(1-theta(i))*Q0m(i)^(1)*(L0m_rent(i)+L0m_own(i))^(-1);
    WH0m(i)=(theta(i))*Q0m(i)^(1)*(H0m_rent(i)+H0m_own(i))^(-1);
    P0m_rent(i)=Cm_rent(i)*(L0m_rent(i)+H0m_rent(i))^(epsilon(i));
    P0m_own(i)=Cm_own(i)*(L0m_own(i)+H0m_own(i))^(epsilon(i));
end

[L1m_rent,L1m_own,H1m_rent,H1m_own,V1m_rent,V1m_own,VH1m_rent,VH1m_own,V1m,VH1m,V1,VH1] = evolve(Mex_Stock_m,Am_rent,Am_own,AHm_rent,AHm_own,L0m_rent,L0m_own,H0m_rent,H0m_own,V0m_rent,V0m_own,VH0m_rent,VH0m_own,P0m_rent,P0m_own,V0m,VH0m,V0,VH0,Q0m,W0m,WH0m,L,H,Cm_rent,Cm_own,Bm,theta,Num_MSAs, lambda, gamma, eta, beta, alpha, epsilon, psi);

V0m_rent=V1m_rent;
VH0m_rent=VH1m_rent;
V0m_own=V1m_own;
VH0m_own=VH1m_own;
V0m=V1m;
VH0m=VH1m;
V0=V1;
VH0=VH1;

L0m_rent=L1m_rent;
H0m_rent=H1m_rent;
L0m_own=L1m_own;
H0m_own=H1m_own;

L_rent = sum(L0m_rent);
H_rent = sum(H0m_rent);
L_own = sum(L0m_own);
H_own = sum(H0m_own);
L0m=L0m_rent+L0m_own;
H0m=H0m_rent+H0m_own;
L=L_rent+L_own;
H=H_rent+H_own;

time(t)=t;

for i=1:Num_MSAs 
    evolution_value(i,t)=(V1m(i)/V1)^(1/lambda);
    evolution_value_rent(i,t)=(V1m(i)/V1)^(1/lambda)*(V1m_rent(i)/V1m(i))^(1/gamma);
    evolution_value_own(i,t)=(V1m(i)/V1)^(1/lambda)*(V1m_own(i)/V1m(i))^(1/gamma);

    evolution_pop(i,t)=(L1m_own(i)+L1m_rent(i)); %/L;
    evolution_pop_rent(i,t)=L1m_rent(i); %/L;
    evolution_pop_own(i,t)=L1m_own(i); %/L;

    evolution_wage(i,t)=W0m(i);    
    
    evolution_rent_gap(i,t)=P0m_rent(i)/P0m_own(i);    
    evolution_rent(i,t)=P0m_rent(i);    

    evolution_valueH(i,t)=(VH1m(i)/VH1)^(1/lambda);
    evolution_value_rentH(i,t)=(VH1m(i)/VH1)^(1/lambda)*(VH1m_rent(i)/VH1m(i))^(1/gamma);
    evolution_value_ownH(i,t)=(VH1m(i)/VH1)^(1/lambda)*(VH1m_own(i)/VH1m(i))^(1/gamma);

    evolution_popH(i,t)=(H1m_own(i)+H1m_rent(i)); %/H;
    evolution_pop_rentH(i,t)=H1m_rent(i); %/H;
    evolution_pop_ownH(i,t)=H1m_own(i); %/H;

    evolution_wageH(i,t)=WH0m(i);    
end

end


%% output

plot(time, evolution_pop_rent(5,1:periods) );

%plot(time, evolution_pop_own(5,1:periods) );

%plot(time, evolution_rent_gap(5,1:periods) );
%plot(time, evolution_wage(5,1:periods) );
%plot(time, evolution_value(5,1:periods) );
%plot(time, evolution_value_rent(5,1:periods) );

%scatter(share_pop_final,share_pop_rent);
aux1=evolution_value_rent(:,4);
aux2=evolution_value_own(:,4);
aux3=evolution_value_rentH(:,4);
aux4=evolution_value_ownH(:,4);
aux5=evolution_wage(:,4);
aux6=evolution_wageH(:,4);
aux7=evolution_rent(:,4);

for t=1:periods
    for i=1:Num_MSAs 
        evolution_value_rent(i,t)=evolution_value_rent(i,t)/aux1(i);
        evolution_value_own(i,t)=evolution_value_own(i,t)/aux2(i);

        evolution_value_rentH(i,t)=evolution_value_rentH(i,t)/aux3(i);
        evolution_value_ownH(i,t)=evolution_value_ownH(i,t)/aux4(i);

        evolution_wage(i,t)=evolution_wage(i,t)/aux5(i);
        evolution_wageH(i,t)=evolution_wageH(i,t)/aux6(i);

        evolution_rent(i,t)=evolution_rent(i,t)/aux7(i);
    end
end



export_data2=[cmsa evolution_pop_rent]; 
filename2 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_pop_rent_cft5', parameterset);
filename2 = strcat(filename2,'.csv');
dlmwrite(filename2,export_data2);

export_data3=[cmsa evolution_value_rent]; 
filename3 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_value_rent_cft5', parameterset);
filename3 = strcat(filename3,'.csv');
dlmwrite(filename3,export_data3);

export_data4=[cmsa evolution_pop_own]; 
filename4 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_pop_own_cft5', parameterset);
filename4 = strcat(filename4,'.csv');
dlmwrite(filename4,export_data4);

export_data5=[cmsa evolution_value_own]; 
filename5 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_value_own_cft5', parameterset);
filename5 = strcat(filename5,'.csv');
dlmwrite(filename5,export_data5);

export_data6=[cmsa evolution_wage]; 
filename6 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_wage_cft5', parameterset);
filename6 = strcat(filename6,'.csv');
dlmwrite(filename6,export_data6);

export_data7=[cmsa evolution_rent_gap]; 
filename7 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_rent_gap_cft5', parameterset);
filename7 = strcat(filename7,'.csv');
dlmwrite(filename7,export_data7);

export_data8=[cmsa evolution_pop_rentH]; 
filename8 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_pop_rentH_cft5', parameterset);
filename8 = strcat(filename8,'.csv');
dlmwrite(filename8,export_data8);

export_data9=[cmsa evolution_value_rentH]; 
filename9 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_value_rentH_cft5', parameterset);
filename9 = strcat(filename9,'.csv');
dlmwrite(filename9,export_data9);

export_data10=[cmsa evolution_pop_ownH]; 
filename10 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_pop_ownH_cft5', parameterset);
filename10 = strcat(filename10,'.csv');
dlmwrite(filename10,export_data10);

export_data11=[cmsa evolution_value_ownH]; 
filename11 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_value_ownH_cft5', parameterset);
filename11 = strcat(filename11,'.csv');
dlmwrite(filename11,export_data11);

export_data12=[cmsa evolution_wageH]; 
filename12 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_wageH_cft5', parameterset);
filename12 = strcat(filename12,'.csv');
dlmwrite(filename12,export_data12);

export_data13=[cmsa evolution_rent]; 
filename13 = sprintf('%s','/home/joan/Dropbox/Columbia/Mexico_1994_revision/matlab/simulated_data_evolution_rent_cft5', parameterset);
filename13 = strcat(filename13,'.csv');
dlmwrite(filename13,export_data13);

